OC.L10N.register(
    "tasks",
    {
    "Today" : "Hiziv",
    "Week" : "Sizun",
    "All" : "Pep tra",
    "Current" : "A red",
    "Completed" : "Achuet",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "Unshare with {displayName}" : "Dirannañ gant {displayName}",
    "Edit" : "Cheñch",
    "Copy private link" : "Eilañ al liamm prevez",
    "Delete" : "Dilemel",
    "Unshare" : "Nag eskemm ken",
    "Cancel" : "Arrest",
    "Save" : "Enrollañ",
    "Calendar link copied to clipboard." : "Liamm deizataer eilet d'ar golver",
    "Calendar link could not be copied to clipboard." : "Dibosup eo bet da eilañ al liamm deizataer er golver",
    "An error occurred, unable to delete the calendar." : "Ur fazi a zo bet,  dibosupl lemel an deizataer.",
    "Tomorrow" : "Warc'hoaz"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
