OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Nadchodzące zadania",
    "Important" : "Ważne",
    "Today" : "Dzisiaj",
    "Week" : "Tydzień",
    "All" : "Wszystkie",
    "Current" : "Obecne",
    "Completed" : "Zakończone",
    "Tasks" : "Zadania",
    "The Tasks app for Nextcloud" : "Aplikacja Tasks dla Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Po włączeniu w menu aplikacji Nextcloud pojawi się nowe menu Zadania. Stamtąd możesz dodawać i usuwać zadania, edytować ich tytuł, opis, daty rozpoczęcia i zakończenia oraz oznaczać je jako ważne. Zadania można synchronizować za pomocą CalDav (każda lista zadań jest połączona z kalendarzem Nextcloud, aby zsynchronizować go z lokalnym klientem: Thunderbird, Evolution, KDE Kontact, iCal… - wystarczy dodać kalendarz jako kalendarz zdalny w swoim kliencie). Zadania mogą być dzielone również z innymi użytkownikami. Możesz pobrać swoje zadania jako pliki ICS, używając przycisku pobierania dla każdego kalendarza.",
    "Default list" : "Lista domyślna",
    "Visibility of Smart Collections" : "Widok kategorii",
    "Hidden" : "Ukryty",
    "Visible" : "Widoczny",
    "Automatic" : "Automatyczny",
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "No users or groups" : "Brak użytkowników lub grup",
    "Can edit" : "Może edytować",
    "Unshare with {displayName}" : "Zatrzymaj udostępnianie dla {displayName}",
    "Unable to delete the share." : "Nie można usunąć udostępnienia.",
    "Unable to change permissions." : "Nie można zmienić uprawnień.",
    "Edit" : "Edytuj",
    "Copy private link" : "Kopiuj link prywatny",
    "Copied" : "Skopiowano",
    "Cannot copy" : "Nie można skopiować",
    "Export" : "Eksportuj",
    "Delete" : "Usuń",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Cancel" : "Anuluj",
    "Save" : "Zapisz",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Spowoduje to usunięcie kalendarza \"{calendar}\" oraz wszystkich odpowiednich wydarzeń i zadań.",
    "This will unshare the calendar \"{calendar}\"." : "Spowoduje to zatrzymanie udostępniania kalendarza \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Spowoduje to usunięcie listy \"{list}\" i wszystkich powiązanych zadań.",
    "This will unshare the list \"{list}\"." : "Spowoduje to zatrzymanie udostępnienia listy \"{list}\".",
    "Calendar link copied to clipboard." : "Link do kalendarza skopiowany do schowka.",
    "List link copied to clipboard." : "Link do listy skopiowany do schowka.",
    "Calendar link could not be copied to clipboard." : "Link do kalendarza nie mógł zostać skopiowany do schowka.",
    "List link could not be copied to clipboard." : "Nie udało się skopiować linku do listy do schowka.",
    "The name \"{calendar}\" is already used." : "Nazwa \"{calendar}\" jest już używana.",
    "An empty name is not allowed." : "Pusta nazwa nie jest dozwolona.",
    "An error occurred, unable to delete the calendar." : "Wystąpił błąd, nie można usunąć kalendarza.",
    "An error occurred, unable to delete the list." : "Wystąpił błąd, nie można usunąć listy.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Usuwanie kalendarza za {countdown} sekundę","Usuwanie kalendarza za {countdown} sekundy","Usuwanie kalendarza za {countdown} sekund","Usuwanie kalendarza za {countdown} sekund"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zatrzymywanie udostępnienia kalendarza za {countdown} sekundę","Zatrzymywanie udostępnienia kalendarza za {countdown} sekundy","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Usuwanie listy za {countdown} sekundę","Usuwanie listy za {countdown} sekundy","Usuwanie listy za {countdown} sekund","Usuwanie listy za {countdown} sekund"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Zatrzymywanie udostępnienia listy za {countdown} sekundę","Zatrzymywanie udostępnienia listy za {countdown} sekundy","Zatrzymywanie udostępnienia listy za {countdown} sekund","Zatrzymywanie udostępnienia listy za {countdown} sekund"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Udostępnione z {num} jednostką","Udostępnione z {num} jednostkami","Udostępnione z {num} jednostkami","Udostępnione z {num} jednostkami"],
    "Trash bin" : "Kosz",
    "Loading deleted calendars, tasks and events." : "Wczytywanie usuniętych kalendarzy, zadań i wydarzeń.",
    "You do not have any deleted calendars, tasks or events." : "Nie masz żadnych usuniętych kalendarzy, zadań ani wydarzeń.",
    "Name" : "Nazwa",
    "Deleted" : "Usunięto",
    "Restore" : "Przywróć",
    "Delete permanently" : "Usuń trwale",
    "Empty trash bin" : "Opróżnij kosz",
    "Untitled task" : "Zadanie bez tytułu",
    "Untitled event" : "Wydarzenie bez tytułu",
    "Untitled journal" : "Dziennik bez tytułu",
    "Untitled item" : "Pozycja bez tytułu",
    "Unknown calendar" : "Kalendarz nieznany",
    "Could not load deleted calendars and objects" : "Nie można załadować usuniętych kalendarzy i obiektów",
    "Could not delete calendar or event" : "Nie udało się usunąć kalendarza lub wydarzenia",
    "Could not restore calendar or event" : "Nie udało się przywrócić kalendarza lub wydarzenia",
    "Do you really want to empty the trash bin?" : "Czy na pewno chcesz opróżnić kosz?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elementy w koszu są usuwane po {numDays} dniu","Elementy w koszu są usuwane po {numDays} dniach","Elementy w koszu są usuwane po {numDays} dniach","Elementy w koszu są usuwane po {numDays} dniach"],
    "Select a calendar" : "Wybierz kalendarz",
    "No calendar matches the search." : "Żaden kalendarz nie pasuje do wyszukiwania.",
    "Set date" : "Ustaw datę",
    "Set time" : "Ustaw czas",
    "Delete date" : "Usuń datę",
    "Click here to add a note." : "Kliknij tutaj, aby dodać notatkę.",
    "Set value" : "Ustaw wartość",
    "Delete value" : "Usuń zawartość",
    "Add this as a new tag" : "Dodaj to jako nową etykietę",
    "No tag available. Create one!" : "Brak dostępnej etykiety. Utwórz jedną!",
    "Delete all completed tasks." : "Usuń wszystkie zakończone zadania.",
    "Delete completed tasks." : "Usuń zakończone zadania.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Usunięto wszystkie zakończone zadania z kalendarza \"{calendar}\".",
    "No errors" : "Brak błędów",
    "Open your browser console for more details" : "Otwórz konsolę przeglądarki, aby uzyskać więcej szczegółów",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Spowoduje to usunięcie {taskCount} zakończonego zadania i jego podzadań z kalendarza \"{calendar}\".","Spowoduje to usunięcie {taskCount} zakończonych zadań i ich podzadań z kalendarza \"{calendar}\".","Spowoduje to usunięcie {taskCount} zakończonych zadań i ich podzadań z kalendarza \"{calendar}\".","Spowoduje to usunięcie {taskCount} zakończonych zadań i ich podzadań z kalendarza \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nie można usunąć {failedCount} zadania.","Nie można usunąć {failedCount} zadań.","Nie można usunąć {failedCount} zadań.","Nie można usunąć {failedCount} zadań."],
    "Add an important task to \"{calendar}\"…" : "Dodaj ważne zadanie do \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Dodaj zadanie na dzisiaj do \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Dodaj bieżące zadanie do \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Dodaj zadanie do \"{calendar}\"…",
    "Load all completed tasks." : "Wczytaj wszystkie zakończone zadania.",
    "Change sort order" : "Zmień kierunek sortowania",
    "Relevance" : "Ważne",
    "Sort by completed state, due date, priority, start date and summary." : "Sortuj według zakończonego stanu, terminu, priorytetu, daty rozpoczęcia i podsumowania.",
    "Start date" : "Data od",
    "Sort by start date and summary." : "Sortuj według daty rozpoczęcia i podsumowania.",
    "Due date" : "Data do",
    "Sort by due date and summary." : "Sortuj według daty zakończenia i podsumowania.",
    "Created date" : "Data utworzenia",
    "Sort by created date and summary." : "Sortuj według daty utworzenia i podsumowania.",
    "Last modified" : "Ostatnio zmodyfikowane",
    "Sort by last-modified date and summary." : "Sortuj według daty ostatniej modyfikacji i podsumowania.",
    "Completed date" : "Data zakończenia",
    "Sort by completed date." : "Sortuj według daty zakończenia.",
    "Priority" : "Priorytet",
    "Sort by priority and summary." : "Sortuj według priorytetu i podsumowania.",
    "Alphabetically" : "Alfabetycznie",
    "Sort by summary and priority." : "Sortuj według podsumowania i priorytetu.",
    "Manually" : "Ręcznie",
    "Sort by manual order." : "Sortuj według ręcznej kolejności.",
    "{complete} % completed" : "Zakończone {complete}%",
    "Task has hidden subtasks" : "Zadanie ma ukryte podzadania",
    "Task is pinned" : "Zadanie jest przypięte",
    "Task has a note" : "Zadanie ma notatkę",
    "Add subtask" : "Dodaj podzadanie",
    "Show subtasks" : "Pokaż podzadania",
    "Hide subtasks" : "Ukryj podzadania",
    "Show closed subtasks" : "Pokaż zamknięte podzadania",
    "Hide closed subtasks" : "Ukryj zamknięte podzadania",
    "Delete task" : "Usuń zadanie",
    "Toggle starred" : "Oznaczono gwiazdką",
    "[Yesterday]" : "[Wczoraj]",
    "[Today]" : "[Dzisiaj]",
    "[Tomorrow]" : "[Jutro]",
    "[Completed yesterday]" : "[Zakończone wczoraj]",
    "[Completed today]" : "[Zakończone dzisiaj]",
    "[Completed tomorrow]" : "[Zakończone będzie jutro]",
    "[Yesterday at] LT" : "[Wczoraj o] LT",
    "[Today at] LT" : "[Dzisiaj o] LT",
    "[Tomorrow at] LT" : "[Jutro o] LT",
    "L [at] LT" : "L [o] LT",
    "[Completed yesterday at] LT" : "[Zakończone wczoraj o] LT",
    "[Completed today at] LT" : "[Zakończone dzisiaj o] LT",
    "[Completed tomorrow at] LT" : "[Zakończone będzie jutro o] LT",
    "[Completed] L [at] LT" : "[Zakończone] L [o] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podzadanie do \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Usunięcie zadania za {countdown} sekundę","Usunięcie zadania za {countdown} sekundy","Usunięcie zadania za {countdown} sekund","Usuwanie zadania za {countdown} sekund"],
    "Task is cancelled" : "Zadanie zostało anulowane",
    "Task is completed" : "Zadanie jest zakończone",
    "Task is read-only" : "Zadanie jest tylko do odczytu",
    "Task is not completed" : "Zadanie nie zostało zakończone",
    "Create a new task" : "Utwórz nowe zadanie",
    "Task summary" : "Podsumowanie zadania",
    "Create task" : "Utwórz zadanie",
    "Creating the new task…" : "Tworzenie nowego zadania…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" zostało dodane do \"{calendar}\"",
    "Open task" : "Otwórz zadanie",
    "Close" : "Zamknij",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n zakończone zadanie","%n zakończonych zadań","%n zakończonych zadań","%n zakończonych zadań"],
    "Tomorrow" : "Jutro",
    "Add List…" : "Dodaj listę…",
    "New List" : "Nowa lista",
    "All day" : "Cały dzień",
    "Unpin" : "Odepnij",
    "Pin" : "Przypnij",
    "Show in Calendar" : "Pokaż w kalendarzu",
    "Edit title" : "Edytuj tytuł",
    "Details" : "Szczegóły",
    "Select a classification" : "Wybierz klasyfikację",
    "Select a status" : "Wybierz status",
    "Select tags" : "Wybierz etykiety",
    "Notes" : "Notatki",
    "Reminders" : "Przypomnienia",
    "Repeat" : "Powtórz",
    "When shared show full event" : "Po udostępnieniu pokaż pełne wydarzenie",
    "When shared show only busy" : "Po udostępnieniu pokaż tylko zajęte",
    "When shared hide this event" : "Po udostępnieniu ukryj to wydarzenie",
    "[Completed] L" : "[Zakończone] L",
    "[Completed last] dddd [at] LT" : "[Zakończone ostatnio] dddd [o] LT",
    "[Completed] dddd [at] LT" : "[Zakończone] dddd [o] LT",
    "[Last modified yesterday at] LT" : "[Ostatnia modyfikacja wczoraj o] LT",
    "[Last modified today at] LT" : "[Ostatnia modyfikacja dzisiaj o] LT",
    "[Last modified] L" : "[Ostatnia modyfikacja] L",
    "[Last modified last] dddd [at] LT" : "[Ostatnia modyfikacja ostatnio] dddd [o] LT",
    "[Last modified] dddd [at] LT" : "[Ostatnia modyfikacja] dddd [o] LT",
    "[Created yesterday at] LT" : "[Utworzone wczoraj o] LT",
    "[Created today at] LT" : "[Utworzone dzisiaj o] LT",
    "[Created] L" : "[Utworzone] L",
    "[Created last] dddd [at] LT" : "[Utworzone ostatnio] dddd [o] LT",
    "[Created] dddd [at] LT" : "[Utworzone] dddd [o] LT",
    "Needs action" : "Wymaga działania",
    "In process" : "W trakcie procesu",
    "Canceled" : "Anulowany",
    "Clear status" : "Wyczyść status",
    "Loading task from server." : "Wczytywanie zadania z serwera.",
    "Task not found!" : "Nie znaleziono zadania!",
    "[Starts today]" : "[Rozpoczyna się dzisiaj]",
    "[Starts tomorrow]" : "[Rozpoczyna się jutro]",
    "[Starts on] LL" : "[Rozpoczyna się] LL",
    "[Started yesterday]" : "[Rozpoczęte wczoraj]",
    "[Started on] LL" : "[Rozpoczęte] LL",
    "[Started today at] LT" : "[Rozpoczęte dzisiaj o] LT",
    "[Starts today at] LT" : "[Rozpoczyna się dzisiaj o] LT",
    "[Starts tomorrow at] LT" : "[Rozpoczyna się jutro o] LT",
    "[Starts on] LL [at] LT" : "[Rozpoczyna się] LL [o] LT",
    "[Started yesterday at] LT" : "[Rozpoczęte wczoraj o] LT",
    "[Started on] LL [at] LT" : "[Rozpoczęte] LL [o] LT",
    "Set start date" : "Ustaw datę rozpoczęcia",
    "[Due today]" : "[Na dzisiaj]",
    "[Due tomorrow]" : "[Na jutro]",
    "[Due on] LL" : "[Na dzień] LL",
    "[Was due yesterday]" : "[Było na wczoraj]",
    "[Was due on] LL" : "[Było w dniu] LL",
    "[Was due today at] LT" : "[Było dzisiaj o] LT",
    "[Due today at] LT" : "[Na dzisiaj o] LT",
    "[Due tomorrow at] LT" : "[Na jutro o] LT",
    "[Due on] LL [at] LT" : "[Na dzień] LL [o] LT",
    "[Was due yesterday at] LT" : "[Było wczoraj o] LT",
    "[Was due on] LL [at] LT" : "[Było w dniu] LL [o] LT",
    "Set due date" : "Ustaw datę zakończenia",
    "Priority {priority}: low" : "Priorytet {priority}: niski",
    "Priority {priority}: medium" : "Priorytet {priority}: średni",
    "Priority {priority}: high" : "Priorytet {priority}: wysoki",
    "No priority assigned" : "Brak priorytetu",
    "{percent} % completed" : "Zakończone {percent}%",
    "No upcoming tasks" : "Brak nadchodzących zadań",
    "upcoming tasks" : "nadchodzących zadań",
    "No tasks today" : "Dzisiaj brak zadań",
    "Mark as done" : "Oznacz jako wykonane",
    "No due date assigned" : "Nie przydzielono terminu",
    "[Due yesterday]" : "[Na wczoraj]",
    "[Due] L" : "[Na dzień] L",
    "[Due yesterday at] LT" : "[Na wczoraj o] LT",
    "[Due] L [at] LT" : "[Na dzień] L [o] LT",
    "Successfully created the task." : "Pomyślnie utworzono zadanie.",
    "Could not delete the task." : "Nie można usunąć zadania.",
    "Synchronizing to the server." : "Synchronizacja z serwerem.",
    "Task successfully saved to server." : "Zadanie pomyślnie zapisane na serwerze.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nie można zaktualizować zadania, ponieważ zostało zmienione na serwerze. Kliknij, aby odświeżyć. Lokalne zmiany zostaną odrzucone.",
    "Could not update the task." : "Nie można zaktualizować zadania.",
    "Successfully updated the task." : "Pomyślnie zaktualizowano zadanie.",
    "Task successfully moved to new calendar." : "Zadanie zostało pomyślnie przeniesione do nowego kalendarza.",
    "An error occurred" : "Wystąpił błąd",
    "Create a task" : "Utwórz zadanie",
    "Message from {author} in {conversationName}" : "Wiadomość od {author} w {conversationName}"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
