OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tâches à venir",
    "Important" : "Important",
    "Today" : "Aujourd'hui",
    "Week" : "Cette semaine",
    "All" : "Tout",
    "Current" : "Maintenant",
    "Completed" : "Terminé",
    "Tasks" : "Tâches",
    "The Tasks app for Nextcloud" : "Application Tasks pour Nextcloud",
    "Default list" : "Liste par défaut",
    "Visibility of Smart Collections" : "Visibilité des collections Smart",
    "Hidden" : "Masqué",
    "Visible" : "Visible",
    "Automatic" : "Automatique",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "No users or groups" : "Aucun utilisateur ou groupe",
    "Can edit" : "Modification possible",
    "Unshare with {displayName}" : "Ne plus partager avec {displayName}",
    "Unable to delete the share." : "Impossible de supprimer le partage.",
    "Unable to change permissions." : "Impossible de modifier les autorisations.",
    "Edit" : "Modifier",
    "Copy private link" : "Copier le lien privé",
    "Copied" : "Copié",
    "Cannot copy" : "Copie impossible",
    "Delete" : "Supprimer",
    "Unshare" : "Ne plus partager",
    "Cancel" : "Annuler",
    "Save" : "Enregistrer",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Cela va supprimer l'agenda \"{calendar}\" ainsi que tous les évènements et tâches associés.",
    "This will unshare the calendar \"{calendar}\"." : "L'agenda \"{calendar}\" ne sera plus partagé.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Cette action va supprimer la liste \"{list}\" et toutes les tâches associées.",
    "This will unshare the list \"{list}\"." : "Cette action va supprimer le partage de la liste \"{list}\".",
    "Calendar link copied to clipboard." : "Lien de l'agenda copié dans le presse-papier.",
    "List link copied to clipboard." : "Lien vers la liste copié dans le presse-papiers.",
    "Calendar link could not be copied to clipboard." : "Impossible de copier le lien de l'agenda dans le presse-papier.",
    "List link could not be copied to clipboard." : "Le lien vers la liste n'a pas pu être copié dans le presse-papiers.",
    "The name \"{calendar}\" is already used." : "Le nom \"{calendar}\" est déjà utilisé.",
    "An empty name is not allowed." : "Un nom vide n'est pas autorisé.",
    "An error occurred, unable to delete the calendar." : "Une erreur est survenue, impossible de supprimer l'agenda.",
    "An error occurred, unable to delete the list." : "Une erreur est survenue, impossible de supprimer la liste.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Suppression de l'agenda dans {countdown} secondes","Suppression de l'agenda dans {countdown} secondes"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fin de partage de l'agenda dans {countdown} secondes.","Fin de partage de l'agenda dans {countdown} secondes."],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Suppression de la liste dans {countdown} seconde","Suppression de la liste dans {countdown} secondes"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Suppression du partage de la liste dans {countdown} seconde","Suppression du partage de la liste dans {countdown} secondes"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Partagé avec {num} entité","Partagé avec {num} entités"],
    "Trash bin" : "Corbeille",
    "Loading deleted calendars, tasks and events." : "Chargement des calendriers, tâches et événements effacés.",
    "You do not have any deleted calendars, tasks or events." : "Vous n'avez aucun calendrier, tâche ou événement effacé.",
    "Name" : "Nom",
    "Deleted" : "Effacé",
    "Restore" : "Restaurer",
    "Delete permanently" : "Supprimer définitivement",
    "Empty trash bin" : "Vider la corbeille",
    "Untitled task" : "Tâche sans titre",
    "Untitled event" : "Événement sans titre",
    "Untitled item" : "Élément sans titre",
    "Unknown calendar" : "Agenda inconnu",
    "Could not load deleted calendars and objects" : "Impossible de charger les calendriers et objets supprimés",
    "Could not delete calendar or event" : "Impossible de supprimer le calendrier ou l'événement",
    "Could not restore calendar or event" : "Impossible de restaurer l'agenda ou l'événement",
    "Do you really want to empty the trash bin?" : "Voulez-vous vraiment vider la corbeille?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Les éléments dans la corbeille sont supprimés après {numDays} jour","Les éléments dans la corbeille sont supprimés après {numDays} jours"],
    "Select a calendar" : "Sélectionnez un agenda",
    "No calendar matches the search." : "Aucun agenda ne correspond à la recherche.",
    "Set date" : "Définir la date",
    "Set time" : "Définir l'heure",
    "Delete date" : "Supprimer la date",
    "Click here to add a note." : "Cliquez ici pour ajouter une remarque.",
    "Set value" : "Définir l'entrée",
    "Delete value" : "Supprimer l'entrée",
    "Add this as a new tag" : "Ajoutez ceci en tant que nouveau tag",
    "No tag available. Create one!" : "Aucune étiquette disponible. Créez-en une !",
    "Delete all completed tasks." : "Supprimer toutes les tâches terminées.",
    "Delete completed tasks." : "Supprimer les tâches terminées.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Supprimer toutes les tâches terminées de l'agenda \"{calendar}\".",
    "No errors" : "Aucune erreur",
    "Open your browser console for more details" : "Ouvrez la console de votre navigateur pour plus d'informations",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Cela va supprimer {taskCount} tâche terminée et ses sous-tâches de l'agenda \"{calendar}\".","Cela va supprimer {taskCount} tâches terminées et ses sous-tâches de l'agenda \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Impossible de supprimer {failedCount} tâche.","Impossible de supprimer {failedCount} tâches."],
    "Add an important task to \"{calendar}\"…" : "Ajouter une tâche importante dans l'agenda \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Ajouter une tâche pour aujourd'hui dans \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Ajouter une tâche courante dans \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Ajouter une tâche dans \"{calendar}\"…",
    "Load all completed tasks." : "Charger toutes les tâches terminées.",
    "Change sort order" : "Modifier l'ordre de tri",
    "Relevance" : "Pertinence",
    "Sort by completed state, due date, priority, start date and summary." : "Trier par état d'avancement, date d'échéance, priorité, date de début et résumé.",
    "Start date" : "Date de début",
    "Sort by start date and summary." : "Trier par date de début et résumé.",
    "Due date" : "Date d'échéance",
    "Sort by due date and summary." : "Trier par échéance et résumé.",
    "Created date" : "Date de création",
    "Sort by created date and summary." : "Trier par date de création et résumé.",
    "Last modified" : "Dernière modification",
    "Sort by last-modified date and summary." : "Trier par date de dernière modification et résumé.",
    "Completed date" : "Date de fin",
    "Sort by completed date." : "Trier par date de fin.",
    "Priority" : "Priorité",
    "Sort by priority and summary." : "Trier par priorité puis résumé.",
    "Alphabetically" : "Par ordre alphabétique",
    "Sort by summary and priority." : "Trier par résumé puis priorité.",
    "Manually" : "Manuellement",
    "Sort by manual order." : "Trier par ordre manuel.",
    "{complete} % completed" : "{complete} % terminé",
    "Task has hidden subtasks" : "La tâche comporte des sous-tâches cachées",
    "Task is pinned" : "La tâche est épinglée",
    "Task has a note" : "La tâche comporte une note",
    "Add subtask" : "Ajouter une sous-tâche",
    "Show subtasks" : "Afficher les sous-tâches",
    "Hide subtasks" : "Masquer les sous-tâches",
    "Show closed subtasks" : "Afficher les sous-tâches fermées",
    "Hide closed subtasks" : "Masquer les sous-tâches fermées",
    "Delete task" : "Supprimer la tâche",
    "Toggle starred" : "Épingler / Désépingler",
    "[Yesterday]" : "[Hier]",
    "[Today]" : "[Aujourd'hui]",
    "[Tomorrow]" : "[Demain]",
    "[Completed yesterday]" : "[Terminé hier]",
    "[Completed today]" : "[Terminé aujourd'hui]",
    "[Completed tomorrow]" : "[Terminé demain]",
    "[Yesterday at] LT" : "[Hier à] LT",
    "[Today at] LT" : "[Aujourd'hui à] LT",
    "[Tomorrow at] LT" : "[Demain à] LT",
    "L [at] LT" : "L [à] LT",
    "[Completed yesterday at] LT" : "[Terminé hier à] LT",
    "[Completed today at] LT" : "[Terminé aujourd'hui à] LT",
    "[Completed tomorrow at] LT" : "[Terminé demain à] LT",
    "[Completed] L [at] LT" : "[Terminé] L [à] LT",
    "Add a subtask to \"{task}\"…" : "Ajouter une sous-tâche dans \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Suppression de la tâche dans {countdown} seconde","Suppression de la tâche dans {countdown} secondes"],
    "Task is completed" : "La tâche est terminée",
    "Create a new task" : "Créer une nouvelle tâche",
    "Task summary" : "Résumé de la tâche",
    "Create task" : "Créer une tâche",
    "Creating the new task…" : "Création de la nouvelle tâche…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" a été ajoutée à \"{calendar}\"",
    "Open task" : "Ouvrir la tâche",
    "Close" : "Fermer",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tâche terminée","%n tâches terminées"],
    "Tomorrow" : "Demain",
    "Add List…" : "Ajouter une liste...",
    "New List" : "Nouvelle liste",
    "All day" : "Toute la journée",
    "Unpin" : "Dépingler",
    "Pin" : "Épingler",
    "Show in Calendar" : "Afficher dans l’agenda",
    "Edit title" : "Modifier le titre",
    "Details" : "Détails",
    "Select a classification" : "Sélectionner une catégorie",
    "Select a status" : "Sélectionner un statut",
    "Select tags" : "Sélectionner les étiquettes",
    "Notes" : "Remarques",
    "Reminders" : "Rappels",
    "Repeat" : "Récurrence",
    "When shared show full event" : "En cas de partage, afficher l’évènement complet",
    "When shared show only busy" : "En cas de partage, afficher la plage horaire comme occupée",
    "When shared hide this event" : "En cas de partage, masquer l’évènement",
    "[Completed] L" : "[Terminé] L",
    "[Completed last] dddd [at] LT" : "[Terminé le] dddd [à] LT",
    "[Completed] dddd [at] LT" : "[Terminé le] dddd [à] LT",
    "[Last modified yesterday at] LT" : "[Dernière modification hier à] LT",
    "[Last modified today at] LT" : "[Dernière modification aujourd'hui à] LT",
    "[Last modified] L" : "[Dernière modification] L",
    "[Last modified last] dddd [at] LT" : "[Dernière modification le] dddd [à] LT",
    "[Last modified] dddd [at] LT" : "[Dernière modification le] dddd [à] LT",
    "[Created yesterday at] LT" : "[Créé hier à] LT",
    "[Created today at] LT" : "[Créé aujourd'hui à] LT",
    "[Created] L" : "[Créé] L",
    "[Created last] dddd [at] LT" : "[Créé le] dddd [à] LT",
    "[Created] dddd [at] LT" : "[Créé le] dddd [à] LT",
    "Needs action" : "Nécessite une action",
    "In process" : "En cours",
    "Canceled" : "Annulé",
    "Clear status" : "Effacer l'état",
    "Loading task from server." : "Chargement de la tâche depuis le serveur.",
    "Task not found!" : "Tâche non trouvée !",
    "[Starts today]" : "[Débute aujourd'hui]",
    "[Starts tomorrow]" : "[Débute demain]",
    "[Starts on] LL" : "[Débute le] LL",
    "[Started yesterday]" : "[Débutées hier]",
    "[Started on] LL" : "[Démarré le] LL",
    "[Started today at] LT" : "[Démarré aujourd'hui à] LT",
    "[Starts today at] LT" : "[Débute aujourd'hui à] LT",
    "[Starts tomorrow at] LT" : "[Débute demain à] LT",
    "[Starts on] LL [at] LT" : "[Débute le] LL [à] LT",
    "[Started yesterday at] LT" : "[Débuté hier à] LT",
    "[Started on] LL [at] LT" : "[Débuté le] LL [à] LT",
    "Set start date" : "Indiquer la date de début",
    "[Due today]" : "[Pour aujourd'hui]",
    "[Due tomorrow]" : "[Pour demain]",
    "[Due on] LL" : "[Pour le] LL",
    "[Was due yesterday]" : "[Était pour hier]",
    "[Was due on] LL" : "[Était pour le] LL",
    "[Was due today at] LT" : "[Était pour aujourd'hui à] LT",
    "[Due today at] LT" : "[Pour aujourd'hui à] LT",
    "[Due tomorrow at] LT" : "[Pour demain à] LT",
    "[Due on] LL [at] LT" : "[Pour le] LL [à] LT",
    "[Was due yesterday at] LT" : "[Était pour hier à] LT",
    "[Was due on] LL [at] LT" : "[Était pour le] LL [à] LT",
    "Set due date" : "Indiquer la date d'échéance",
    "Priority {priority}: low" : "Priorité {priority} : basse",
    "Priority {priority}: medium" : "Priorité {priority} : moyenne",
    "Priority {priority}: high" : "Priorité {priority} : haute",
    "No priority assigned" : "Aucune priorité",
    "{percent} % completed" : "Terminé à {percent} %",
    "No upcoming tasks" : "Pas de tâches à venir",
    "upcoming tasks" : "Tâches à venir",
    "No tasks today" : "Pas de tâches aujourd'hui",
    "Mark as done" : "Marquer comme fait",
    "No due date assigned" : "Aucune date d’échéance attribuée",
    "[Due yesterday]" : "[Échéance hier]",
    "[Due] L" : "[Échéance] L",
    "[Due yesterday at] LT" : "[Échéance hier à] LT",
    "[Due] L [at] LT" : "[Échéance] L [à] LT",
    "Successfully created the task." : "Tâche créée avec succès.",
    "Could not delete the task." : "Impossible de supprimer la tâche.",
    "Synchronizing to the server." : "Synchronisation en cours avec le serveur.",
    "Task successfully saved to server." : "Tâche enregistrée sur le serveur.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "La tâche ne peut pas être mise à jour car elle a été modifiée sur le serveur. Merci de cliquer pour la recharger, les modifications locales seront perdues.",
    "Could not update the task." : "Impossible de mettre à jour la tâche.",
    "Successfully updated the task." : "Tâche modifiée avec succès.",
    "Task successfully moved to new calendar." : "Tâche déplacée avec succès vers le nouvel agenda.",
    "An error occurred" : "Une erreur est survenue",
    "Create a task" : "Créer une tâche",
    "Message from {author} in {conversationName}" : "Message de {author} dans {conversationName}"
},
"nplurals=2; plural=(n > 1);");
