OC.L10N.register(
    "tasks",
    {
    "Today" : "Heddiw",
    "Week" : "Wythnos",
    "All" : "Popeth",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "Unable to delete the share." : "Methu dileu'r gyfran.",
    "Unable to change permissions." : "Methu newid caniatâd.",
    "Edit" : "Golygu",
    "Copied" : "Copïwyd",
    "Delete" : "Dileu",
    "Unshare" : "Dad-rannu",
    "Cancel" : "Diddymu",
    "Save" : "Cadw",
    "No errors" : "Dim gwallau",
    "Open your browser console for more details" : "Agorwch eich consol porwr am fwy o fanylion",
    "Last modified" : "Newidiwyd diwethaf",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "An error occurred" : "Digwyddodd gwall"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
