OC.L10N.register(
    "tasks",
    {
    "Important" : "Quan trọng",
    "Today" : "Hôm nay",
    "Week" : "Tuần",
    "All" : "Tất cả",
    "Current" : "Hiện tại",
    "Completed" : "Hoàn thành",
    "Tasks" : "Nhiệm vụ",
    "The Tasks app for Nextcloud" : "Ứng dụng Nhiệm vụ cho Nextcloud",
    "Hidden" : "Ẩn",
    "Automatic" : "Tự động",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Unable to delete the share." : "Không thể xóa chia sẻ.",
    "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
    "Edit" : "Sửa",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Copied" : "Đã sao chép",
    "Delete" : "Xóa",
    "Unshare" : "Bỏ chia sẽ",
    "Cancel" : "Hủy",
    "Save" : "Lưu",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
    "An empty name is not allowed." : "Để trống tên không được cho phép.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "No errors" : "Không có lỗi",
    "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
    "Due date" : "Thời hạn",
    "Last modified" : "Lần cuối chỉnh sửa",
    "Add List…" : "Thêm vào danh sách…",
    "New List" : "Danh sách mới",
    "All day" : "Cả ngày",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "An error occurred" : "Có lỗi đã xảy ra"
},
"nplurals=1; plural=0;");
