OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tarefas",
    "Important" : "Importante",
    "Today" : "Hoje",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Corrente",
    "Completed" : "Concluído",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "O aplicativo Tarefas para Nextcloud",
    "Default list" : "Lista padrão",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "No users or groups" : "Sem usuários ou grupos",
    "Can edit" : "Pode editar ",
    "Unshare with {displayName}" : "Descompartilhar com {displayName}",
    "Unable to delete the share." : "Não foi possível excluir o compartilhamento.",
    "Unable to change permissions." : "Não foi possível alterar as permissões",
    "Edit" : "Editar",
    "Copy private link" : "Copiar link privado",
    "Copied" : "Copiado",
    "Cannot copy" : "Não pode copiar",
    "Delete" : "Excluir",
    "Unshare" : "Descompartilhar",
    "Cancel" : "Cancelar",
    "Save" : "Salvar",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Isso excluirá o calendário \"{calendar}\" e todos os eventos e tarefas correspondentes.",
    "This will unshare the calendar \"{calendar}\"." : "Isso irá descompartilhar o calendário \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Essa ação vai apagar a lista \"{list}\" e todas as tarefas correspondentes.",
    "This will unshare the list \"{list}\"." : "Essa ação vai descompartilhar a lista \"{list}\".",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "List link copied to clipboard." : "Link para a lista copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "O link do calendário não pôde ser copiado para a área de transferência.",
    "List link could not be copied to clipboard." : "Link para a lista não pôde ser copiado para a área de transferência.",
    "The name \"{calendar}\" is already used." : "O nome \"{calendar}\" já está em uso.",
    "An empty name is not allowed." : "Não é permitido nome em branco",
    "An error occurred, unable to delete the calendar." : "Erro ao excluir o calendário.",
    "An error occurred, unable to delete the list." : "Um erro não permitiu que a lista fosse apagada.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Excluindo o calendário em {countdown} segundo","Excluindo o calendário em {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Descompartilhando o calendário em {countdown} segundo","Descompartilhando o calendário em {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Apagando a lista em {countdown} segundo","Apagando a lista em {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Descompartilhando a lista em {countdown} segundo","Descompartilhando a lista em {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartilhado com {num} entidade","Compartilhado com {num} entidades"],
    "Trash bin" : "Lixeira",
    "Loading deleted calendars, tasks and events." : "Carregando calendários, tarefas e eventos excluídos. ",
    "You do not have any deleted calendars, tasks or events." : "Você não tem calendários, tarefas ou eventos excluídos. ",
    "Name" : "Nome",
    "Deleted" : "Excluído",
    "Restore" : "Restaurar",
    "Delete permanently" : "Apagar permanentemente ",
    "Empty trash bin" : "Esvaziar lixeira",
    "Untitled task" : "Tarefa sem título",
    "Untitled event" : "Evento sem título",
    "Untitled journal" : "Jornal sem título",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos excluídos ",
    "Could not delete calendar or event" : "Não foi possível excluir calendário ou evento",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
    "Do you really want to empty the trash bin?" : "Tem certeza de que deseja esvaziar a lixeira? ",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Os elementos da lixeira são excluídos após {numDays} dia ","Os elementos da lixeira são excluídos após {numDays} dias "],
    "Select a calendar" : "Selecione um calendário",
    "No calendar matches the search." : "Nenhum calendário corresponde à pesquisa.",
    "Set date" : "Definir data ",
    "Set time" : "Definir tempo ",
    "Delete date" : "Apagar data ",
    "Click here to add a note." : "Clique aqui para adicionar uma nota. ",
    "Set value" : "Definir valor ",
    "Delete value" : "Excluir valor ",
    "Add this as a new tag" : "Adicionar como uma nova etiqueta",
    "No tag available. Create one!" : "Nenhuma etiqueta disponível. Crie um! ",
    "Delete all completed tasks." : "Excluir todas as tarefas concluídas.",
    "Delete completed tasks." : "Excluir tarefas concluídas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Todas as tarefas concluídas foram excluídas do calendário \"{calendar}\".",
    "No errors" : "Sem erros",
    "Open your browser console for more details" : "Abra o console do navegador para mais detalhes",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Isso excluirá {taskCount} tarefa1 concluída e suas subtarefas do calendário \"{calendar}\".","Isso excluirá {taskCount} tarefas concluídas e suas subtarefas do calendário \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Não foi possível excluir {failedCount} tarefa.","Não foi possível excluir {failedCount} tarefas."],
    "Add an important task to \"{calendar}\"…" : "Adicionar uma tarefa importante em \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Adicionar uma tarefa para hoje em \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Adicionar uma tarefa atual em \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Adicionar uma tarefa em \"{calendar}\"…",
    "Load all completed tasks." : "Carregar todas as tarefas finalizadas.",
    "Change sort order" : "Alterar a ordem de classificação",
    "Relevance" : "Relevância",
    "Sort by completed state, due date, priority, start date and summary." : "Classificar por status, data devida, prioridade, data de início e resumo.",
    "Start date" : "Data de início",
    "Sort by start date and summary." : "Ordenar por data de início e resumo.",
    "Due date" : "Data programada",
    "Sort by due date and summary." : "Ordenar por data prevista e resumo.",
    "Created date" : "Data de criação",
    "Sort by created date and summary." : "Ordenar por data de criação e resumo.",
    "Last modified" : "Última modificação",
    "Sort by last-modified date and summary." : "Ordenar por data de modificação e resumo.",
    "Completed date" : "Data de finalização",
    "Sort by completed date." : "Ordenar por data de finalização",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Ordenar por prioridade e resumo.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por resumo e prioridade.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar manualmente.",
    "{complete} % completed" : "{complete} % completo",
    "Task has hidden subtasks" : "A tarefa tem subtarefas ocultas ",
    "Task is pinned" : "Tarefa marcada ",
    "Task has a note" : "A tarefa tem uma nota ",
    "Add subtask" : "Adicionar subtarefas",
    "Show subtasks" : "Mostrar subtarefas",
    "Hide subtasks" : "Ocultar subtarefas",
    "Show closed subtasks" : "Mostrar subtarefas fechadas ",
    "Hide closed subtasks" : "Esconder subtarefas fechadas ",
    "Delete task" : "Excluir tarefa",
    "Toggle starred" : "Alternar com estrela ",
    "[Yesterday]" : "[Ontem]",
    "[Today]" : "[Hoje]",
    "[Tomorrow]" : "[Amanhã]",
    "[Completed yesterday]" : "[Finalizado ontem]",
    "[Completed today]" : "[Finalizado hoje]",
    "[Completed tomorrow]" : "[Finalizado amanhã]",
    "[Yesterday at] LT" : "[Ontem às] LT",
    "[Today at] LT" : "[Hoje às] LT",
    "[Tomorrow at] LT" : "[Amanhã às] LT",
    "L [at] LT" : "L [às] LT",
    "[Completed yesterday at] LT" : "[Finalizado ontem às] LT",
    "[Completed today at] LT" : "[Finalizado hoje às ] LT",
    "[Completed tomorrow at] LT" : "[Finalizado amanhã às] LT",
    "[Completed] L [at] LT" : "[Finalizado] L [às] LT",
    "Add a subtask to \"{task}\"…" : "Adicionar uma subtarefa em \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Excluindo a tarefa em {countdown} segundo","Excluindo a tarefa em {countdown} segundos"],
    "Task is completed" : "Tarefa concluída",
    "Create a new task" : "Criar uma nova tarefa",
    "Task summary" : "Resumo da tarefa ",
    "Create task" : "Criar tarefa",
    "Creating the new task…" : "Criando a nova tarefa ... ",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" foi adicionada a \"{calendar}\"",
    "Open task" : "Abrir tarefa ",
    "Close" : "Fechar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas"],
    "Tomorrow" : "Amanhã",
    "Add List…" : "Adicionar Lista...",
    "New List" : "Nova Lista",
    "All day" : "Todo dia",
    "Unpin" : "Desmarcar",
    "Pin" : "Pino",
    "Show in Calendar" : "Mostrar no Calendário ",
    "Edit title" : "Editar título ",
    "Details" : "Detalhes ",
    "Select a classification" : "Selecione uma classificação",
    "Select a status" : "Selecione um status",
    "Select tags" : "Selecione as etiquetas",
    "Notes" : "Notas ",
    "Reminders" : "Lembretes ",
    "Repeat" : "Repetir ",
    "When shared show full event" : "Quando compartilhado, mostrar o evento completo",
    "When shared show only busy" : "Quando compartilhado, mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado, ocultar este evento",
    "[Completed] L" : "[Concluído] L ",
    "[Completed last] dddd [at] LT" : "[Concluído pela última vez] dddd [às] LT ",
    "[Completed] dddd [at] LT" : "[Concluído] dddd [às] LT ",
    "[Last modified yesterday at] LT" : "[Última modificação ontem às] LT ",
    "[Last modified today at] LT" : "[Última modificação hoje às] LT ",
    "[Last modified] L" : "[Última modificação] L ",
    "[Last modified last] dddd [at] LT" : "[Última modificação pela última vez] dddd [às] LT ",
    "[Last modified] dddd [at] LT" : "[Última modificação] dddd [às] LT ",
    "[Created yesterday at] LT" : "[Criado ontem às] LT ",
    "[Created today at] LT" : "[Criado hoje em] LT ",
    "[Created] L" : "[Criado] L ",
    "[Created last] dddd [at] LT" : "[Criado pela última vez] dddd [às] LT ",
    "[Created] dddd [at] LT" : "[Criado] dddd [às] LT",
    "Needs action" : "Necessita ação",
    "In process" : "Em processo",
    "Canceled" : "Cancelado",
    "Clear status" : "Limpar status ",
    "Loading task from server." : "Carregando tarefas do servidor.",
    "Task not found!" : "Tarefa não encontrada!",
    "[Starts today]" : "[Inicia hoje]",
    "[Starts tomorrow]" : "[Inicia amanhã]",
    "[Starts on] LL" : "[Inicia em] LL",
    "[Started yesterday]" : "[Iniciou ontem]",
    "[Started on] LL" : "[Iniciou em] LL",
    "[Started today at] LT" : "[Iniciou hoje às] LT",
    "[Starts today at] LT" : "[Inicia hoje às] LT",
    "[Starts tomorrow at] LT" : "[Inicia amanhã às] LT",
    "[Starts on] LL [at] LT" : "[Inicia em] LL [às] LT",
    "[Started yesterday at] LT" : "[Iniciou ontem às] LT",
    "[Started on] LL [at] LT" : "[Iniciou em] LL [às] LT",
    "Set start date" : "Definir data de início",
    "[Due today]" : "[Para hoje]",
    "[Due tomorrow]" : "[Para amanhã]",
    "[Due on] LL" : "[Para] LL",
    "[Was due yesterday]" : "[Era para ontem]",
    "[Was due on] LL" : "[Era para] LL",
    "[Was due today at] LT" : "[Era para hoje às] LT",
    "[Due today at] LT" : "[Para hoje às] LT",
    "[Due tomorrow at] LT" : "[Para amanhã às] LT",
    "[Due on] LL [at] LT" : "[Para] LL [às] LT",
    "[Was due yesterday at] LT" : "[Era para ontem às] LT",
    "[Was due on] LL [at] LT" : "[Era para] LL [às] LT",
    "Set due date" : "Definir data programada",
    "Priority {priority}: low" : "Prioridade {priority}: baixa",
    "Priority {priority}: medium" : "Prioridade {priority}: média",
    "Priority {priority}: high" : "Prioridade {priority}: alta",
    "No priority assigned" : "Sem prioridade definida",
    "{percent} % completed" : "{percent} % finalizado",
    "No upcoming tasks" : "Sem tarefas futuras",
    "upcoming tasks" : "próximas tarefas",
    "No tasks today" : "Sem tarefas hoje",
    "Mark as done" : "Marcar como concluído",
    "No due date assigned" : "Sem data de vencimento atribuída ",
    "[Due yesterday]" : "[Venceu ontem] ",
    "[Due] L" : "[Para] LL",
    "[Due yesterday at] LT" : "[Venceu ontem às] LT",
    "[Due] L [at] LT" : "[Para] LL [às] LT",
    "Successfully created the task." : "Tarefa criada com sucesso.",
    "Could not delete the task." : "Não foi possível excluir a tarefa.",
    "Synchronizing to the server." : "Sincronizando com o servidor.",
    "Task successfully saved to server." : "Tarefa salva no servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Não foi possível atualizar a tarefa porque ela foi alterada no servidor. Clique para atualizá-la. As alterações locais serão descartadas.",
    "Could not update the task." : "Não foi possível atualizar a tarefa.",
    "Successfully updated the task." : "Tarefa atualizada com sucesso.",
    "Task successfully moved to new calendar." : "Tarefa movida para o novo calendário.",
    "An error occurred" : "Ocorreu um erro",
    "Create a task" : "Crie uma tarefa ",
    "Message from {author} in {conversationName}" : "Mensagem de {author} em {conversationName}"
},
"nplurals=2; plural=(n > 1);");
