/**
 * Nextcloud - Tasks
 *
 * @author Raimund Schlüßler
 * @copyright 2021 Raimund Schlüßler <raimund.schluessler@mailbox.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

@include icon-black-white('circle', 'tasks', 1);

// Adjust app-navigation-toggle position
button.app-navigation-toggle {
	top: 12px !important;
	right: -15px !important;

	@media only screen and (max-width: $breakpoint-mobile) {
		right: 0 !important;
	}
}

// Hack for https://github.com/nextcloud/nextcloud-vue/issues/1384
body {
	min-height: 100%;
	height: auto;
}

.app-navigation {
	> ul > div > li,
	> ul > li {
		&.dnd-hover,
		&.sortable-ghost {
			background-color: var(--color-primary-light);
			box-shadow: 0 0 3px var(--color-primary);
			z-index: 1000;
		}
	}
}

.app-content {
	background-color: var(--color-background-dark) !important;

	> div {
		box-sizing: border-box;
		padding-bottom: 75px;

		.task-list {
			width: 100%;
			padding: 0 15px;

			@media only screen and (max-width: $breakpoint-mobile) {
				padding: 0;
			}

			.grouped-tasks {
				position: relative;
				padding-top: 2px;

				> ol {
					filter: drop-shadow(0 0 1px var(--color-box-shadow));
					z-index: 1;

					&:hover {
						z-index: 10;
					}

					&.completed {
						margin-top: 12px;
					}
				}
			}
		}
	}

	.heading {
		display: flex;
		align-items: center;
		margin-top: 20px !important;

		@media only screen and (max-width: $breakpoint-mobile) {
			padding-left: 15px;
		}

		&--hiddentasks {
			margin-bottom: 0;

			.heading__title {
				display: inline-block;
				padding-right: 16px;
				background-position: right center;
				cursor: pointer;
				&:hover {
					opacity: .7;
				}
			}
		}

		&__title {
			font-weight: bold;
			font-size: 13px;
			word-wrap: break-word;
			opacity: .5;
			white-space: nowrap;
			text-overflow: ellipsis;
			overflow: hidden;

		}

		&__icon-bullet {
			width: 14px;
			min-width: 14px;
			height: 14px;
			border: none;
			border-radius: 50%;
			margin-right: 8px;
		}
	}
}
