OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hodie",
    "Week" : "Septimana",
    "All" : "Tote",
    "Current" : "Actual",
    "Completed" : "Completate",
    "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
    "Hidden" : "Occultate",
    "Visible" : "Visibile",
    "Automatic" : "Automatic",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Edit" : "Modificar",
    "Delete" : "Deler",
    "Unshare" : "Cessa de compartir",
    "Cancel" : "Cancellar",
    "Save" : "Salveguardar",
    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
    "Change sort order" : "Cambiar ordine de classification",
    "Priority" : "Prioritate",
    "Alphabetically" : "Alphabeticamente",
    "Manually" : "Manualmente",
    "Tomorrow" : "Deman",
    "New List" : "Nove Lista",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Set start date" : "Assigna le data de initio",
    "Set due date" : "Assignar data debite"
},
"nplurals=2; plural=(n != 1);");
