OC.L10N.register(
    "tasks",
    {
    "Important" : "Vigtigt",
    "Today" : "I dag",
    "Week" : "Uge",
    "All" : "Alle",
    "Current" : "Nuværende",
    "Completed" : "Fuldført",
    "Tasks" : "Opgaver",
    "Visibility of Smart Collections" : "Synlighed for smarte samlinger",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kan ikke ændre tilladelser.",
    "Edit" : "Redigér",
    "Copy private link" : "Kopier privat link",
    "Copied" : "opieret",
    "Delete" : "Slet",
    "Unshare" : "Fjern deling",
    "Cancel" : "Annullér",
    "Save" : "Gem",
    "Calendar link copied to clipboard." : "Kalender link kopieret.",
    "Calendar link could not be copied to clipboard." : "Kalender link kunne ikke kopieres.",
    "An empty name is not allowed." : "Et tomt navn er ikke tilladt.",
    "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
    "No errors" : "Ingen fejl",
    "Open your browser console for more details" : "Åbn din browsers konsol for flejre detaljer",
    "Change sort order" : "Skift sorteringsrækkefølge",
    "Start date" : "Start dato",
    "Due date" : "Forfaldsdato",
    "Created date" : "Oprettelsesdato",
    "Last modified" : "Sidst ændret",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "Task is completed" : "Denne opgave er udført",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n fuldført opgave","%n fuldførte opgaver"],
    "Tomorrow" : "I morgen",
    "New List" : "Ny liste",
    "All day" : "Hele dagen",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Task not found!" : "Opgaven blev ikke fundet!",
    "Set start date" : "Angiv startdato",
    "Set due date" : "Angiv en forfaldsdato",
    "An error occurred" : "Der var en fejl"
},
"nplurals=2; plural=(n != 1);");
