OC.L10N.register(
    "tasks",
    {
    "Important" : "Importants",
    "Today" : "Avui",
    "Week" : "Aquesta setmana",
    "All" : "Totes",
    "Current" : "Actuals",
    "Completed" : "Completades",
    "Tasks" : "Tasques",
    "The Tasks app for Nextcloud" : "L'app de tasques per Nextcloud",
    "Default list" : "Llista per defecte",
    "Visibility of Smart Collections" : "Visibilitat de les col·leccions intel·ligents",
    "Hidden" : "Ocult",
    "Visible" : "Visible",
    "Automatic" : "Automàtic",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "No users or groups" : "No hi ha usuaris ni grups",
    "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
    "Unable to delete the share." : "No s'ha pogut suprimir la compartició.",
    "Unable to change permissions." : "No s'han pogut canviar els permisos.",
    "Edit" : "Edita",
    "Copy private link" : "Copia l'enllaç privat",
    "Copied" : "Copiat",
    "Delete" : "Suprimeix",
    "Unshare" : "Deixa de compartir",
    "Cancel" : "Cancel·la",
    "Save" : "Desa",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Això suprimirà el calendari \"{calendar}\" i tots els esdeveniments i tasques corresponents.",
    "This will unshare the calendar \"{calendar}\"." : "Això deixa de comparteix el calendari \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Aquesta acció suprimirà la llista \"{list}\" i totes les tasques corresponents.",
    "This will unshare the list \"{list}\"." : "Aquesta acció farà que la llista \"{list}\" deixi d'estar compartida.",
    "Calendar link copied to clipboard." : "S'ha copiat l'enllaç del calendari al porta-retalls.",
    "List link copied to clipboard." : "Enllaç a la llista copiat al porta-retalls.",
    "Calendar link could not be copied to clipboard." : "No s'ha copiat l'enllaç del calendari al porta-retalls.",
    "List link could not be copied to clipboard." : "No s'ha copiat l'enllaç de la llista al porta-retalls.",
    "The name \"{calendar}\" is already used." : "El nom \"[calendar]\" ja està usat.",
    "An empty name is not allowed." : "No es permet un nom buit.",
    "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
    "An error occurred, unable to delete the list." : "S'ha produït un error, no es pot suprimir la llista.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Supressió del calendari en {countdown} segon","Supressió dels calendaris en {countdown} segons"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segon","Deixant de compartir els calendaris en {countdown} segons"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartit amb {num} entitats","Compartit amb [num] entitats"],
    "Delete all completed tasks." : "Suprimeix totes les tasques completades.",
    "Delete completed tasks." : "Suprimeix les tasques completades.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "S'han suprimit totes les tasques completades del calendari \"{calendar}\".",
    "No errors" : "Sense errors",
    "Open your browser console for more details" : "Obriu la consola del navegador per veure més detalls",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Això esborrarà {taskCount} tasques i subtasques completades del calendari \"{calendar}\".","This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} tasques no s'han pogut esborrar..","No s'han pogut suprimit {failedCount} tasques."],
    "Add an important task to \"{calendar}\"…" : "Afegeix una tasca important a \"{calendar}”…",
    "Add a task due today to \"{calendar}\"…" : "Afegeix un tasca per a avui a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Afegeix una tasca en curs a \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Afegeix una tasca a \"{calendar}”…",
    "Load all completed tasks." : "Carrega totes les tasques completades.",
    "Change sort order" : "Canvia l'ordre",
    "Relevance" : "Rellevància",
    "Sort by completed state, due date, priority, start date and summary." : "Ordena per estat de completat, data de venciment, prioritat, data d'inici i resum.",
    "Start date" : "Data d'inici",
    "Sort by start date and summary." : "Ordena per data d'inici i resum.",
    "Due date" : "Per la data",
    "Sort by due date and summary." : "Ordena per estat, prioritat, data d'inici i resum.",
    "Created date" : "Data de creació",
    "Sort by created date and summary." : "Ordena per data de creació i resum.",
    "Last modified" : "Darrera modificació",
    "Sort by last-modified date and summary." : "Ordena per darrera modificació i resum.",
    "Completed date" : "Data de completat",
    "Sort by completed date." : "Ordena per data de completat.",
    "Priority" : "Prioritat",
    "Sort by priority and summary." : "Ordena per prioritat i resum.",
    "Alphabetically" : "Alfabèticament",
    "Sort by summary and priority." : "Ordena per resum i prioritat.",
    "Manually" : "Manual",
    "Sort by manual order." : "Ordena manualment.",
    "{complete} % completed" : "{complete} % completat",
    "Add subtask" : "Afegeix subtasca",
    "Show subtasks" : "Mostra subtasques",
    "Hide subtasks" : "Amaga subtasques",
    "Delete task" : "Esborra la tasca",
    "[Yesterday]" : "[Ahir]",
    "[Today]" : "[Avui]",
    "[Tomorrow]" : "[Demà]",
    "[Completed yesterday]" : "[Completada ahir]",
    "[Completed today]" : "[Completada avui]",
    "[Completed tomorrow]" : "[Completada demà]",
    "[Yesterday at] LT" : "[Ahir a] LT",
    "[Today at] LT" : "[Avui a] LT",
    "[Tomorrow at] LT" : "[Demà a] LT",
    "L [at] LT" : "L [a] LT",
    "[Completed yesterday at] LT" : "[Completada ahir a] LT",
    "[Completed today at] LT" : "[Completada avui a] LT",
    "[Completed tomorrow at] LT" : "[Completada demà a] LT",
    "[Completed] L [at] LT" : "[Completada] L [a] LT",
    "Add a subtask to \"{task}\"…" : "Afegeix una subtasca a \"{task}”…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Supressió de la tasca en {countdown} segon","Supressió de les tasques en {countdown} segons"],
    "Task is completed" : "Completat",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tasca Completada","%n Tasques Completades"],
    "Tomorrow" : "Demà",
    "Add List…" : "Afegeix una llista…",
    "New List" : "Crea una llista",
    "All day" : "Tot el dia",
    "Select a classification" : "Selecciona una classificació",
    "Select a status" : "Seleccioneu un estat",
    "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
    "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
    "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
    "Needs action" : "Cal una acció",
    "In process" : "En procés",
    "Canceled" : "Cancel·lat",
    "Loading task from server." : "Es carrega la tasca del servidor.",
    "Task not found!" : "No s'ha trobat la tasca!",
    "[Starts today]" : "[Comença avui]",
    "[Starts tomorrow]" : "[Comença demà]",
    "[Starts on] LL" : "[Comença el] LL",
    "[Started yesterday]" : "[Començat ahir]",
    "[Started on] LL" : "[Va començar el] LL",
    "[Started today at] LT" : "[Ha començat avui a les] LT",
    "[Starts today at] LT" : "[Comença avui a les] LT",
    "[Starts tomorrow at] LT" : "[Començarà demà a les] LT",
    "[Starts on] LL [at] LT" : "[Comença] LL [a les] LT",
    "[Started yesterday at] LT" : "[Va començar ahir a les]  LT",
    "[Started on] LL [at] LT" : "[Va començar el] LL [a les] LT",
    "Set start date" : "Assigna una data d'inici",
    "[Due today]" : "[Per avui]",
    "[Due tomorrow]" : "[Per demà]",
    "[Due on] LL" : "[Finalitza el] LL",
    "[Was due yesterday]" : "[Va finalitzar ahir]",
    "[Was due on] LL" : "[Va finalitzar el] LL",
    "[Was due today at] LT" : "[Ha finalitzat avui a les] LT",
    "[Due today at] LT" : "[Ha finalitzat avui a les] LT",
    "[Due tomorrow at] LT" : "[Finalitzarà demà a les] LT",
    "[Due on] LL [at] LT" : "[Finalitza el] LL [a les] LT",
    "[Was due yesterday at] LT" : "[Va finalitzar ahir a les] LT",
    "[Was due on] LL [at] LT" : "[Va finalitzar el] LL [a les] LT",
    "Set due date" : "Estableix la data de venciment",
    "Priority {priority}: low" : "Prioritat {priority}: baixa",
    "Priority {priority}: medium" : "Prioritat {priority}: mitjana",
    "Priority {priority}: high" : "Prioritat {priority}: alta",
    "No priority assigned" : "Sense prioritat assignada",
    "{percent} % completed" : "{percent} % completat",
    "Successfully created the task." : "S'ha creat correctament la tasca.",
    "Could not delete the task." : "No s'ha pogut suprimir la tasca.",
    "Synchronizing to the server." : "Sincronitzant amb el servidor.",
    "Task successfully saved to server." : "Tasca desada correctament al servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No s'ha pogut actualitzar la tasca perquè aquesta ha canviat al servidor. Si us plau refresqueu la tasca, es perdran els canvis locals.",
    "Could not update the task." : "No s'ha pogut actualitzar la tasca.",
    "Successfully updated the task." : "S'ha actualitzat correctament la tasca.",
    "Task successfully moved to new calendar." : "S’ha mogut correctament la tasca al calendari nou.",
    "An error occurred" : "S'ha produït un error"
},
"nplurals=2; plural=(n != 1);");
