OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tareas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completada",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "La app de tareas para Nextcloud",
    "Default list" : "Lista por defecto",
    "Visibility of Smart Collections" : "Visibilidad de las colecciones inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Can edit" : "Puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "Unable to delete the share." : "No se ha podido eliminar el elemento compartido.",
    "Unable to change permissions." : "No se han podido cambiar los permisos.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar enlace privado",
    "Copied" : "Copiado",
    "Cannot copy" : "No se pudo copiar",
    "Delete" : "Eliminar",
    "Unshare" : "No compartir",
    "Cancel" : "Cancelar",
    "Save" : "Guardar",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Esto eliminará el calendario \"{calendar}\" y todos los eventos y tareas correspondientes.",
    "This will unshare the calendar \"{calendar}\"." : "Esto dejará de compartir el calendario \"{calendar}\"",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Esto eliminará la lista \"{list}\" y todas sus correspondientes tareas.",
    "This will unshare the list \"{list}\"." : "Esto dejará de compartir la lista \"{list}\".",
    "Calendar link copied to clipboard." : "Enlace de calendario copiado al portapapeles.",
    "List link copied to clipboard." : "Lista de enlaces copiados al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se ha podido copiar al portapapeles el enlace de calendario.",
    "List link could not be copied to clipboard." : "No se ha podido copiar al portapapeles la lista de enlaces.",
    "The name \"{calendar}\" is already used." : "El nombre \"{calendar}\" ya está en uso.",
    "An empty name is not allowed." : "No se puede dejar el nombre en blanco.",
    "An error occurred, unable to delete the calendar." : "Se ha producido un error, no se ha podido borrar el calendario.",
    "An error occurred, unable to delete the list." : "Se ha producido un error, no se ha podido borrar la lista.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Borrando el calendario en {countdown} segundo","Borrando el calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Borrando la lista en {countdown} segundo","Borrando la lista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Dejando de compartir la lista en {countdown} segundo","Dejando de compartir la lista en {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidades","Compartido con {num} entidades"],
    "Trash bin" : "Papelera de reciclaje",
    "Loading deleted calendars, tasks and events." : "Se están cargando los calendarios, las tareas y los eventos eliminados.",
    "You do not have any deleted calendars, tasks or events." : "No tienes ningún calendario, tarea o evento eliminado.",
    "Name" : "Nombre",
    "Deleted" : "Eliminados",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Empty trash bin" : "Vacíar la papelera",
    "Untitled task" : "Tarea sin título",
    "Untitled event" : "Evento sin título",
    "Untitled journal" : "Registro sin título",
    "Untitled item" : "Elemento sin nombre",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se han podido cargar los calendarios y los objetos eliminados",
    "Could not delete calendar or event" : "No se ha podido eliminar un calendario o un evento",
    "Could not restore calendar or event" : "No se ha podido restaurar un calendario o un evento",
    "Do you really want to empty the trash bin?" : "¿De verdad quieres vaciar la papelera?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera de reciclaje se eliminan después de {numDays} día","Los elementos en la papelera de reciclaje se eliminan después de {numDays} días"],
    "Select a calendar" : "Selecciona un calendario",
    "No calendar matches the search." : "Ningún calendario coincide con la búsqueda.",
    "Set date" : "Establecer fecha",
    "Set time" : "Establecer hora",
    "Delete date" : "Borrar fecha",
    "Click here to add a note." : "Haz clic aquí para añadir una nota.",
    "Set value" : "Establecer valor",
    "Delete value" : "Borrar valor",
    "Add this as a new tag" : "Añadir esto como etiqueta nueva",
    "No tag available. Create one!" : "No hay etiquetas. ¡Crea una!",
    "Delete all completed tasks." : "Borrar todas las tareas completadas.",
    "Delete completed tasks." : "Borrar las tareas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Se han eliminado todas las tareas completadas del calendario \"{calendar}\".",
    "No errors" : "No hay errores",
    "Open your browser console for more details" : "Abre la consola del navegador para más detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Esto eliminará {taskCount} tarea completada y sus subtareas del calendario \"{calendar}\".","Esto eliminará {taskCount} tareas completadas y sus subtareas del calendario \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No se ha podido eliminar {failedCount} tarea.","No se han podido eliminar {failedCount} tareas."],
    "Add an important task to \"{calendar}\"…" : "Añadir una tarea importante a \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Añadir una tarea que finaliza hoy a \"{calendar}\"",
    "Add a current task to \"{calendar}\"…" : "Añadir una tarea actual a \"{calendar}\"",
    "Add a task to \"{calendar}\"…" : "Añadir una tarea a \"{calendar}\"",
    "Load all completed tasks." : "Cargar todas las tareas completadas.",
    "Change sort order" : "Cambiar el orden",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenar por grado de completado, fecha límite, prioridad, fecha de inicio y resumen.",
    "Start date" : "Fecha inicial",
    "Sort by start date and summary." : "Ordenar por fecha de inicio y resumen.",
    "Due date" : "Fecha límite",
    "Sort by due date and summary." : "Ordenar por fecha tope y resumen.",
    "Created date" : "Fecha de creación",
    "Sort by created date and summary." : "Ordenar por fecha de creación y resumen.",
    "Last modified" : "Modificado por última vez",
    "Sort by last-modified date and summary." : "Ordenar por fecha de última modificación y resumen.",
    "Completed date" : "Fecha en que se completa",
    "Sort by completed date." : "Ordenar por fecha en que se completa.",
    "Priority" : "Prioridad",
    "Sort by priority and summary." : "Ordenar por prioridad y resumen.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por resumen y prioridad.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar por orden manual.",
    "{complete} % completed" : "{complete} % completado",
    "Task has hidden subtasks" : "Esta tarea tiene subtareas ocultas",
    "Task is pinned" : "Tarea fijada",
    "Task has a note" : "Esta tarea tiene una nota",
    "Add subtask" : "Añadir subtarea",
    "Show subtasks" : "Ver subtareas",
    "Hide subtasks" : "Ocultar subtareas",
    "Show closed subtasks" : "Mostrar subtareas cerradas",
    "Hide closed subtasks" : "Ocultar subtareas cerradas",
    "Delete task" : "Eliminar tarea",
    "Toggle starred" : "Alternar favorito",
    "[Yesterday]" : "[Ayer]",
    "[Today]" : "[Hoy]",
    "[Tomorrow]" : "[Mañana]",
    "[Completed yesterday]" : "[Completado ayer]",
    "[Completed today]" : "[Completado hoy]",
    "[Completed tomorrow]" : "[Completado mañana]",
    "[Yesterday at] LT" : "[Ayer a las] LT",
    "[Today at] LT" : "[Hoy a las] LT",
    "[Tomorrow at] LT" : "[Mañana a las] LT",
    "L [at] LT" : "L [a las] LT",
    "[Completed yesterday at] LT" : "[Completado ayer a a las] LT",
    "[Completed today at] LT" : "[Completado hoy a a las] LT",
    "[Completed tomorrow at] LT" : "[Completado mañana a las] LT",
    "[Completed] L [at] LT" : "[Completado] L [a las] LT",
    "Add a subtask to \"{task}\"…" : "Añadir una subtarea a \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Borrando la tarea en {countdown} segundo","Borrando la tarea en {countdown} segundos"],
    "Task is completed" : "La tarea está completada",
    "Create a new task" : "Crear una tarea nueva",
    "Task summary" : "Resumen de tareas",
    "Create task" : "Crear una tarea",
    "Creating the new task…" : "Creando la tarea nueva...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" se ha añadido a \"{calendar}\"",
    "Open task" : "Tarea abierta",
    "Close" : "Cerrar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarea completada","%n tareas completadas"],
    "Tomorrow" : "Mañana",
    "Add List…" : "Agregar lista...",
    "New List" : "Nueva lista",
    "All day" : "Todo el día",
    "Unpin" : "No fijar",
    "Pin" : "Fijar",
    "Show in Calendar" : "Mostrar en Calendario",
    "Edit title" : "Editar título",
    "Details" : "Detalles",
    "Select a classification" : "Selecciona una clasificación",
    "Select a status" : "Seleccione un estado",
    "Select tags" : "Selecciona etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar solo ocupado",
    "When shared hide this event" : "Al compartir, ocultar este evento",
    "[Completed] L" : "[Completado] L",
    "[Completed last] dddd [at] LT" : "[Completado el pasado] dddd [a las] LT",
    "[Completed] dddd [at] LT" : "[Completado] dddd [a las] LT",
    "[Last modified yesterday at] LT" : "[Última modificación ayer a las] LT",
    "[Last modified today at] LT" : "[Última modificación hoy a las] LT",
    "[Last modified] L" : "[Última modificación] L",
    "[Last modified last] dddd [at] LT" : "[Última modificación el pasado] dddd [a las] LT",
    "[Last modified] dddd [at] LT" : "[Última modificación el] dddd [a las] LT",
    "[Created yesterday at] LT" : "[Creado ayer a las] LT",
    "[Created today at] LT" : "[Creado hoy a las] LT",
    "[Created] L" : "[Creado] L",
    "[Created last] dddd [at] LT" : "[Creado el pasado] dddd [a las] LT",
    "[Created] dddd [at] LT" : "[Creado el] dddd [a las] LT",
    "Needs action" : "Necesita una acción",
    "In process" : "En proceso",
    "Canceled" : "Cancelado",
    "Clear status" : "Borrar estado",
    "Loading task from server." : "Cargando tareas desde el servidor.",
    "Task not found!" : "¡Tarea no encontrada!",
    "[Starts today]" : "[Empieza hoy]",
    "[Starts tomorrow]" : "[Empieza mañana]",
    "[Starts on] LL" : "[Empieza el] LL",
    "[Started yesterday]" : "[Empezó ayer]",
    "[Started on] LL" : "[Empezó el] LL",
    "[Started today at] LT" : "[Empezó hoy a las] LT",
    "[Starts today at] LT" : "[Empieza hoy a las] LT",
    "[Starts tomorrow at] LT" : "[Empieza mañana a las] LT",
    "[Starts on] LL [at] LT" : "[Empieza el] LL [a las] LT",
    "[Started yesterday at] LT" : "[Empezó ayer a las] LT",
    "[Started on] LL [at] LT" : "[Empezó el] LL [a las] LT",
    "Set start date" : "Establecer fecha de inicio",
    "[Due today]" : "[Termina hoy]",
    "[Due tomorrow]" : "[Termina mañana]",
    "[Due on] LL" : "[Termina el] LL",
    "[Was due yesterday]" : "[Terminaba ayer]",
    "[Was due on] LL" : "[Terminaba el] LL",
    "[Was due today at] LT" : "[Terminaba hoy a las] LT",
    "[Due today at] LT" : "[Termina hoy a las] LT",
    "[Due tomorrow at] LT" : "[Termina mañana a las] LT",
    "[Due on] LL [at] LT" : "[Termina el] LL [a las] LT",
    "[Was due yesterday at] LT" : "[Terminaba ayer a las] LT",
    "[Was due on] LL [at] LT" : "[Terminaba el] LL [a las] LT",
    "Set due date" : "Fijar fecha límite",
    "Priority {priority}: low" : "Prioridad {priority}: baja",
    "Priority {priority}: medium" : "Prioridad {priority}: media",
    "Priority {priority}: high" : "Prioridad {priority}: alta",
    "No priority assigned" : "Sin prioridad asignada",
    "{percent} % completed" : "{percent}% completado",
    "No upcoming tasks" : "No hay tareas próximas",
    "upcoming tasks" : "tareas próximas",
    "No tasks today" : "No hay tareas para hoy",
    "Mark as done" : "Marcar como hecho",
    "No due date assigned" : "Fecha de vencimiento sin especificar",
    "[Due yesterday]" : "[Termina ayer]",
    "[Due] L" : "[Termina] L",
    "[Due yesterday at] LT" : "[Termina ayer a las] LT",
    "[Due] L [at] LT" : "[Termina] L [a las] LT",
    "Successfully created the task." : "Tarea creada con éxito.",
    "Could not delete the task." : "No se ha podido eliminar la tarea.",
    "Synchronizing to the server." : "Sincronizando con el servidor.",
    "Task successfully saved to server." : "Tarea guardada correctamente en el servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No se ha podido actualizar la tarea porque ha cambiado en el servidor. Por favor, pulsa para volver a cargarla. Se perderán los cambios locales.",
    "Could not update the task." : "No se ha podido actualizar la tarea.",
    "Successfully updated the task." : "Tarea actualizada con éxito.",
    "Task successfully moved to new calendar." : "Tarea movida con éxito al nuevo calendario.",
    "An error occurred" : "Ha ocurrido un error",
    "Create a task" : "Crear una tarea",
    "Message from {author} in {conversationName}" : "Mensaje de {author} en {conversationName}"
},
"nplurals=2; plural=(n != 1);");
