OC.L10N.register(
    "tasks",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Today" : "আজ",
    "Week" : "সপ্তাহ",
    "All" : "সবাই",
    "Current" : "বর্তমান",
    "Completed" : "সুসম্পন্ন",
    "Tasks" : "কর্ম",
    "Visibility of Smart Collections" : "চটপট সংগ্রহের দর্শনযোগ্যতা",
    "Hidden" : "লুকনো",
    "Visible" : "দর্শনযোগ্য",
    "Automatic" : "স্বয়ংক্রিয়",
    "Edit" : "সম্পাদনা",
    "Delete" : "মুছে",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "Cancel" : "বাতিল",
    "Save" : "সংরক্ষণ",
    "An empty name is not allowed." : "একটি শুন্য নাম গ্রহণযোগ্য নয়।",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n সুসম্পন্ন কাজ","%n সুসম্পন্ন কাজ"],
    "Tomorrow" : "আগামীকাল",
    "New List" : "নতুন তালিকা",
    "Set start date" : "আরম্ভের তারিখ নির্ধারণ করুন",
    "Set due date" : "কার্যকারিতার তারিখ নির্ধারণ করুন"
},
"nplurals=2; plural=(n != 1);");
