OC.L10N.register(
    "tasks",
    {
    "Important" : "חשוב",
    "Today" : "היום",
    "Week" : "שבוע",
    "All" : "הכול",
    "Current" : "נוכחי",
    "Completed" : "הושלם",
    "Tasks" : "משימות",
    "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
    "Default list" : "רשימת בררת מחדל",
    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
    "Hidden" : "מוסתר",
    "Visible" : "גלוי",
    "Automatic" : "אוטומטי",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
    "Unable to delete the share." : "לא ניתן למחוק את השיתוף.",
    "Unable to change permissions." : "לא ניתן לשנות הרשאות.",
    "Edit" : "עריכה",
    "Copy private link" : "העתקת קישור פרטי",
    "Copied" : "הועתק",
    "Delete" : "מחיקה",
    "Unshare" : "ביטול שיתוף",
    "Cancel" : "ביטול",
    "Save" : "שמירה",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "פעולה זו תמחק את לוח השנה „{calendar}” ואת כל האירועים והמשימות הקשורים אליו.",
    "This will unshare the calendar \"{calendar}\"." : "פעולה זו תבטל את שיתוף לוח השנה „{calendar}”.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "פעולה זו תמחק את הרשימה „{list}” ואת כל המשימות הקשורות אליה.",
    "This will unshare the list \"{list}\"." : "פעולה זו תבטל את שיתוף הרשימה „{list}”.",
    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
    "List link copied to clipboard." : "הקישור לרשימה הועתק ללוח הגזירים.",
    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
    "List link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור לרשימה ללוח הגזירים.",
    "The name \"{calendar}\" is already used." : "השם „{calendar}” כבר נמצא בשימוש.",
    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
    "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
    "An error occurred, unable to delete the list." : "אירעה שגיאה, אין אפשרות למחוק את הרשימה.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["לוח השנה יימחק בעוד שנייה","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["שיתוף לוח השנה יפסק בעוד שנייה","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["הרשימה תימחק בעוד שנייה","הרשימה תימחק בעוד שתי שניות","הרשימה תימחק בעוד {countdown} שניות","הרשימה תימחק בעוד {countdown} שניות"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["שיתוף הרשומה יבוטל בעוד שנייה אחת","שיתוף הרשומה יבוטל בעוד שתי שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["משותף עם ישות אחת","משותף עם {num} ישויות","משותף עם {num} ישויות","משותף עם {num} ישויות"],
    "Delete all completed tasks." : "מחיקת כל המשימות שהושלמו.",
    "Delete completed tasks." : "מחיקת המשימות שהושלמו.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "כל המשימות שהושלמו נמחקו מהיומן „{calendar}”.",
    "No errors" : "אין שגיאות",
    "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["פעולה זו תמחק משימה שהושלמה ואת תת־המשימות שלה מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["לא ניתן למחוק משימה אחת.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות."],
    "Add an important task to \"{calendar}\"…" : "הוספת משימה חשובה אל „{calendar}”",
    "Add a task due today to \"{calendar}\"…" : "הוספה משימה שמועד תפוגתה הוא היום אל „{calendar}”",
    "Add a current task to \"{calendar}\"…" : "הוספת משימה נוכחית אל „{calendar}”",
    "Add a task to \"{calendar}\"…" : "הוספת משימה אל „{calendar}”",
    "Load all completed tasks." : "טעינת כל המשימות שהושלמו.",
    "Change sort order" : "שינוי סדר מיון",
    "Relevance" : "רלוונטיות",
    "Sort by completed state, due date, priority, start date and summary." : "מיון לפי מצב ההשלמה, תאריך הסיום, עדיפות, תאריך ההתחלה והתקציר.",
    "Start date" : "תאריך התחלה",
    "Sort by start date and summary." : "מיון לפי תאריך התחלה ותקציר.",
    "Due date" : "תאריך יעד",
    "Sort by due date and summary." : "מיון לפי תאריך תפוגה ותקציר.",
    "Created date" : "תאריך יצירה",
    "Sort by created date and summary." : "מיון לפי תאריך יצירה ותקציר.",
    "Last modified" : "מועד שינוי אחרון",
    "Sort by last-modified date and summary." : "מיון לפי מועד שינוי אחרון ותקציר.",
    "Completed date" : "תאריך השלמה",
    "Sort by completed date." : "מיון לפי תאריך השלמה.",
    "Priority" : "עדיפות",
    "Sort by priority and summary." : "מיון לפי עדיפות ותקציר.",
    "Alphabetically" : "בסדר האלף-בית",
    "Sort by summary and priority." : "מיון לפי תקציר ועדיפות.",
    "Manually" : "באופן ידני",
    "Sort by manual order." : "מיון ידני.",
    "{complete} % completed" : "{complete} % הושלמו",
    "Add subtask" : "הוספת תת־משימה",
    "Show subtasks" : "הצגת תת־משימות",
    "Hide subtasks" : "הסתרת תת־משימות",
    "Delete task" : "מחיקת משימה",
    "[Yesterday]" : "[אתמול]",
    "[Today]" : "[היום]",
    "[Tomorrow]" : "[מחר]",
    "[Completed yesterday]" : "[הושלמה אתמול]",
    "[Completed today]" : "[הושלמה היום]",
    "[Completed tomorrow]" : "[תושלם מחר]",
    "[Yesterday at] LT" : "[אתמול בשעה] LT",
    "[Today at] LT" : "[היום בשעה] LT",
    "[Tomorrow at] LT" : "[מחר בשעה] LT",
    "L [at] LT" : "L [בשעה] LT",
    "[Completed yesterday at] LT" : "[הושלמה אתמול בשעה] LT",
    "[Completed today at] LT" : "[הושלמה היום בשעה] LT",
    "[Completed tomorrow at] LT" : "[תושלם מחר בשעה] LT",
    "[Completed] L [at] LT" : "[הושלמה] L [בשעה] LT",
    "Add a subtask to \"{task}\"…" : "הוספת תת־משימה אל „{task}”",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["המשימה תימחק בעוד שנייה","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות"],
    "Task is completed" : "המשימה הושלמה",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
    "Tomorrow" : "מחר",
    "Add List…" : "הוספת רשימה…",
    "New List" : "רשימה חדשה",
    "All day" : "כל היום",
    "Select a classification" : "בחירת סיווג",
    "Select a status" : "בחירת מצב",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Needs action" : "נדרשת התערבות",
    "In process" : "בתהליך",
    "Canceled" : "מבוטלת",
    "Loading task from server." : "נטענת משימה מהשרת.",
    "Task not found!" : "לא אותרה משימה!",
    "[Starts today]" : "[מתחילה היום]",
    "[Starts tomorrow]" : "[מתחילה מחר]",
    "[Starts on] LL" : "[מתחילה במועד] LL",
    "[Started yesterday]" : "[החלה אתמול]",
    "[Started on] LL" : "[החלה במועד] LL",
    "[Started today at] LT" : "[החלה היום בשעה] LT",
    "[Starts today at] LT" : "[מתחילה היום בשעה] LT",
    "[Starts tomorrow at] LT" : "[מתחילה מחר בשעה] LT",
    "[Starts on] LL [at] LT" : "[מתחילה ביום] LL [בשעה] LT",
    "[Started yesterday at] LT" : "[החלה אתמול בשעה] LT",
    "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT",
    "Set start date" : "קביעת תאריך התחלה",
    "[Due today]" : "[מועד התפוגה הוא היום]",
    "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
    "[Due on] LL" : "[מועד התפוגה הוא] LL",
    "[Was due yesterday]" : "[מועד התפוגה היה אתמול]",
    "[Was due on] LL" : "[מועד התפוגה היה] LL",
    "[Was due today at] LT" : "[מועד התפוגה היה היום בשעה] LT",
    "[Due today at] LT" : "[מועד התפוגה הוא היום בשעה] LT",
    "[Due tomorrow at] LT" : "[מועד התפוגה הוא מחר בשעה] LT",
    "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
    "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
    "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
    "Set due date" : "הגדרת תאריך יעד",
    "Priority {priority}: low" : "עדיפות {priority}: נמוכה",
    "Priority {priority}: medium" : "עדיפות {priority}: בינונית",
    "Priority {priority}: high" : "עדיפות {priority}: גבוהה",
    "No priority assigned" : "לא הוגדרה עדיפות",
    "{percent} % completed" : "{percent} % הושלמו",
    "Successfully created the task." : "המשימה נוצרה בהצלחה.",
    "Could not delete the task." : "לא ניתן למחוק את המשימה.",
    "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
    "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "לא ניתן לעדכן את המשימה כיוון שהיא השתנתה בשרת. נא ללחוץ כדי לרענן אותה, השינויים המקומיים לא יישמרו.",
    "Could not update the task." : "לא ניתן לעדכן את המשימה.",
    "Successfully updated the task." : "המשימה עודכנה בהצלחה.",
    "Task successfully moved to new calendar." : "המשימה הועברה בהצלחה ליומן חדש.",
    "An error occurred" : "אירעה שגיאה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
