OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Nadchádzajúce úlohy",
    "Important" : "Dôležité",
    "Today" : "Dnes",
    "Week" : "Týždeň",
    "All" : "Všetky",
    "Current" : "Aktuálne",
    "Completed" : "Dokončené",
    "Tasks" : "Úlohy",
    "The Tasks app for Nextcloud" : "Aplikácia úloh pre Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Po povolení sa objaví nové menu Úlohy v aplikáciách Nextcloud. Odtiaľ možno pridávať a mazať úlohy, upravovať ich názov, popis, dátum začiatku a termín dokončenia, časy upozornení, označovať ich ako dôležité. Úlohy možno zdieľať medzi užívateľmi. Úlohy možno synchronizovať pomocou CalDav (každý zoznam úloh prepojený na kalendár Nextcloud sa dá synchronizovať s lokálnym klientom -Thunderbird, Evolution, KDE Kontact, iCal... - stačí pridať ako vzdialený kalendár v klientovi). Je možné stiahnuť úlohy ako súbory ICS pomocou tlačítka stiahnuť pri každom kalendári",
    "Default list" : "Predvolený zoznam",
    "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
    "Hidden" : "Skryté",
    "Visible" : "Viditeľné",
    "Automatic" : "Automaticky",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "No users or groups" : "Žiadny používatelia alebo skupiny",
    "Can edit" : "Môže upravovať",
    "Unshare with {displayName}" : "Zrušiť zdieľanie s {displayName}",
    "Unable to delete the share." : "Nemožno zmazať zdieľanie.",
    "Unable to change permissions." : "Nepodarilo sa zmeniť oprávnenia.",
    "Edit" : "Upraviť",
    "Copy private link" : "Kopírovať privátny odkaz",
    "Copied" : "Skopírované",
    "Cannot copy" : "Nemôže kopírovať",
    "Export" : "Export",
    "Delete" : "Zmazať",
    "Unshare" : "Zneprístupniť",
    "Cancel" : "Zrušiť",
    "Save" : "Uložiť",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Táto operácia odstráni kalendár \"{calendar}\" a všetky jeho udalosti a úlohy.",
    "This will unshare the calendar \"{calendar}\"." : "Toto zruší sprístupnenie kalendára \"{calendar}\" .",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Táto operácia odstráni zoznam \"{list}\" a všetky príslušné úlohy.",
    "This will unshare the list \"{list}\"." : "Toto zruší zdieľanie zoznamu {list}.",
    "Calendar link copied to clipboard." : "Odkaz na kalendár skopírovaný do schránky.",
    "List link copied to clipboard." : "Odkaz na zoznam bol skopírovaný do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendár nebolo možné  skopírovať do schránky.",
    "List link could not be copied to clipboard." : "Odkaz na zoznam sa nepodarilo skopírovať do schránky.",
    "The name \"{calendar}\" is already used." : "Názov \"{calendar}\" je už použitý.",
    "An empty name is not allowed." : "Prázdny názov nie je povolený",
    "An error occurred, unable to delete the calendar." : "Vyskytla sa chyba, nie je možné zmazať kalendár.",
    "An error occurred, unable to delete the list." : "Vyskytla sa chyba, zoznam sa nepodarilo odstrániť.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendár bude zmazaný za {countdown} sekundu","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekúnd"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zdieľanie kalendára bude zmazané za {countdown} sekundu","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekúnd"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Zoznam sa odstráni o {countdown} sekundu","Zoznam sa odstráni o {countdown} sekundy","Zoznam sa odstráni o {countdown} sekundy","Zoznam sa odstráni o {countdown} sekúnd"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Zrušenie zdieľania zoznamu o {countdown} sekundu","Zrušenie zdieľania zoznamu o {countdown} sekundy","Zrušenie zdieľania zoznamu o {countdown} sekundy","Zrušenie zdieľania zoznamu o {countdown} sekúnd"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Zdieľané s {num} entitou","Zdieľané s {num} entitami","Zdieľané s {num} entitami","Zdieľané s {num} entitami"],
    "Trash bin" : "Kôš",
    "Loading deleted calendars, tasks and events." : "Načítavajú sa zmazané kalendáre, úlohy alebo udalosti.",
    "You do not have any deleted calendars, tasks or events." : "Nemáte žiadne zmazané kalendáre, úlohy alebo udalosti.",
    "Name" : "Názov",
    "Deleted" : "Zmazané",
    "Restore" : "Obnoviť",
    "Delete permanently" : "Zmazať  natrvalo",
    "Empty trash bin" : "Vyprázdniť kôš",
    "Untitled task" : "Úloha bez názvu",
    "Untitled event" : "Udalosť bez názvu",
    "Untitled journal" : "Denník bez názvu",
    "Untitled item" : "Položka bez názvu",
    "Unknown calendar" : "Neznámy kalendár",
    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
    "Could not delete calendar or event" : "Nie je možné vymazať kalendár alebo udalosť",
    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
    "Do you really want to empty the trash bin?" : "Naozaj chcete vymazať kôš?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Položky v odpadkovom koši budú odstránené po {numDays} dni","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch"],
    "Select a calendar" : "Vybrať kalendár",
    "No calendar matches the search." : "Vyhľadávaniu nezodpovedá žiadny kalendár.",
    "Set date" : "Nastaviť dátum",
    "Set time" : "Nastaviť čas",
    "Delete date" : "Zmazať dátum",
    "Click here to add a note." : "Kliknite sem pre pridanie poznámky.",
    "Set value" : "Nastaviť hodnotu",
    "Delete value" : "Vymazať hodnotu",
    "Add this as a new tag" : "Pridať ako nový štítok",
    "No tag available. Create one!" : "Žiadny štítok. Vytvorte nejaký!",
    "Delete all completed tasks." : "Zmazať všetky ukončené úlohy",
    "Delete completed tasks." : "Zmazať ukončené úlohy",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Zmazať všetky ukončené úlohy z kalendára \"{calendar}\".",
    "No errors" : "Žiadne chyby",
    "Open your browser console for more details" : "Pre podrobnejšie informácie otvorte konzolu vášho webového prehliadača",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Toto vymaže {taskCount} ukočenú úlohu a jej čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukočené úlohy a ich čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukočených úloh a ich čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukončených úloh a ich čiastkové úlohy z kalendára \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nepodarilo sa zmazať {failedCount} úlohu.","Nepodarilo sa zmazať {failedCount} úlohy.","Nepodarilo sa zmazať {failedCount} úloh.","Nepodarilo sa zmazať {failedCount} úloh."],
    "Add an important task to \"{calendar}\"…" : "Pridať dôležitú úlohu do kalendára \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Pridať úlohu s termínom ukončenia dnes do kalendára \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Pridať aktuálnu úlohu do kalendára \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Pridať úlohu do \"{calendar}\"…",
    "Load all completed tasks." : "Načítať všetky ukončené úlohy",
    "Change sort order" : "Zmeniť spôsob zoradenia",
    "Relevance" : "Relevantnosť",
    "Sort by completed state, due date, priority, start date and summary." : "Zoradiť podľa stavu dokončenia, termínu dokončenia, priority, dátumu začiatku a súhrnu.",
    "Start date" : "Dátum začatia",
    "Sort by start date and summary." : "Zoradiť podľa dátumu začiatku a súhrnu.",
    "Due date" : "Termín dokončenia",
    "Sort by due date and summary." : "Zoradiť podľa termínu dokončenia a sumáru.",
    "Created date" : "Dátum vytvorenia",
    "Sort by created date and summary." : "Zoradiť podľa dátumu vytvorenia a súhrnu.",
    "Last modified" : "Naposledy upravené",
    "Sort by last-modified date and summary." : "Zoradiť podľa dátumu poslednej modifikácie a súhrnu.",
    "Completed date" : "Dátum dokončenia",
    "Sort by completed date." : "Zoradiť podľa dátumu dokončenia.",
    "Priority" : "Priorita",
    "Sort by priority and summary." : "Zoradiť podľa priority a súhrnu.",
    "Alphabetically" : "Abecedne",
    "Sort by summary and priority." : "Zoradiť podľa súhrnu a priority.",
    "Manually" : "Manuálne",
    "Sort by manual order." : "Zoradiť manuálne.",
    "{complete} % completed" : "{complete} % hotovo",
    "Task has hidden subtasks" : "Úloha ma skryté podúlohy",
    "Task is pinned" : "Úloha je pripnutá",
    "Task has a note" : "Úloha má poznámku",
    "Add subtask" : "Pridať čiastkovú úlohu",
    "Show subtasks" : "Zobraziť čiastkové úlohy",
    "Hide subtasks" : "Skryť čiastkové úlohy",
    "Show closed subtasks" : "Zobraziť uzavreté čiastkové úlohy",
    "Hide closed subtasks" : "Skryť uzavreté čiastkové úlohy",
    "Delete task" : "Odstrániť úlohu",
    "Toggle starred" : "Prepnúť na ohviedzičkované",
    "[Yesterday]" : "[Včera]",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zajtra]",
    "[Completed yesterday]" : "[Dokončené včera]",
    "[Completed today]" : "[Dokončené dnes]",
    "[Completed tomorrow]" : "[Dokončené zajtra]",
    "[Yesterday at] LT" : "[Včera o] LT",
    "[Today at] LT" : "[Dnes o] LT",
    "[Tomorrow at] LT" : "[Zajtra o] LT",
    "L [at] LT" : "L [o] LT",
    "[Completed yesterday at] LT" : "[Dokončené včera o] LT",
    "[Completed today at] LT" : "[Dokončené dnes o] LT",
    "[Completed tomorrow at] LT" : "[Dokončené zajtra o] LT",
    "[Completed] L [at] LT" : "[Dokončené] L [o] LT",
    "Add a subtask to \"{task}\"…" : "Pridať čiastkovú úlohu do  \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Odstránenie úlohy o {countdown} sekundu","Odstránenie úlohy o {countdown} sekundy","Odstránenie úlohy o {countdown} sekundy","Odstránenie úlohy o {countdown} sekúnd"],
    "Task is cancelled" : "Úloha je zrušená",
    "Task is completed" : "Úloha je dokončená",
    "Task is read-only" : "Úloha je iba na čítanie",
    "Task is not completed" : "Úloha nie je dokončená",
    "Create a new task" : "Vytvoriť novú úlohu",
    "Task summary" : "Zhrnutie úlohy",
    "Create task" : "Vytvoriť úlohu",
    "Creating the new task…" : "Vytváram novú úlohu...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" bola pridaná do \"{calendar}\"",
    "Open task" : "Otvoriť úlohu",
    "Close" : "Zatvoriť",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
    "Tomorrow" : "Zajtra",
    "Add List…" : "Pridať zoznam",
    "New List" : "Nový zoznam",
    "All day" : "Celý deň",
    "Unpin" : "Odopnúť",
    "Pin" : "Pripnúť",
    "Show in Calendar" : "Zobraziť v Kalendári",
    "Edit title" : "Upraviť názov",
    "Details" : "Podrobnosti",
    "Select a classification" : "Vybrať klasifikáciu",
    "Select a status" : "Vybrať status",
    "Select tags" : "Vyberte štítky",
    "Notes" : "Poznámky",
    "Reminders" : "Pripomienky",
    "Repeat" : "Opakovať",
    "When shared show full event" : "Pri zdieľaní zobraziť udalosť úplne",
    "When shared show only busy" : "Pri zdieľaní zobraziť len zaneprázdnený",
    "When shared hide this event" : "Pri zdieľaní skryť udalosť",
    "[Completed] L" : "[Dokončené] L",
    "[Completed last] dddd [at] LT" : "[Posledné dokončené] dddd [o] LT",
    "[Completed] dddd [at] LT" : "[Dokončené] dddd [o] LT",
    "[Last modified yesterday at] LT" : "[Posledná zmena včera o] LT",
    "[Last modified today at] LT" : "[Posledná zmena dnes o] LT",
    "[Last modified] L" : "[Naposledy zmenené] L",
    "[Last modified last] dddd [at] LT" : "[Posledné naposledy zmenené] dddd [o] LT",
    "[Last modified] dddd [at] LT" : "[Naposledy zmenené] dddd [o] LT",
    "[Created yesterday at] LT" : "[Vytvorené včera o] LT",
    "[Created today at] LT" : "[Vytvorené dnes o] LT",
    "[Created] L" : "[Vytvorené] L",
    "[Created last] dddd [at] LT" : "[Posledné vytvorené] dddd [o] LT",
    "[Created] dddd [at] LT" : "[Vytvorené] dddd [o] LT",
    "Needs action" : "Vyžaduje akciu",
    "In process" : "V priebehu",
    "Canceled" : "Zrušené",
    "Clear status" : "Vyčistiť stav",
    "Loading task from server." : "Nahrať úlohu zo servera.",
    "Task not found!" : "Úloha nebola nájdená!",
    "[Starts today]" : "[Začína dnes]",
    "[Starts tomorrow]" : "[Začína zajtra]",
    "[Starts on] LL" : "[Začína] LL",
    "[Started yesterday]" : "[Začalo včera]",
    "[Started on] LL" : "[Začalo] LL",
    "[Started today at] LT" : "[Začalo dnes o] LT",
    "[Starts today at] LT" : "[Začne dnes o] LT",
    "[Starts tomorrow at] LT" : "[Začne zajtra o] LT",
    "[Starts on] LL [at] LT" : "[Začne] LL [o] LT",
    "[Started yesterday at] LT" : "[Začalo včera o] LT",
    "[Started on] LL [at] LT" : "[Začalo] LL [o] LT",
    "Set start date" : "Nastaviť dátum začatia",
    "[Due today]" : "[Termín ukončenia dnes]",
    "[Due tomorrow]" : "[Termín ukončenia zajtra]",
    "[Due on] LL" : "[Termín ukončenia] LL",
    "[Was due yesterday]" : "[Termín ukončenia bol včera]",
    "[Was due on] LL" : "[Termín ukončenia bol] LL",
    "[Was due today at] LT" : "[Termín ukončenia bol dnes o] LT",
    "[Due today at] LT" : "[Termín ukončenia dnes o] LT",
    "[Due tomorrow at] LT" : "[Termín ukončenia zajtra o] LT",
    "[Due on] LL [at] LT" : "[Termín ukončenia] LL [o] LT",
    "[Was due yesterday at] LT" : "[Termín ukončenia bol včera o] LT",
    "[Was due on] LL [at] LT" : "[Termín ukončenia bol] LL [o] LT",
    "Set due date" : "Nastaviť do dátumu",
    "Priority {priority}: low" : "Priorita {priority}: nízka",
    "Priority {priority}: medium" : "Priorita {priority}: stredná",
    "Priority {priority}: high" : "Priorita {priority}: vysoká",
    "No priority assigned" : "Nepridelená žiadna priorita",
    "{percent} % completed" : "{percent} % hotovo",
    "No upcoming tasks" : "Žiadne nadchádzajúce úlohy",
    "upcoming tasks" : "nadchádzajúce úlohy",
    "No tasks today" : "Dnes žiadne úlohy",
    "Mark as done" : "Označiť ako dokončené",
    "No due date assigned" : "Nie je priradený žiadny dátum platnosti",
    "[Due yesterday]" : "[Termín včera]",
    "[Due] L" : "[Termín] L",
    "[Due yesterday at] LT" : "[Termín včera o] LT",
    "[Due] L [at] LT" : "[Termín] L [o] LT",
    "Successfully created the task." : "Úloha bola úspešne vytvorená.",
    "Could not delete the task." : "Nepodarilo sa zmazať úlohu.",
    "Synchronizing to the server." : "Synchronizácia so serverom.",
    "Task successfully saved to server." : "Úloha úspešne uložená na server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nepodarilo sa upraviť úlohu, pretože bola zmenená na serveri. Kliknite na obnovenie, lokálne vykonané zmeny budú zahodené.",
    "Could not update the task." : "Nepodarilo sa upraviť úlohu.",
    "Successfully updated the task." : "Úloha bola úspešne upravená.",
    "Task successfully moved to new calendar." : "Úloha úspešne presunutá do nového kalendára.",
    "An error occurred" : "Vyskytla sa chyba",
    "Create a task" : "Vytvoriť úlohu",
    "Message from {author} in {conversationName}" : "Správa od {author} v {conversationName}"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
