OC.L10N.register(
    "tasks",
    {
    "Important" : "Vacib",
    "Today" : "Bu gün",
    "Week" : "Həftə",
    "All" : "Hamısı",
    "Current" : "Mövcud",
    "Completed" : "Bitmişdir",
    "Tasks" : "Tapşırıqlar",
    "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
    "Hidden" : "Gizli",
    "Visible" : "Görünən",
    "Automatic" : "Avtomatik",
    "Edit" : "Dəyişiklik et",
    "Delete" : "Sil",
    "Unshare" : "Paylaşımı durdur",
    "Cancel" : "Dayandır",
    "Save" : "Saxla",
    "An empty name is not allowed." : "Boş ada izin verilmir.",
    "_%n Completed Task_::_%n Completed Tasks_" : ["\"%s\" Bitmiş Tapşırıqlar","Completed Tasks"],
    "Tomorrow" : "Sabah",
    "New List" : "Yeni Siyahı",
    "Task not found!" : "Tapşırıq tapılmadı!",
    "Set start date" : "Başlanğıc tarixini işə sal",
    "Set due date" : "Vaxtı təyin et"
},
"nplurals=2; plural=(n != 1);");
