OC.L10N.register(
    "tasks",
    {
    "Important" : "Важливий",
    "Today" : "Сьогодні",
    "Week" : "Тиждень",
    "All" : "Всі",
    "Current" : "Поточні",
    "Completed" : "Завершені",
    "Tasks" : "Завдання",
    "The Tasks app for Nextcloud" : "Застосунок Завдання (Tasks) для Nextcloud",
    "Default list" : "Типовий список",
    "Visibility of Smart Collections" : "Видимість Smart-колекції",
    "Hidden" : "Прихований",
    "Visible" : "Видимий",
    "Automatic" : "Автоматично",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "No users or groups" : "Жодного користувача або групм",
    "Unshare with {displayName}" : "Припинити поширення з {displayName}",
    "Unable to delete the share." : "Неможливо вилучити спільний елемент.",
    "Unable to change permissions." : "Неможливо змінити права доступу.",
    "Edit" : "Редагувати",
    "Copy private link" : "Копіювати приватне посилання",
    "Copied" : "Скопійовано",
    "Delete" : "Вилучити",
    "Unshare" : "Закрити доступ",
    "Cancel" : "Скасувати",
    "Save" : "Зберегти",
    "Calendar link copied to clipboard." : "Посилання на календар зкопійовано до буфера обміну",
    "Calendar link could not be copied to clipboard." : "Посилання на календар не може бути зкопійоване до буфера обміну",
    "An empty name is not allowed." : "Порожнє поле не допускається.",
    "An error occurred, unable to delete the calendar." : "Помилка: неможливо вилучити календар.",
    "No errors" : "Без помилок",
    "Open your browser console for more details" : "Відкрийте консоль браузера для докладної інформації",
    "Change sort order" : "Зміна порядку сортування",
    "Relevance" : "Відповідність",
    "Start date" : "Дата початку",
    "Due date" : "Термін виконання",
    "Created date" : "Дата створення",
    "Last modified" : "Останні зміни",
    "Priority" : "Перевага",
    "Alphabetically" : "За алфавітом",
    "Manually" : "Вручну",
    "Add subtask" : "Додати підзавдання",
    "Delete task" : "Вилучити завдання",
    "Task is completed" : "Завдання виконано",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань","%n завершених завдань"],
    "Tomorrow" : "Завтра",
    "Add List…" : "Додати список",
    "New List" : "Новий список",
    "All day" : "Всі дні",
    "When shared show full event" : "При поширенні показувати подію повністю",
    "When shared show only busy" : "При поширенні показувати тільки зайнятий час",
    "When shared hide this event" : "При поширенні приховати цю подію",
    "Canceled" : "Скасовано",
    "Task not found!" : "Завдання не знайдене!",
    "Set start date" : "Встановити дату початку",
    "Set due date" : "Встановіть термін",
    "An error occurred" : "Виникла помилка"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
