OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Közelgő feladatok",
    "Important" : "Fontos",
    "Today" : "Ma",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "Tasks" : "Feladatok",
    "The Tasks app for Nextcloud" : "Feladatok alkalmazás a Nextcloudhoz",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Engedélyezés esetén egy új Feladatok menü jelenik meg a Nextcloud alkalmazásmenüben. A menüből feladatokat tud létrehozni és törölni, szerkesztheti a címeiket, a leírásokat, a kezdő dátumokat és a határidőket. emlékeztetőket állíthat be. megjelölheti fontosnak és jegyzeteket tud hozzájuk fűzni. A feladatok megoszthatók a felhasználók között. A feladatok szinkronizálhatók CalDav használatával (minden egyes feladatlista hozzá van rendelve egy Nextcloud-naptárhoz, és szinkronizálható egy helyi klienssel: Thunderbird, Evolution, KDE Kontakt, iCal… – csak hozzá kell adnia távoli naptárként. A letöltés gomb segítségével minden egyes naptári feladat letölthető ICS-fájlként.",
    "Default list" : "Alapértelmezett lista",
    "Visibility of Smart Collections" : "Az okos gyűjtemények láthatósága",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Automatikus",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok",
    "Can edit" : "Szerkesztheti",
    "Unshare with {displayName}" : "Megosztás megszüntetése a következővel: {displayName}",
    "Unable to delete the share." : "Nem lehet törölni a megosztást.",
    "Unable to change permissions." : "Nem lehet megváltoztatni a jogosultságokat",
    "Edit" : "Szerkesztés",
    "Copy private link" : "Személyes hivatkozás másolása",
    "Copied" : "Másolva",
    "Cannot copy" : "Nem lehet másolni",
    "Delete" : "Törlés",
    "Unshare" : "Megosztás visszavonása",
    "Cancel" : "Mégse",
    "Save" : "Mentés",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ez törölni fogja a(z) „{calendar}” naptárat és az összes kapcsolódó eseményt és feladatot.",
    "This will unshare the calendar \"{calendar}\"." : "Ez megszünteti a(z) „{calendar}” naptár megosztását.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ez törölni fogja a(z) „{list}” listát és az összes kapcsolódó feladatot.",
    "This will unshare the list \"{list}\"." : "Ez megszünteti a(z) „{list}” lista megosztását.",
    "Calendar link copied to clipboard." : "Naptárhivatkozás a vágólapra másolva.",
    "List link copied to clipboard." : "Listahivatkozás a vágólapra másolva.",
    "Calendar link could not be copied to clipboard." : "A naptárhivatkozást nem sikerült a vágólapra másolni.",
    "List link could not be copied to clipboard." : "A listahivatkozást nem sikerült a vágólapra másolni.",
    "The name \"{calendar}\" is already used." : "A(z) „[calendar]” név már foglalt.",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "An error occurred, unable to delete the calendar." : "Hiba történt, a naptárat nem lehet törölni.",
    "An error occurred, unable to delete the list." : "Hiba történt, a listát nem lehet törölni.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["A naptár törlése {countdown} másodperc múlva","A naptár törlése {countdown} másodperc múlva"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["A naptár megosztásának megszüntetése {countdown} másodperc múlva","A naptár megosztásának megszüntetése {countdown} másodperc múlva"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["A lista törlése {countdown} másodperc múlva","A lista törlése {countdown} másodperc múlva"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["A lista megosztásának megszüntetése {countdown} másodperc múlva","A lista megosztásának megszüntetése {countdown} másodperc múlva"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Megosztva {num} entitással","Megosztva {num} entitással"],
    "Trash bin" : "Kuka",
    "Loading deleted calendars, tasks and events." : "Törölt naptárak, feladatok és események betöltése.",
    "You do not have any deleted calendars, tasks or events." : "Nincsenek törölt naptárak, feladatok vagy események",
    "Name" : "Név",
    "Deleted" : "Törölve",
    "Restore" : "Helyreállítás",
    "Delete permanently" : "Végleges törlés",
    "Empty trash bin" : "Kuka ürítése",
    "Untitled task" : "Névtelen feladat",
    "Untitled event" : "Névtelen esemény",
    "Untitled journal" : "Névtelen napló",
    "Untitled item" : "Névtelen elem",
    "Unknown calendar" : "Ismeretlen naptár",
    "Could not load deleted calendars and objects" : "A törölt naptárak és objektumok nem tölthetők be",
    "Could not delete calendar or event" : "A naptár vagy esemény nem törölhető",
    "Could not restore calendar or event" : "A naptár vagy esemény nem állítható helyre",
    "Do you really want to empty the trash bin?" : "Biztos, hogy üríti a kukát?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["A kukában lévő elemek {numDays} nap után törölve lesznek","A kukában lévő elemek {numDays} nap után törölve lesznek"],
    "Select a calendar" : "Válasszon naptárat",
    "No calendar matches the search." : "Nincs a keresésnek megfelelő naptár",
    "Set date" : "Dátum beállítása",
    "Set time" : "Idő beállítása",
    "Delete date" : "Dátum törlése",
    "Click here to add a note." : "Kattintson ide egy jegyzet hozzáadásához",
    "Set value" : "Érték beállítása",
    "Delete value" : "Érték törlése",
    "Add this as a new tag" : "Hozzáadás új címkeként",
    "No tag available. Create one!" : "Nincs elérhető címke. Hozzon létre egyet!",
    "Delete all completed tasks." : "Összes befejezett feladat törlése.",
    "Delete completed tasks." : "Befejezett feladatok törlése.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Az összes befejezett feladatot törölte a(z) „{calendar}” naptárból.",
    "No errors" : "Nincsenek hibák",
    "Open your browser console for more details" : "Nyissa meg a böngészőkonzolt a további részletekért",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ez töröl {taskCount} befejezett feladatot (és annak a részfeladatait) a(z) „{calendar}” naptárból.","Ez töröl {taskCount} befejezett feladatot (és azok részfeladatait) a(z) „{calendar}” naptárból."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failCount} feladatot nem sikerült törölni.","{failCount} feladatot nem sikerült törölni."],
    "Add an important task to \"{calendar}\"…" : "Fontos feladat hozzáadása a(z) „{calendar}” naptárhoz…",
    "Add a task due today to \"{calendar}\"…" : "Egy ma esedékes feladat hozzáadása a(z) „{calendar}” naptárhoz…",
    "Add a current task to \"{calendar}\"…" : "Egy aktuális feladat hozzáadása a(z) „{calendar}” naptárhoz…",
    "Add a task to \"{calendar}\"…" : "Feladat hozzáadása a(z) „{calendar}” naptárhoz…",
    "Load all completed tasks." : "Összes befejezett feladat betöltése.",
    "Change sort order" : "Rendezési sorrend váltása",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Rendezés befejezett állapot, határidő, prioritás, kezdési dátum és összefoglalás szerint.",
    "Start date" : "Kezdési dátum",
    "Sort by start date and summary." : "Rendezés a kezdési dátum és az összefoglaló szerint.",
    "Due date" : "Határidő",
    "Sort by due date and summary." : "Rendezés a határidő és az összegzés szerint.",
    "Created date" : "Létrehozás dátuma",
    "Sort by created date and summary." : "Rendezés a létrehozás dátuma és az összefoglaló szerint.",
    "Last modified" : "Utoljára módosítva",
    "Sort by last-modified date and summary." : "Rendezés az utolsó módosítás dátuma és az összefoglaló szerint.",
    "Completed date" : "Teljesítési idő",
    "Sort by completed date." : "Rendezés a befejezési dátum szerint.",
    "Priority" : "Prioritás",
    "Sort by priority and summary." : "Rendezés a prioritás és az összefoglaló szerint.",
    "Alphabetically" : "Betűrendben",
    "Sort by summary and priority." : "Rendezés az összefoglaló és a prioritás szerint.",
    "Manually" : "Kézileg",
    "Sort by manual order." : "Rendezés kézi sorrend szerint.",
    "{complete} % completed" : "{complete}% kész",
    "Task has hidden subtasks" : "A feladatnak rejtett részfeladatai vannak",
    "Task is pinned" : "A feladat rögzített",
    "Task has a note" : "A feladathoz jegyzet tartozik",
    "Add subtask" : "Részfeladat hozzáadása",
    "Show subtasks" : "Részfeladatok megjelenítése",
    "Hide subtasks" : "Részfeladatok elrejtése",
    "Show closed subtasks" : "Lezárt részfeladatok megjelenítése",
    "Hide closed subtasks" : "Lezárt részfeladatok megjelenítése",
    "Delete task" : "Feladat törlése",
    "Toggle starred" : "Csillagozás be/ki",
    "[Yesterday]" : "[Tegnap]",
    "[Today]" : "[Ma]",
    "[Tomorrow]" : "[Holnap]",
    "[Completed yesterday]" : "[Tegnap elkészült]",
    "[Completed today]" : "[Ma elkészült]",
    "[Completed tomorrow]" : "[Holnap elkészül]",
    "[Yesterday at] LT" : "[Tegnap] LT",
    "[Today at] LT" : "[Ma] LT",
    "[Tomorrow at] LT" : "[Holnap] LT",
    "L [at] LT" : "L LT",
    "[Completed yesterday at] LT" : "[Tegnap elkészült] LT",
    "[Completed today at] LT" : "[Ma elkészült] LT",
    "[Completed tomorrow at] LT" : "[Holnap elkészül] LT",
    "[Completed] L [at] LT" : "L [elkészült] [ekkor:] LT",
    "Add a subtask to \"{task}\"…" : "Részfeladat hozzáadása a(z) „{task}” elemhez…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["A feladat törlése {countdown} másodperc múlva","A feladat törlése {countdown} másodperc múlva"],
    "Task is completed" : "Feladat elvégezve",
    "Create a new task" : "Új feladat létrehozása",
    "Task summary" : "Feladat összegzése",
    "Create task" : "Feladat létrehozása",
    "Creating the new task…" : "Új feladat létrehozása…",
    "\"{task}\" was added to \"{calendar}\"" : "A(z) „{task}” hozzáadva a(z) „{calendar}” naptárhoz",
    "Open task" : "Feladat megnyitása",
    "Close" : "Bezárás",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Tomorrow" : "Holnap",
    "Add List…" : "Lista hozzáadása…",
    "New List" : "Új lista",
    "All day" : "Egész napos",
    "Unpin" : "Rögzítés feloldása",
    "Pin" : "Rögzítés",
    "Show in Calendar" : "Megjelenítés a Naptárban",
    "Edit title" : "Cím szerkesztése",
    "Details" : "Részletek",
    "Select a classification" : "Besorolás kiválasztása",
    "Select a status" : "Állapot kiválasztása",
    "Select tags" : "Címkék kiválasztása",
    "Notes" : "Jegyzetek",
    "Reminders" : "Emlékeztetők",
    "Repeat" : "Ismétlés",
    "When shared show full event" : "Megosztáskor a teljes esemény megjelenítése.",
    "When shared show only busy" : "Megosztáskor csak a foglaltság megjelenítése",
    "When shared hide this event" : "Megosztáskor az esemény elrejtése.",
    "[Completed] L" : "[Elkészült:] L",
    "[Completed last] dddd [at] LT" : "[Elkészült: múlt] dddd[,] LT",
    "[Completed] dddd [at] LT" : "[Elkészült:] dddd[,] LT",
    "[Last modified yesterday at] LT" : "[Utoljára módosítva: tegnap] LT",
    "[Last modified today at] LT" : "[Utoljára módosítva: ma] LT",
    "[Last modified] L" : "[Utoljára módosítva:] L",
    "[Last modified last] dddd [at] LT" : "[Utoljára módosítva: múlt] dddd[,] LT",
    "[Last modified] dddd [at] LT" : "[Utoljára módosítva:] dddd[,] LT",
    "[Created yesterday at] LT" : "[Létrehozva: tegnap] LT",
    "[Created today at] LT" : "[Létrehozva: ma] LT",
    "[Created] L" : "[Létrehozva:] L",
    "[Created last] dddd [at] LT" : "[Létrehozva: múlt] dddd[,] LT",
    "[Created] dddd [at] LT" : "[Létrehozva:] dddd[,] LT",
    "Needs action" : "Beavatkozás szükséges",
    "In process" : "Folyamatban",
    "Canceled" : "Megszakítva",
    "Clear status" : "Állapot törlése",
    "Loading task from server." : "Feladat betöltése a kiszolgálóról.",
    "Task not found!" : "A feladat nem található.",
    "[Starts today]" : "[Ma kezdődik]",
    "[Starts tomorrow]" : "[Holnap kezdődik]",
    "[Starts on] LL" : "[Kezdés:] LL",
    "[Started yesterday]" : "[Tegnap elkezdődött]",
    "[Started on] LL" : "[Elkezdve:] LL",
    "[Started today at] LT" : "[Ma elkezdődött:] LT",
    "[Starts today at] LT" : "[Ma kezdődik:] LT",
    "[Starts tomorrow at] LT" : "[Holnap kezdődik:] LT",
    "[Starts on] LL [at] LT" : "[Kezdés:] LL LT",
    "[Started yesterday at] LT" : "[Tegnap kezdődött:] LT",
    "[Started on] LL [at] LT" : "[Kezdés:] LL LT",
    "Set start date" : "Kezdési dátum beállítása",
    "[Due today]" : "[Ma esedékes]",
    "[Due tomorrow]" : "[Holnap esedékes]",
    "[Due on] LL" : "[Határidő:] LL",
    "[Was due yesterday]" : "[Tegnap volt esedékes]",
    "[Was due on] LL" : "[Esedékessé vált:] LL",
    "[Was due today at] LT" : "[Ma volt esedékes:] LT",
    "[Due today at] LT" : "[Ma esedékes:] LT",
    "[Due tomorrow at] LT" : "[Holnap esedékes:] LT",
    "[Due on] LL [at] LT" : "[Határidő:] LL LT",
    "[Was due yesterday at] LT" : "[Tegnap volt esedékes:] LT",
    "[Was due on] LL [at] LT" : "[Esedékessé vált:] LL LT",
    "Set due date" : "Határidő beállítása",
    "Priority {priority}: low" : "Prioritás: {priority} – alacsony",
    "Priority {priority}: medium" : "Prioritás: {priority} – közepes",
    "Priority {priority}: high" : "Prioritás: {priority} – magas",
    "No priority assigned" : "Nincs prioritás beállítva",
    "{percent} % completed" : "{percent}% kész",
    "No upcoming tasks" : "Nincsenek közelgő feladatok",
    "upcoming tasks" : "közelgő feladatok",
    "No tasks today" : "Ma nincsenek feladatok",
    "Mark as done" : "Megjelölés készként",
    "No due date assigned" : "Nincs határidő beállítva",
    "[Due yesterday]" : "[Tegnap volt esedékes]",
    "[Due] L" : "[Határidő:] LL",
    "[Due yesterday at] LT" : "[Tegnap volt esedékes:] LT",
    "[Due] L [at] LT" : "[Határidő:] L[,] LT",
    "Successfully created the task." : "Sikeresen létrehozta a feladatot.",
    "Could not delete the task." : "Nem sikerült törölni a feladatot.",
    "Synchronizing to the server." : "Szinkronizálás a kiszolgálóval.",
    "Task successfully saved to server." : "Feladat sikeresen mentve a kiszolgálóra.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nem sikerült frissíteni a feladatot, mert időközben megváltozott a kiszolgálón. Kattintson a frissítéshez. A helyi módosításokat el lesznek vetve.",
    "Could not update the task." : "Nem sikerült frissíteni a feladatot.",
    "Successfully updated the task." : "A feladat frissítése sikeresen megtörtént.",
    "Task successfully moved to new calendar." : "A feladat sikeresen átkerült az új naptárba.",
    "An error occurred" : "Hiba történt",
    "Create a task" : "Feladat létrehozása",
    "Message from {author} in {conversationName}" : "Üzenet a(z) {conversationName} beszélgetésben tőle: {author}"
},
"nplurals=2; plural=(n != 1);");
