OC.L10N.register(
    "tasks",
    {
    "Important" : "Tähtis",
    "Today" : "Täna",
    "Week" : "Nädal",
    "All" : "Kõik",
    "Current" : "Praegune",
    "Completed" : "Lõpetatud",
    "Tasks" : "Ülesanded",
    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
    "Hidden" : "Peidetud",
    "Visible" : "Nähtav",
    "Automatic" : "Automaatne",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
    "Edit" : "Muuda",
    "Copy private link" : "Kopeeri privaatne link",
    "Delete" : "Kustuta",
    "Unshare" : "Lõpeta jagamine",
    "Cancel" : "Loobu",
    "Save" : "Salvesta",
    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
    "Change sort order" : "Muuda sorteerimisjärjekorda",
    "Start date" : "Alguskuupäev",
    "Due date" : "Tähtaeg",
    "Last modified" : "Viimati muudetud",
    "Priority" : "Prioriteet",
    "Alphabetically" : "Tähestikujärjekorras",
    "Manually" : "Käsitsi",
    "Task is completed" : "Ülesanne on tehtud",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lõpetatud ülesanne","%n lõpetatud ülesannet"],
    "Tomorrow" : "Homme",
    "New List" : "Uus nimekiri",
    "All day" : "Kogu päev",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Task not found!" : "Ülesannet ei leitud!",
    "Set start date" : "Määra alguse kuupäev",
    "Set due date" : "Määra tähtaeg",
    "An error occurred" : "Tekkis tõrge"
},
"nplurals=2; plural=(n != 1);");
