OC.L10N.register(
    "tasks",
    {
    "Today" : "өнөөдөр",
    "Week" : "Долоо хоног",
    "All" : "бүх",
    "Current" : "Одоогийн",
    "Completed" : "Гүйцэтгэгдсэн",
    "Hidden" : "Далд",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "Edit" : "засварлах",
    "Delete" : "устгах",
    "Unshare" : "Түгээлтийг зогсоох",
    "Cancel" : "цуцлах",
    "Save" : "хадгалах",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Tomorrow" : "маргааш",
    "New List" : "шинэ жагсаалт",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу"
},
"nplurals=2; plural=(n != 1);");
