OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Güei",
    "Week" : "Selmana",
    "All" : "Toos",
    "Current" : "Actual",
    "Completed" : "Completáu",
    "Tasks" : "Xeres",
    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
    "Hidden" : "Anubríu",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "Edit" : "Editar",
    "Delete" : "Desaniciar",
    "Unshare" : "Dexar de compartir",
    "Cancel" : "Encaboxar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "Nun s'almite un nome baleru",
    "Change sort order" : "Camudar orde d'ordenación",
    "Priority" : "Prioridá",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "A mano",
    "Task is completed" : "La xera ta completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Tomorrow" : "Mañana",
    "New List" : "Nueva Llista",
    "All day" : "Tol día",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Task not found!" : "¡Xera non atopada!",
    "Set start date" : "Afitar la fecha d'entamu",
    "Set due date" : "Afitar la data de caducidá"
},
"nplurals=2; plural=(n != 1);");
