OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Anstehende Aufgaben",
    "Important" : "Wichtig",
    "Today" : "Heute",
    "Week" : "Woche",
    "All" : "Alle",
    "Current" : "Aktuell",
    "Completed" : "Fertiggestellt",
    "Tasks" : "Aufgaben",
    "The Tasks app for Nextcloud" : "Die Aufgabenverwaltungs-App für Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Nach der Aktivierung erscheint ein neues Aufgabenmenü in Ihrem Nextcloud-Applikationsmenü. Von dort aus können Sie Aufgaben hinzufügen und löschen, deren Titel, Beschreibung, Start- und Fälligkeitsdaten bearbeiten und als wichtig markieren. Aufgaben können zwischen den Benutzern geteilt werden. Aufgaben können mit CalDav synchronisiert werden (jede Aufgabenliste ist mit einem Nextcloud-Kalender verknüpft, um sie mit Ihrem lokalen Client zu synchronisieren: Thunderbird, Evolution, KDE Kontact, iCal … - fügen Sie einfach den Kalender als entfernten Kalender in Ihrem Client hinzu). Sie können Ihre Aufgaben als ICS-Dateien über den Download-Knopf für jeden Kalender herunterladen.",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Sichtbarkeit der intelligenten Sammlungen",
    "Hidden" : "Verborgen",
    "Visible" : "Sichtbar",
    "Automatic" : "Automatisch",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "Can edit" : "Kann bearbeiten",
    "Unshare with {displayName}" : "Mit {displayName} nicht mehr teilen",
    "Unable to delete the share." : "Freigabe kann nicht gelöscht werden.",
    "Unable to change permissions." : "Berechtigungen können nicht geändert werden.",
    "Edit" : "Bearbeiten",
    "Copy private link" : "Privaten Link kopieren",
    "Copied" : "Kopiert",
    "Cannot copy" : "Kann nicht kopieren",
    "Export" : "Exportieren",
    "Delete" : "Löschen",
    "Unshare" : "Freigabe aufheben",
    "Cancel" : "Abbrechen",
    "Save" : "Speichern",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Hierdurch wird der Kalender „{calendar}“ mit allen Terminen und Aufgaben gelöscht.",
    "This will unshare the calendar \"{calendar}\"." : "Die Freigabe des Kalenders \"{calendar}\" wird aufgehoben.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Hiermit werden die Liste \"{list}\" und alle dazugehörigen Aufgaben gelöscht.",
    "This will unshare the list \"{list}\"." : "Dies wird die Listen-Freigabe \"{list}\" aufheben.",
    "Calendar link copied to clipboard." : "Kalender-Link in die Zwischenablage kopiert.",
    "List link copied to clipboard." : "Listen-Link in die Zwischenablage kopiert.",
    "Calendar link could not be copied to clipboard." : "Kalender-Link konnte nicht in die Zwischenablage kopiert werden.",
    "List link could not be copied to clipboard." : "Listen-Link konnte nicht in die Zwischenablage kopiert werden.",
    "The name \"{calendar}\" is already used." : "Der Name „{calendar}“ wird bereits verwendet.",
    "An empty name is not allowed." : "Ein leerer Name ist nicht erlaubt.",
    "An error occurred, unable to delete the calendar." : "Es ist ein Fehler aufgetreten, der Kalender konnte nicht gelöscht werden.",
    "An error occurred, unable to delete the list." : "Es ist ein Fehler aufgetreten, die Liste konnte nicht gelöscht werden.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Lösche den Kalender in {countdown} Sekunde","Lösche den Kalender in {countdown} Sekunden"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalenderfreigabe wird in {countdown} Sekunde aufgehoben","Kalenderfreigabe wird in {countdown} Sekunden aufgehoben"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Die Liste wird in {countdown} Sekunde gelöscht","Die Liste wird in {countdown} Sekunden gelöscht"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Listenfreigabe wird in {countdown} Sekunde aufgehoben","Listenfreigabe wird in {countdown} Sekunden aufgehoben"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Mit {num} Entität geteilt","Mit {num} Entitäten geteilt"],
    "Trash bin" : "Papierkorb",
    "Loading deleted calendars, tasks and events." : "Lade gelöschte Kalender, Aufgaben und Termine",
    "You do not have any deleted calendars, tasks or events." : "Sie haben keine gelöschten Kalender, Aufgaben oder Termine.",
    "Name" : "Name",
    "Deleted" : "Gelöscht",
    "Restore" : "Wiederherstellen",
    "Delete permanently" : "Endgültig löschen",
    "Empty trash bin" : "Papierkorb leeren",
    "Untitled task" : "Unbenannte Aufgabe",
    "Untitled event" : "Unbenannter Termin",
    "Untitled journal" : "Unbenanntes Journal",
    "Untitled item" : "Eintrag ohne Namen",
    "Unknown calendar" : "Unbekannter Kalender",
    "Could not load deleted calendars and objects" : "Gelöschte Kalender und Objekte konnten nicht geladen werden",
    "Could not delete calendar or event" : "Kalender oder Termin konnte nicht gelöscht werden",
    "Could not restore calendar or event" : "Kalender oder Termin konnte nicht wiederhergestellt werden",
    "Do you really want to empty the trash bin?" : "Möchten Sie wirklich den Papierkorb leeren?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elemente im Papierkorb werden nach {numDays} Tag gelöscht","Elemente im Papierkorb werden nach {numDays} Tagen gelöscht"],
    "Select a calendar" : "Kalender auswählen",
    "No calendar matches the search." : "Kein Kalender entspricht der Suche.",
    "Set date" : "Datum setzen",
    "Set time" : "Zeit setzen",
    "Delete date" : "Datum löschen",
    "Click here to add a note." : "Hier klicken, um eine Notiz hinzuzufügen.",
    "Set value" : "Wert setzen",
    "Delete value" : "Wert löschen",
    "Add this as a new tag" : "Dies als neues Schlagwort hinzufügen",
    "No tag available. Create one!" : "Kein Schlagwort verfügbar. Erstellen Sie eines!",
    "Delete all completed tasks." : "Alle abgeschlossenen Aufgaben löschen.",
    "Delete completed tasks." : "Abgeschlossene Aufgaben löschen.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Alle abgeschlossenen Aufgaben aus dem Kalender \"{calendar}\" gelöscht.",
    "No errors" : "Keine Fehler",
    "Open your browser console for more details" : "Browser-Konsole für weitere Einzelheiten öffnen",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Hiermit wird {taskCount} abgeschlossene Aufgabe und ihre Unteraufgaben aus dem Kalender \"{calendar}\" gelöscht.","Hiermit werden {taskCount} abgeschlossene Aufgaben und deren Unteraufgaben aus dem Kalender \"{calendar}\" gelöscht."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} Aufgabe konnte nicht gelöscht werden.","{failedCount} Aufgaben konnten nicht gelöscht werden."],
    "Add an important task to \"{calendar}\"…" : "Eine wichtige Aufgabe zu \"{calendar}\" hinzufügen…",
    "Add a task due today to \"{calendar}\"…" : "Eine heute fällige Aufgabe zu \"{calendar}\" hinzufügen…",
    "Add a current task to \"{calendar}\"…" : "Eine aktuelle Aufgabe zu \"{calendar}\" hinzufügen…",
    "Add a task to \"{calendar}\"…" : "Eine Aufgabe zu \"{calendar}\" hinzufügen…",
    "Load all completed tasks." : "Alle abgeschlossenen Aufgaben laden.",
    "Change sort order" : "Sortierreihenfolge ändern",
    "Relevance" : "Wichtigkeit",
    "Sort by completed state, due date, priority, start date and summary." : "Sortieren nach Abgeschlossen-Status, Fälligkeitsdatum, Priorität, Startdatum und Zusammenfassung.",
    "Start date" : "Startdatum",
    "Sort by start date and summary." : "Nach Startdatum und Zusammenfassung sortieren.",
    "Due date" : "Fälligkeitsdatum",
    "Sort by due date and summary." : "Nach Fälligkeitsdatum und Zusammenfassung sortieren.",
    "Created date" : "Erstellungsdatum",
    "Sort by created date and summary." : "Nach Erstellungsdatum und Zusammenfassung sortieren.",
    "Last modified" : "Zuletzt geändert",
    "Sort by last-modified date and summary." : "Nach letztem Änderungsdatum und Zusammenfassung sortieren.",
    "Completed date" : "Erledigungsdatum",
    "Sort by completed date." : "Sortiere nach Erledigungsdatum.",
    "Priority" : "Priorität",
    "Sort by priority and summary." : "Nach Priorität und Zusammenfassung sortieren.",
    "Alphabetically" : "Alphabetisch",
    "Sort by summary and priority." : "Nach Zusammenfassung und Priorität sortieren.",
    "Manually" : "Manuell",
    "Sort by manual order." : "Nach manueller Reihenfolge sortieren.",
    "{complete} % completed" : "{complete}% fertiggestellt",
    "Task has hidden subtasks" : "Aufgabe hat ausgeblendete Teilaufgaben",
    "Task is pinned" : "Aufgabe ist angeheftet",
    "Task has a note" : "Aufgabe hat eine Notiz",
    "Add subtask" : "Teilaufgabe hinzufügen",
    "Show subtasks" : "Teilaufgabe anzeigen",
    "Hide subtasks" : "Teilaufgaben ausblenden",
    "Show closed subtasks" : "Geschlossene Teilaufgaben anzeigen",
    "Hide closed subtasks" : "Geschlossene Teilaufgaben ausblenden",
    "Delete task" : "Aufgabe löschen",
    "Toggle starred" : "Favorisiert umschalten",
    "[Yesterday]" : "[Gestern]",
    "[Today]" : "[Heute]",
    "[Tomorrow]" : "[Morgen]",
    "[Completed yesterday]" : "[Gestern erledigt]",
    "[Completed today]" : "[Heute erledigt]",
    "[Completed tomorrow]" : "[Morgen erledigt]",
    "[Yesterday at] LT" : "[Gestern um] LT",
    "[Today at] LT" : "[Heute um] LT",
    "[Tomorrow at] LT" : "[Morgen um] LT",
    "L [at] LT" : "L [um] LT",
    "[Completed yesterday at] LT" : "[Gestern erledigt um] LT",
    "[Completed today at] LT" : "[Heute erledigt um] LT",
    "[Completed tomorrow at] LT" : "[Morgen erledigt um] LT",
    "[Completed] L [at] LT" : "L [erledigt] [um] LT",
    "Add a subtask to \"{task}\"…" : "Eine Unteraufgabe zu \"{task}\" hinzufügen…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Lösche die Aufgabe in {countdown} Sekunde","Lösche die Aufgabe in {countdown} Sekunden"],
    "Task is cancelled" : "Aufgabe abgebrochen",
    "Task is completed" : "Aufgabe fertiggestellt",
    "Task is read-only" : "Aufgabe ist schreibgeschützt",
    "Task is not completed" : "Aufgabe ist nicht fertiggestellt",
    "Create a new task" : "Neue Aufgabe erstellen",
    "Task summary" : "Aufgaben Zusammenfassung",
    "Create task" : "Aufgabe erstellen",
    "Creating the new task…" : "Neue Aufgabe wird erstellt …",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" wurde \"{calendar}\" hinzugefügt",
    "Open task" : "Aufgabe öffnen",
    "Close" : "Schließen",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n erledigte Aufgabe","%n erledigte Aufgaben"],
    "Tomorrow" : "Morgen",
    "Add List…" : "Liste hinzufügen…",
    "New List" : "Neue Liste",
    "All day" : "Ganztägig",
    "Unpin" : "Abheften",
    "Pin" : "Anheften",
    "Show in Calendar" : "Im Kalender anzeigen",
    "Edit title" : "Titel bearbeiten",
    "Details" : "Details",
    "Select a classification" : "Klassifikation wählen",
    "Select a status" : "Status auswählen",
    "Select tags" : "Schlagworte auswählen",
    "Notes" : "Notizen",
    "Reminders" : "Erinnerungen",
    "Repeat" : "Wiederholen",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "Wenn geteilt, zeige nur den Status 'beschäftigt' an",
    "When shared hide this event" : "Wenn geteilt, zeige den Termin nicht an",
    "[Completed] L" : "[Fertiggestellt] L",
    "[Completed last] dddd [at] LT" : "[Fertiggestellt am letzten] dddd [at] LT",
    "[Completed] dddd [at] LT" : "[Fertiggestellt am] dddd [um] LT",
    "[Last modified yesterday at] LT" : "[Zuletzt gestern geändert um] LT",
    "[Last modified today at] LT" : "[Zuletzt heute geändert um] LT",
    "[Last modified] L" : "[Zuletzt geändert] L",
    "[Last modified last] dddd [at] LT" : "[Zuletzt geändert am letzten] dddd [um] LT",
    "[Last modified] dddd [at] LT" : "[Zuletzt geändert am] dddd [um] LT",
    "[Created yesterday at] LT" : "[Gestern erstellt um] LT",
    "[Created today at] LT" : "[Heute erstellt um] LT",
    "[Created] L" : "[Erstellt] L",
    "[Created last] dddd [at] LT" : "[Erstellt am Letzten] dddd [um] LT",
    "[Created] dddd [at] LT" : "[Erstellt am] dddd [um] LT",
    "Needs action" : "Handlungsbedarf",
    "In process" : "In Bearbeitung",
    "Canceled" : "Abgebrochen",
    "Clear status" : "Status löschen",
    "Loading task from server." : "Aufgabe wird vom Server geladen.",
    "Task not found!" : "Aufgabe nicht gefunden!",
    "[Starts today]" : "[Beginnt heute]",
    "[Starts tomorrow]" : "[Beginnt morgen]",
    "[Starts on] LL" : "[Beginnt am] LL",
    "[Started yesterday]" : "[Begann gestern]",
    "[Started on] LL" : "[Begann am] LL",
    "[Started today at] LT" : "[Begann heute um] LT",
    "[Starts today at] LT" : "[Beginnt heute um] LT",
    "[Starts tomorrow at] LT" : "[Beginnt morgen um] LT",
    "[Starts on] LL [at] LT" : "[Beginnt am] LL [um] LT",
    "[Started yesterday at] LT" : "[Begann gestern um] LT",
    "[Started on] LL [at] LT" : "[Begann am] LL [um] LT",
    "Set start date" : "Startdatum setzen",
    "[Due today]" : "[Heute fällig]",
    "[Due tomorrow]" : "[Morgen fällig]",
    "[Due on] LL" : "[Fällig am] LL",
    "[Was due yesterday]" : "[War gestern fällig]",
    "[Was due on] LL" : "[War fällig am] LL",
    "[Was due today at] LT" : "[War heute fällig um] LT",
    "[Due today at] LT" : "[Heute fällig um] LT",
    "[Due tomorrow at] LT" : "[Morgen fällig um] LT",
    "[Due on] LL [at] LT" : "[Fällig am] LL [um] LT",
    "[Was due yesterday at] LT" : "[War gestern fällig um] LT",
    "[Was due on] LL [at] LT" : "[War fällig am] LL [um] LT",
    "Set due date" : "Ablaufdatum setzen",
    "Priority {priority}: low" : "Priorität {priority}: niedrig",
    "Priority {priority}: medium" : "Priorität {priority}: mittel",
    "Priority {priority}: high" : "Priorität {priority}: hoch",
    "No priority assigned" : "Keine Priorität zugewiesen",
    "{percent} % completed" : "{percent} % fertiggestellt",
    "No upcoming tasks" : "Keine anstehenden Aufgaben",
    "upcoming tasks" : "Anstehende Aufgaben",
    "No tasks today" : "Heute keine Aufgaben",
    "Mark as done" : "Als erledigt markieren",
    "No due date assigned" : "Kein Fälligkeitsdatum zugewiesen",
    "[Due yesterday]" : "[Gestern fällig]",
    "[Due] L" : "[Fällig] L",
    "[Due yesterday at] LT" : "[War gestern fällig um] LT",
    "[Due] L [at] LT" : "[Fällig] L [um] LT",
    "Successfully created the task." : "Aufgabe erstellt.",
    "Could not delete the task." : "Aufgabe konnte nicht gelöscht werden.",
    "Synchronizing to the server." : "Synchronisiere mit dem Server.",
    "Task successfully saved to server." : "Aufgabe erfolgreich auf dem Server gespeichert.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Die Aufgabe konnte nicht aktualisiert werden, da sie auf dem Server geändert wurde. Bitte Aktualisieren drücken, damit die lokalen Änderungen verworfen werden.",
    "Could not update the task." : "Aufgabe konnte nicht aktualisiert werden.",
    "Successfully updated the task." : "Aufgabe aktualisiert.",
    "Task successfully moved to new calendar." : "Aufgabe in neuen Kalender verschoben.",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "Create a task" : "Aufgabe erstellen",
    "Message from {author} in {conversationName}" : "Nachricht von {author} in {conversationName}"
},
"nplurals=2; plural=(n != 1);");
