OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Hurrengo zereginak",
    "Important" : "Garrantzitsua",
    "Today" : "Gaur",
    "Week" : "Astea",
    "All" : "Denak",
    "Current" : "Unekoa",
    "Completed" : "Osatua",
    "Tasks" : "Zereginak",
    "The Tasks app for Nextcloud" : "Nextcloudeko Zereginak aplikazioa",
    "Default list" : "Zerrenda lehenetsia",
    "Visibility of Smart Collections" : "Bilduma adimendunen ikusgaitasuna",
    "Hidden" : "Ezkutuan",
    "Visible" : "Ikusgai",
    "Automatic" : "Automatikoa",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edo talderik",
    "Can edit" : "Editatu dezake",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
    "Edit" : "Editatu",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Copied" : "Kopiatuta",
    "Cannot copy" : "Ezin da kopiatu",
    "Export" : "Esportatu",
    "Delete" : "Ezabatu",
    "Unshare" : "Ez partekatu",
    "Cancel" : "Ezeztatu",
    "Save" : "Gorde",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Honek \"{calendar}\" egutegia eta bere gertaera eta zeregin guztiak ezabatuko ditu.",
    "This will unshare the calendar \"{calendar}\"." : "Honek \"{calendar}\" egutegia partekatzea etengo du.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Honek \"{list}\" zerrenda eta bere zeregin guztiak ezabatuko ditu.",
    "This will unshare the list \"{list}\"." : "Honek \"{list}\" zerrenda partekatzea etengo du.",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "List link copied to clipboard." : "Zerrenda esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "List link could not be copied to clipboard." : "Ezin izan da zerrenda esteka arbelera kopiatu.",
    "The name \"{calendar}\" is already used." : "\"{calendar}\" izena badago dagoeneko.",
    "An empty name is not allowed." : "Ez da izen hutsik onartzen.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "An error occurred, unable to delete the list." : "Errore bat gertatu da, ezin izan da zerrenda ezabatu.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatuko da {countdown} segundo barru","Egutegia ezabatuko da {countdown} segundo barru"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Egutegia partekatzea kenduko da {countdown} segundo barru","Egutegia partekatzea kenduko da {countdown} segundo barru"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Zerrenda ezabatzen segundu {countdown}ean","Zerrenda ezabatzen {countdown} segundutan"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Zerrenda partekatzea kenduko da {countdown} segundo barru ","Zerrenda partekatzea kenduko da {countdown} segundo barru "],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatua","{num} entitaterekin partekatua"],
    "Trash bin" : "Zakarrontzia",
    "Loading deleted calendars, tasks and events." : "Ezabatutako egutegi, zeregin eta gertaerak kargatzen.",
    "You do not have any deleted calendars, tasks or events." : "Ez duzu ezabatutako egutegi, zeregin edo gertaerarik.",
    "Name" : "Izena",
    "Deleted" : "Ezabatuta",
    "Restore" : "Berezarri",
    "Delete permanently" : "Ezabatu betirako",
    "Empty trash bin" : "Hustu zakarrontzia",
    "Untitled task" : "Izenik gabeko zeregina",
    "Untitled event" : "Izenik gabeko gertaera",
    "Untitled item" : "Izen gabeko elementua",
    "Unknown calendar" : "Egutegi ezezaguna",
    "Could not load deleted calendars and objects" : "Ezin izan dira ezabatutako egutegi eta elementuak kargatu",
    "Could not delete calendar or event" : "Ezin izan da egutegi edo gertaera ezabatu",
    "Could not restore calendar or event" : "Ezin izan da egutegia edo gertaera berezarri",
    "Do you really want to empty the trash bin?" : "Ziur zaude zakarrontzia hustu nahi duzula?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Zakarrontziko elementuak egun {numDays} igaro ondoren ezabatzen dira","Zakarrontziko elementuak {numDays} egun igaro ondoren ezabatzen dira"],
    "Select a calendar" : "Hautatu egutegi bat",
    "Set date" : "Ezarri data",
    "Set time" : "Ezarri denbora",
    "Delete date" : "Ezabatu data",
    "Click here to add a note." : "Egin klik hemen nota bat gehitzeko.",
    "Set value" : "Ezarri balioa",
    "Delete value" : "Ezabatu balioa",
    "Add this as a new tag" : "Gehitu hau etiketa berri bezala",
    "No tag available. Create one!" : "Ez dago etiketarik eskuragarri. Sortu bat!",
    "Delete all completed tasks." : "Ezabatu osatutako zeregin guztiak.",
    "Delete completed tasks." : "Ezabatu osatutako zereginak.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" egutegiko osatutako zeregin guztiak ezabatu dira.",
    "No errors" : "Errorerik ez",
    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Honek osatutako ataza {taskCount} eta beren azpi-atazak ezabatuko ditu \"{calendar}\" egutegitik.","Honek osatutako {taskCount} zeregin eta beren azpizereginak ezabatuko ditu \"{calendar}\" egutegitik."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ezin izan da ataza {failedCount} ezabatu.","Ezin izan dira {failedCount} zereginak ezabatu."],
    "Add an important task to \"{calendar}\"…" : "Gehitu zeregin garrantzitsu bat \"{calendar}\" egutegiari…",
    "Add a task due today to \"{calendar}\"…" : "Gehitu gaurko epemuga bat duen zeregin bat \"{calendar}\" egutegiari…",
    "Add a current task to \"{calendar}\"…" : "Gehitu uneko zeregin bat \"{calendar}\" egutegiari…",
    "Add a task to \"{calendar}\"…" : "Gehitu zeregin bat \"{calendar}\" egutegiari…",
    "Load all completed tasks." : "Kargatu osatutako zeregin guztiak.",
    "Change sort order" : "Aldatu ordenatzeko irizpidea",
    "Relevance" : "Garrantzia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenatu osatutako egoera, epemuga, lehentasuna, hasiera-data eta laburpenaren arabera.",
    "Start date" : "Hasiera-data",
    "Sort by start date and summary." : "Ordenatu hasiera-data eta laburpenaren arabera.",
    "Due date" : "Epemuga",
    "Sort by due date and summary." : "Ordenatu epemuga eta laburpenaren arabera.",
    "Created date" : "Sortze-data",
    "Sort by created date and summary." : "Ordenatu sortze-data eta laburpenaren arabera",
    "Last modified" : "Azken aldaketa",
    "Sort by last-modified date and summary." : "Ordenatu azken aldaketaren data eta laburpenaren arabera.",
    "Completed date" : "Osatze-data",
    "Sort by completed date." : "Ordenatu osatze-dataren arabera",
    "Priority" : "Lehentasuna",
    "Sort by priority and summary." : "Ordenatu lehentasuna eta laburpenaren arabera.",
    "Alphabetically" : "Alfabetikoki",
    "Sort by summary and priority." : "Ordenatu laburpena eta lehentasunaren arabera.",
    "Manually" : "Eskuz",
    "Sort by manual order." : "Ordenatu eskuz.",
    "{complete} % completed" : "% {complete} osatuta",
    "Task has hidden subtasks" : "Zereginak ezkutuko azpizereginak ditu",
    "Task is pinned" : "Zeregina ainguratuta dago",
    "Task has a note" : "Zereginak ohar bat du",
    "Add subtask" : "Gehitu azpizeregina",
    "Show subtasks" : "Erakutsi azpizereginak",
    "Hide subtasks" : "Ezkutatu azpizereginak",
    "Show closed subtasks" : "Erakutsi itxitako azpizereginak",
    "Hide closed subtasks" : "Ezkutatu itxitako azpizereginak",
    "Delete task" : "Ezabatu zeregina",
    "Toggle starred" : "Txandakatu izardunak",
    "[Yesterday]" : "[Atzo]",
    "[Today]" : "[Gaur]",
    "[Tomorrow]" : "[Bihar]",
    "[Completed yesterday]" : "[Completed yesterday]",
    "[Completed today]" : "[Completed today]",
    "[Completed tomorrow]" : "[Bihar bukatuta]",
    "[Yesterday at] LT" : "[Atzo ordu honetan] LT",
    "[Today at] LT" : "[Gaur ordu honetan] LT",
    "[Tomorrow at] LT" : "[Bihar ordu honetan] LT",
    "L [at] LT" : "L [ordu honetan] LT",
    "[Completed yesterday at] LT" : "[Bukatuta atzo ordu honetan] LT",
    "[Completed today at] LT" : "[Gaur bukatuta ordu honetan] LT",
    "[Completed tomorrow at] LT" : "[Bihar bukatuta ordu honetan] LT",
    "[Completed] L [at] LT" : "[Bukatuta] L [ordu honetan] LT",
    "Add a subtask to \"{task}\"…" : "Gehitu azpizeregin bat \"{task}\" zereginari…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Zeregina ezabatuko da {countdown} segundo barru","Zeregina ezabatuko da {countdown} segundo barru"],
    "Task is completed" : "Zeregina osatuta",
    "Create a new task" : "Sortu zeregin berria",
    "Task summary" : "Zereginaren laburpena",
    "Create task" : "Sortu zeregina",
    "Creating the new task…" : "Zeregin berria sortzen…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" \"{calendar}\" atalean gehitu da",
    "Open task" : "Ireki zeregina",
    "Close" : "Itxi",
    "_%n Completed Task_::_%n Completed Tasks_" : ["Ataza %n osatuta","%n zeregina osatuta"],
    "Tomorrow" : "Bihar",
    "Add List…" : "Gehitu zerrenda...",
    "New List" : "Zerrenda berria",
    "All day" : "Egun osoa",
    "Unpin" : "Kendu aingura",
    "Pin" : "Ainguratu",
    "Show in Calendar" : "Erakutsi egutegian",
    "Edit title" : "Editatu izenburua",
    "Details" : "Xehetasunak",
    "Select a classification" : "Hautatu sailkapen bat",
    "Select a status" : "Hautatu egoera bat",
    "Select tags" : "Hautatu etiketak",
    "Notes" : "Oharrak",
    "Reminders" : "Abisuak",
    "Repeat" : "Errepikatu",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "[Completed] L" : "[Bukatuta] L",
    "[Completed last] dddd [at] LT" : "[Bukatuta azken] dddd [ordu honetan] LT",
    "[Completed] dddd [at] LT" : "[Bukatuta] dddd [ordu honetan] LT",
    "[Last modified yesterday at] LT" : "[Azken aldaketa atzo ordu honetan] LT",
    "[Last modified today at] LT" : "[Azken aldaketa gaur ordu honetan] LT",
    "[Last modified] L" : "[Azken aldaketa] L",
    "[Last modified last] dddd [at] LT" : "[Azken aldaketa] dddd [ordu honetan] LT",
    "[Last modified] dddd [at] LT" : "[Azken aldaketa] dddd [ordu honetan] LT",
    "[Created yesterday at] LT" : "[Atzo sortu zen ordu honetan] LT",
    "[Created today at] LT" : "[Gaur sortu da ordu honetan] LT",
    "[Created] L" : "[Sortua] L",
    "[Created last] dddd [at] LT" : "[Sortua azken] dddd [ordu honetan] LT",
    "[Created] dddd [at] LT" : "[Sortua] dddd [ordu honetan] LT",
    "Needs action" : "Ekintza behar du",
    "In process" : "Abian",
    "Canceled" : "Utzita",
    "Clear status" : "Garbitu egoera",
    "Loading task from server." : "Zeregina zerbitzaritik kargatzen.",
    "Task not found!" : "Ez da zeregina aurkitu!",
    "[Starts today]" : "[Gaur hasten da]",
    "[Starts tomorrow]" : "[Bihar hasten da]",
    "[Starts on] LL" : "LL [hasiko da] ",
    "[Started yesterday]" : "[Atzo hasi zen]",
    "[Started on] LL" : "LL [hasi da]",
    "[Started today at] LT" : "[Gaur hasi da ordu honetan] LT",
    "[Starts today at] LT" : "[Gaur hasten da ordu honetan] LT",
    "[Starts tomorrow at] LT" : "[Bihar hasten da ordu honetan] LT",
    "[Starts on] LL [at] LT" : "LL [hasiko da ordu honetan] LT",
    "[Started yesterday at] LT" : "[Atzo hasi zen ordu honetan] LT",
    "[Started on] LL [at] LT" : "LL [hasi da ordu honetan] LT",
    "Set start date" : "Ezarri hasiera-data",
    "[Due today]" : "[Epemuga gaur]",
    "[Due tomorrow]" : "[Epemuga bihar]",
    "[Due on] LL" : "[Epemuga] LL",
    "[Was due yesterday]" : "[Epemuga atzo]",
    "[Was due on] LL" : "[Epemuga] LL",
    "[Was due today at] LT" : "[Epemuga gaur zen ordu honetan] LT",
    "[Due today at] LT" : "[Epemuga gaur ordu honetan] LT",
    "[Due tomorrow at] LT" : "[Epemuga bihar ordu honetan] LT",
    "[Due on] LL [at] LT" : "[Epemuga] LL [ordu honetan] LT",
    "[Was due yesterday at] LT" : "[Epemuga atzo ordu honetan] LT",
    "[Was due on] LL [at] LT" : "[Epemuga] LL [ordu honetan] LT",
    "Set due date" : "Ezarri epemuga",
    "Priority {priority}: low" : "Lehentasuna {priority}: baxua",
    "Priority {priority}: medium" : "Lehentasuna {priority}: ertaina",
    "Priority {priority}: high" : "Lehentasuna {priority}: altua",
    "No priority assigned" : "Lehentasuna ezarri gabe",
    "{percent} % completed" : "% {percent} osatuta",
    "No upcoming tasks" : "Ez dago hurrengo zereginik",
    "upcoming tasks" : "hurrengo zereginak",
    "No tasks today" : "Zereginik ez gaurko",
    "Mark as done" : "Markatu eginda",
    "No due date assigned" : "Ez da epemuga esleitu",
    "[Due yesterday]" : "[Epemuga atzo]",
    "[Due] L" : "[Epemuga] L",
    "[Due yesterday at] LT" : "[Epemuga atzo ordu honetan] LT",
    "[Due] L [at] LT" : "[Epemuga] L [ordu honetan] LT",
    "Successfully created the task." : "Zeregina ondo sortu da.",
    "Could not delete the task." : "Ezin izan da zeregina ezabatu.",
    "Synchronizing to the server." : "Zerbitzariarekin sinkronizatzen.",
    "Task successfully saved to server." : "Zeregina behar bezala gorde da zerbitzarian.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ezin izan da zeregina eguneratu, zerbitzarian aldatua zegoelako. Egin klik freskatzeko, aldaketa lokalak baztertuko dira.",
    "Could not update the task." : "Ezin izan da zeregina eguneratu.",
    "Successfully updated the task." : "Zeregina ondo eguneratu da.",
    "Task successfully moved to new calendar." : "Zeregina ondo eraman da egutegi berrira.",
    "An error occurred" : "Errore bat gertatu da",
    "Create a task" : "Sortu zeregin bat",
    "Message from {author} in {conversationName}" : "{Author} erabiltzailearen mezua {conversationName} atalean"
},
"nplurals=2; plural=(n != 1);");
