OC.L10N.register(
    "tasks",
    {
    "Important" : "Viktig",
    "Today" : "I dag",
    "Week" : "Uke",
    "All" : "Alle",
    "Current" : "Nåværende",
    "Completed" : "Ferdig",
    "Tasks" : "Oppgaver",
    "The Tasks app for Nextcloud" : "Oppgave-appen for Nextcloud",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Synlighet for smarte samlinger",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "Can edit" : "Kan redigere",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kunne ikke endre rettigheter.",
    "Edit" : "Rediger",
    "Copy private link" : "Kopier privat lenke",
    "Copied" : "Kopiert",
    "Cannot copy" : "Kan ikke kopiere",
    "Delete" : "Slett",
    "Unshare" : "Opphev deling",
    "Cancel" : "Avbryt",
    "Save" : "Lagre",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Dette sletter kalender \"{calendar}\" og alle hendelser og oppgaver i denne.",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "List link copied to clipboard." : "Lenke kopiert til utklippstavlen.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "List link could not be copied to clipboard." : "Lenke kunne ikke kopieres til utklippstavlen.",
    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
    "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
    "An error occurred, unable to delete the list." : "En feil oppstod, kunne ikke slette listen.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sletter listen om {countdown} sekund","Sletter listen om {countdown} sekunder"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Fjerner deling av listen om {countdown} sekund","Fjerner deling av listen om {countdown} sekunder"],
    "Trash bin" : "Papirkurv",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gjenoprett",
    "Delete permanently" : "Slett permament",
    "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
    "Delete completed tasks." : "Slett fullførte oppgaver.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
    "No errors" : "Ingen feil",
    "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
    "Load all completed tasks." : "Last alle fullførte oppgaver.",
    "Change sort order" : "Endre sorteringsrekkefølge",
    "Relevance" : "Relevans",
    "Start date" : "Startdato",
    "Due date" : "Forfallsdato",
    "Created date" : "Opprettelsesdato",
    "Last modified" : "Sist redigert",
    "Completed date" : "Fullført dato",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "{complete} % completed" : "{complete} % utført",
    "Add subtask" : "Legg til underoppgave",
    "Show subtasks" : "Vis underoppgaver",
    "Hide subtasks" : "Skjul underoppgaver",
    "Delete task" : "Slett oppgave",
    "Add a subtask to \"{task}\"…" : "Legg til en underoppgave i \"{task}\"...",
    "Task is completed" : "Oppgaven er fullført",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n utført oppgave","%n avsluttede oppgaver"],
    "Tomorrow" : "I morgen",
    "Add List…" : "Legg til liste...",
    "New List" : "Ny liste",
    "All day" : "Hele dagen",
    "Select a status" : "Velg en status",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "Needs action" : "Krever handling",
    "Canceled" : "Avbrutt",
    "Loading task from server." : "Laster oppgaver fra serveren.",
    "Task not found!" : "Oppgaven ble ikke funnet!",
    "Set start date" : "Sett startdato",
    "Set due date" : "Sett forfallsdato",
    "Priority {priority}: low" : "Prioritet {priority}: lav",
    "Priority {priority}: medium" : "Prioritet {priority}: middels",
    "Priority {priority}: high" : "Prioritet {priority}: høy",
    "No priority assigned" : "Ingen tildelt prioritet",
    "{percent} % completed" : "{percent} % utført",
    "Could not delete the task." : "Kunne ikke slette oppgaven.",
    "An error occurred" : "En feil oppstod"
},
"nplurals=2; plural=(n != 1);");
