OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Astăzi",
    "Week" : "Săptămâna",
    "All" : "Toate ",
    "Current" : "Curent",
    "Completed" : "Terminat",
    "Tasks" : "Sarcini",
    "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
    "Hidden" : "Ascuns",
    "Visible" : "Vizibil",
    "Automatic" : "Automat",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "Edit" : "Editează",
    "Copy private link" : "Copiază link privat",
    "Delete" : "Șterge",
    "Unshare" : "Oprește partajarea",
    "Cancel" : "Anulează",
    "Save" : "Salvează",
    "An empty name is not allowed." : "Un nume vid nu este permis.",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n sarcină realizată","%n sarcini realizate","%n sarcini realizate"],
    "Tomorrow" : "Mâine",
    "New List" : "Listă nouă",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "Task not found!" : "Sarcina nu a fost găsită!",
    "Set start date" : "Setează data de început",
    "Set due date" : "Setează termenul limită"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
