OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Prossime attività",
    "Important" : "Importante",
    "Today" : "Oggi",
    "Week" : "Settimana",
    "All" : "Tutti",
    "Current" : "Attuale",
    "Completed" : "Completato",
    "Tasks" : "Attività",
    "The Tasks app for Nextcloud" : "L'applicazione delle attività per Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Una volta abilitata, un nuovo menu Attività apparirà nel menu delle tue applicazioni di Nextcloud. Da qui, potrai aggiungere ed eliminare attività, modificare il loro titolo, la descrizione, le date di inizio e fine e marcarle come importanti. Le attività possono essere condivise tra utenti. Le attività possono essere sincronizzate utilizzando CalDav (ogni elenco di attività è collegato a un calendario di Nextcloud, per sincronizzarlo con il tuo client locale: Thunderbird, Evolution, KDE Kontact, iCal … - ti basta aggiungere il calendario come un calendario remoto nel tuo client). Puoi scaricare le tue attività come file ICS utilizzando il pulsante di scaricamento per ogni calendario.",
    "Default list" : "Elenco predefinito",
    "Visibility of Smart Collections" : "Visibilità delle collezioni veloci",
    "Hidden" : "Nascosto",
    "Visible" : "Visibile",
    "Automatic" : "Automatico",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "No users or groups" : "Nessun utente o gruppo",
    "Can edit" : "Può modificare",
    "Unshare with {displayName}" : "Rimuovi condivisione con {displayName}",
    "Unable to delete the share." : "Impossibile eliminare la condivisione.",
    "Unable to change permissions." : "Impossibile cambiare i permessi.",
    "Edit" : "Modifica",
    "Copy private link" : "Copia collegamento privato",
    "Copied" : "Copiato",
    "Cannot copy" : "Impossibile copiare",
    "Delete" : "Elimina",
    "Unshare" : "Rimuovi condivisione",
    "Cancel" : "Annulla",
    "Save" : "Salva",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ciò eliminerà il calendario \"{calendar}\" e tutti gli eventi e le attività corrispondenti.",
    "This will unshare the calendar \"{calendar}\"." : "Questo rimuoverà il calendario \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Questo eliminerà l'elenco \"{list}\" e tutte le attività corrispondenti.",
    "This will unshare the list \"{list}\"." : "Questo rimuoverà la condivisione dell'elenco \"{list}\".",
    "Calendar link copied to clipboard." : "Collegamento del calendario copiato negli appunti.",
    "List link copied to clipboard." : "Collegamento all'elenco copiato negli appunti.",
    "Calendar link could not be copied to clipboard." : "Il collegamento del calendario non può essere copiato negli appunti.",
    "List link could not be copied to clipboard." : "Il collegamento all'elenco non può essere copiato negli appunti.",
    "The name \"{calendar}\" is already used." : "Il nome \"{calendar}\" è già utilizzato.",
    "An empty name is not allowed." : "Un nome vuoto non è consentito.",
    "An error occurred, unable to delete the calendar." : "Si è verificato un errore, impossibile eliminare il calendario.",
    "An error occurred, unable to delete the list." : "Si è verificato un errore, impossibile eliminare l'elenco.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminazione del calendario in {countdown} secondo","Eliminazione del calendario in {countdown} secondi"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Rimozione della condivisione del calendario in {countdown} secondo","Rimozione della condivisione del calendario in {countdown} secondi"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eliminazione dell'elenco in {countdown} secondo","Eliminazione dell'elenco in {countdown} secondi"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Rimozione della condivisione dell'elenco in {countdown} secondo","Rimozione della condivisione dell'elenco in {countdown} secondi"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Condiviso con {num} entità","Condiviso con {num} entità"],
    "Trash bin" : "Cestino",
    "Loading deleted calendars, tasks and events." : "Caricamento di calendari, attività ed eventi eliminati.",
    "You do not have any deleted calendars, tasks or events." : "Non hai calendari, attività o eventi eliminati.",
    "Name" : "Nome",
    "Deleted" : "Eliminato",
    "Restore" : "Ripristina",
    "Delete permanently" : "Elimina definitivamente",
    "Empty trash bin" : "Svuota cestino",
    "Untitled task" : "Attività senza titolo",
    "Untitled event" : "Evento senza titolo",
    "Untitled journal" : "Documento senza titolo",
    "Untitled item" : "Elemento senza titolo",
    "Unknown calendar" : "Calendario sconosciuto",
    "Could not load deleted calendars and objects" : "Impossibile caricare i calendari e gli oggetti eliminati",
    "Could not delete calendar or event" : "Impossibile eliminare il calendario o l'evento",
    "Could not restore calendar or event" : "Impossibile ripristinare il calendario o l'evento",
    "Do you really want to empty the trash bin?" : "Vuoi davvero svuotare il cestino?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Gli elementi nel cestino sono eliminati dopo {numDays} giorni","Gli elementi nel cestino sono eliminati dopo {numDays} giorni"],
    "Select a calendar" : "Seleziona un calendario",
    "No calendar matches the search." : "Nessun calendario corrisponde alla ricerca",
    "Set date" : "Imposta data",
    "Set time" : "Imposta ora",
    "Delete date" : "Elimina data",
    "Click here to add a note." : "Fai clic qui per aggiungere una nota.",
    "Set value" : "Imposta valore",
    "Delete value" : "Elimina valore",
    "Add this as a new tag" : "Aggiungi come nuova etichetta",
    "No tag available. Create one!" : "Nessuna etichetta disponibile. Creane una!",
    "Delete all completed tasks." : "Elimina tutte le attività completate.",
    "Delete completed tasks." : "Elimina le attività completate.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminate tutte le attività completate dal calendario \"{calendar}\".",
    "No errors" : "Nessun errore",
    "Open your browser console for more details" : "Apri la console del tuo browser per altri dettagli",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Questo eliminerà {taskCount} attività completata e le relative sottoattività dal calendario \"{calendar}\".","Questo eliminerà {taskCount} attività completate e le relative sottoattività dal calendario \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Impossibile eliminare {failedCount} attività.","Impossibile eliminare {failedCount} attività."],
    "Add an important task to \"{calendar}\"…" : "Aggiungi un'attività importante a \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Aggiungi un'attività che scade oggi a \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Aggiungi un'attività attuale a \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Aggiungi un'attività a \"{calendar}\"...",
    "Load all completed tasks." : "Carica tutte le attività completate.",
    "Change sort order" : "Cambia l'ordinamento",
    "Relevance" : "Importanza",
    "Sort by completed state, due date, priority, start date and summary." : "Ordina per stato di completamento, data di scadenza, priorità, data di inizio e riepilogo.",
    "Start date" : "Data iniziale",
    "Sort by start date and summary." : "Ordina per data di inizio e riepilogo.",
    "Due date" : "Data di scadenza",
    "Sort by due date and summary." : "Ordina per data di scadenza e riepilogo.",
    "Created date" : "Data di creazione",
    "Sort by created date and summary." : "Ordina per data di creazione e riepilogo.",
    "Last modified" : "Ultima modifica",
    "Sort by last-modified date and summary." : "Ordina per data di ultima modifica e riepilogo.",
    "Completed date" : "Data di completamento",
    "Sort by completed date." : "Ordina per data di completamento.",
    "Priority" : "Priorità",
    "Sort by priority and summary." : "Ordina per priorità e riepilogo.",
    "Alphabetically" : "Ordine alfabetico",
    "Sort by summary and priority." : "Ordina per riepilogo e priorità.",
    "Manually" : "Manuale",
    "Sort by manual order." : "Ordina manualmente.",
    "{complete} % completed" : "{complete} % completato",
    "Task has hidden subtasks" : "L'attività ha sotto-attività nascoste",
    "Task is pinned" : "L'attività è appuntata",
    "Task has a note" : "L'attività ha una nota",
    "Add subtask" : "Aggiungi sottoattività",
    "Show subtasks" : "Mostra sottoattività",
    "Hide subtasks" : "Nascondi sottoattività",
    "Show closed subtasks" : "Mostra sotto-attività chiuse",
    "Hide closed subtasks" : "Nascondi sotto-attività chiuse",
    "Delete task" : "Elimina attività",
    "Toggle starred" : "Commuta stella",
    "[Yesterday]" : "[Ieri]",
    "[Today]" : "[Oggi]",
    "[Tomorrow]" : "[Domani]",
    "[Completed yesterday]" : "[Completata ieri]",
    "[Completed today]" : "[Completata oggi]",
    "[Completed tomorrow]" : "[Completata domani]",
    "[Yesterday at] LT" : "[Ieri alle] LT",
    "[Today at] LT" : "[Oggi alle] LT",
    "[Tomorrow at] LT" : "[Domani alle] LT",
    "L [at] LT" : "L [alle] LT",
    "[Completed yesterday at] LT" : "[Completata ieri alle] LT",
    "[Completed today at] LT" : "[Completata oggi alle] LT",
    "[Completed tomorrow at] LT" : "[Completata domani alle] LT",
    "[Completed] L [at] LT" : "[Completata il] L [alle] LT",
    "Add a subtask to \"{task}\"…" : "Aggiungi una sottoattività a \"{task}\"...",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Eliminazione dell'attività in {countdown} secondo","Eliminazione dell'attività in {countdown} secondi"],
    "Task is cancelled" : "L'attività è stata annullata",
    "Task is completed" : "L'attività è completata",
    "Task is read-only" : "L'attività è in sola lettura",
    "Task is not completed" : "L'attività non è completata",
    "Create a new task" : "Crea una nuova attività",
    "Task summary" : "Riepilogo attività",
    "Create task" : "Crea attività",
    "Creating the new task…" : "Creazione della nuova attività…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" è stato aggiunto a \"{calendar}\"",
    "Open task" : "Apri attività",
    "Close" : "Chiudi",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n attività completata","%n attività completate"],
    "Tomorrow" : "Domani",
    "Add List…" : "Aggiungi elenco...",
    "New List" : "Nuovo elenco",
    "All day" : "Tutto il giorno",
    "Unpin" : "Rimuovi",
    "Pin" : "Fissa",
    "Show in Calendar" : "Mostra nel calendario",
    "Edit title" : "Modifica titolo",
    "Details" : "Dettagli",
    "Select a classification" : "Seleziona una classificazione",
    "Select a status" : "Seleziona uno stato",
    "Select tags" : "Seleziona etichette",
    "Notes" : "Note",
    "Reminders" : "Promemoria",
    "Repeat" : "Ripeti",
    "When shared show full event" : "Se condiviso, mostra evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "[Completed] L" : "[Completata il] L",
    "[Completed last] dddd [at] LT" : "[Completata l'ultimo] dddd [alle] LT",
    "[Completed] dddd [at] LT" : "[Completata il] dddd [alle] LT",
    "[Last modified yesterday at] LT" : "[Ultima modifica ieri alle] LT",
    "[Last modified today at] LT" : "[Ultima modifica oggi alle] LT",
    "[Last modified] L" : "[Ultima modifica il] L",
    "[Last modified last] dddd [at] LT" : "[Ultima modifica il] dddd [alle] LT",
    "[Last modified] dddd [at] LT" : "[Ultima modifica il] dddd [alle] LT",
    "[Created yesterday at] LT" : "[Creata ieri alle] LT",
    "[Created today at] LT" : "[Creata oggi alle] LT",
    "[Created] L" : "[Creata il] L",
    "[Created last] dddd [at] LT" : "[Creata l'ultimo] dddd [alle] LT",
    "[Created] dddd [at] LT" : "[Creata il] dddd [alle] LT",
    "Needs action" : "Richiede azione",
    "In process" : "In corso",
    "Canceled" : "Annullata",
    "Clear status" : "Cancella stato",
    "Loading task from server." : "Caricamento attività dal server.",
    "Task not found!" : "Attività non trovata!",
    "[Starts today]" : "[Inizia oggi]",
    "[Starts tomorrow]" : "[Inizia domani]",
    "[Starts on] LL" : "[Inizia il] LL",
    "[Started yesterday]" : "[Iniziata ieri]",
    "[Started on] LL" : "[Iniziata il] LL",
    "[Started today at] LT" : "[Iniziata oggi alle] LT",
    "[Starts today at] LT" : "[Inizia oggi alle] LT",
    "[Starts tomorrow at] LT" : "[Inizia domani alle] LT",
    "[Starts on] LL [at] LT" : "[Inizia il] LL [alle] LT",
    "[Started yesterday at] LT" : "[Iniziata ieri alle] LT",
    "[Started on] LL [at] LT" : "[Iniziata il] LL [alle] LT",
    "Set start date" : "Imposta data iniziale",
    "[Due today]" : "[Scade oggi]",
    "[Due tomorrow]" : "[Scade domani]",
    "[Due on] LL" : "[Scade il] LL",
    "[Was due yesterday]" : "[Scaduta ieri]",
    "[Was due on] LL" : "[Scaduta il] LL",
    "[Was due today at] LT" : "[Scaduta oggi alle] LT",
    "[Due today at] LT" : "[Scade oggi alle] LT",
    "[Due tomorrow at] LT" : "[Scade domani alle] LT",
    "[Due on] LL [at] LT" : "[Scade il] LL [alle] LT",
    "[Was due yesterday at] LT" : "[Scaduta ieri alle] LT",
    "[Was due on] LL [at] LT" : "[Scaduta il] LL [alle] LT",
    "Set due date" : "Imposta data di scadenza",
    "Priority {priority}: low" : "Priorità {priority}: bassa",
    "Priority {priority}: medium" : "Priorità {priority}: media",
    "Priority {priority}: high" : "Priorità {priority}: alta",
    "No priority assigned" : "Nessuna priorità assegnata",
    "{percent} % completed" : "{percent} % completato",
    "No upcoming tasks" : "Nessuna attività imminente",
    "upcoming tasks" : "attività imminenti",
    "No tasks today" : "Nessuna attività oggi",
    "Mark as done" : "Marca come completato",
    "No due date assigned" : "Nessuna scadenza assegnata",
    "[Due yesterday]" : "[Scaduta ieri]",
    "[Due] L" : "[Scade il] L",
    "[Due yesterday at] LT" : "[Scaduta ieri alle] LT",
    "[Due] L [at] LT" : "[Scade il] L [alle] LT",
    "Successfully created the task." : "Attività creata correttamente.",
    "Could not delete the task." : "Impossibile eliminare l'attività.",
    "Synchronizing to the server." : "Sincronizzazione con il server.",
    "Task successfully saved to server." : "Attività salvata correttamente sul server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Impossibile aggiornare l'attività poiché è stata modificata sul server. Fai clic per aggiornarla, le modifiche locali saranno scartate.",
    "Could not update the task." : "Impossibile aggiornare l'attività.",
    "Successfully updated the task." : "Attività aggiornata correttamente.",
    "Task successfully moved to new calendar." : "Attività spostata correttamente in nuovo calendario.",
    "An error occurred" : "Si è verificato un errore",
    "Create a task" : "Crea un'attività",
    "Message from {author} in {conversationName}" : "Messaggio da {author} in {conversationName}"
},
"nplurals=2; plural=(n != 1);");
