OC.L10N.register(
    "tasks",
    {
    "Important" : "Mikilvægt",
    "Today" : "Í dag",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "Tasks" : "Verkefni",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Default list" : "Sjálfgefinn listi",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
    "Unable to delete the share." : "Get ekki eytt sameigninni.",
    "Unable to change permissions." : "Tekst ekki að breyta heimildum.",
    "Edit" : "Breyta",
    "Copy private link" : "Afrita einkatengil",
    "Copied" : "Afritað",
    "Delete" : "Eyða",
    "Unshare" : "Hætta deilingu",
    "Cancel" : "Hætta við",
    "Save" : "Vista",
    "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
    "Delete all completed tasks." : "Eyða öllum loknum verkum.",
    "Delete completed tasks." : "Eyða loknum verkum.",
    "No errors" : "Engar villur",
    "Open your browser console for more details" : "Opnaðu stjórnborð vafrans þíns til að sjá frekari upplýsingar",
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Gat ekki eytt {failedCount} verkefni.","Gat ekki eytt {failedCount} verkefnum."],
    "Add an important task to \"{calendar}\"…" : "Bæta mikilvægu verkefni við \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Bæta verkefni sem á að klára í dag við \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Bæta fyrirliggjandi verkefni við \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Bæta verkefni við \"{calendar}\"...",
    "Load all completed tasks." : "Hlaða inn öllum loknum verkum.",
    "Change sort order" : "Breyta röðun",
    "Sort by completed state, due date, priority, start date and summary." : "Raða eftir framvindustöðu, skiladegi, forgangi, upphafsdagsetningu og yfirliti.",
    "Start date" : "Upphafsdagur",
    "Sort by start date and summary." : "Raða eftir upphafsdagsetningu og yfirliti.",
    "Due date" : "Skiladagur",
    "Sort by due date and summary." : "Raða eftir skiladagsetningu og yfirliti.",
    "Created date" : "Búið til",
    "Sort by created date and summary." : "Raða eftir dagsetningu þegar var útbúið og yfirliti.",
    "Last modified" : "Síðast breytt",
    "Sort by last-modified date and summary." : "Raða eftir dagsetningu þegar var síðast breytt og yfirliti.",
    "Completed date" : "Lokadagsetning",
    "Sort by completed date." : "Raða eftir lokadagsetningu",
    "Priority" : "Forgangur",
    "Sort by priority and summary." : "Raða eftir forgangi og yfirliti.",
    "Alphabetically" : "Í stafrófsröð",
    "Sort by summary and priority." : "Raða eftir yfirliti og forgangi.",
    "Manually" : "Handvirkt",
    "Sort by manual order." : "Raða eftir handvirkri röð.",
    "{complete} % completed" : "{complete} % lokið",
    "[Yesterday]" : "[Í gær]",
    "[Today]" : "[Í dag]",
    "[Tomorrow]" : "[Á morgun]",
    "Add a subtask to \"{task}\"…" : "Bæta undirverkefni við \"{task}\"...",
    "Task is completed" : "Verkefni er lokið",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verkefni","%n lokin verkefni"],
    "Tomorrow" : "Á morgun",
    "Add List…" : "Bæta við lista...",
    "New List" : "Nýr listi",
    "All day" : "Heilsdagsviðburður",
    "Select a classification" : "Veldu flokkun",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Canceled" : "Hætt við",
    "Task not found!" : "Verkefn fannst ekki!",
    "[Starts today]" : "[Byrjar í dag]",
    "[Starts tomorrow]" : "[Byrjar á morgun]",
    "[Starts on] LL" : "[Byrjar þann] LL",
    "[Started yesterday]" : "[Byrjaði í gær]",
    "[Started on] LL" : "[Byrjar þann] LL",
    "[Started today at] LT" : "[Byrjaði í dag klukkan] LT",
    "[Starts today at] LT" : "[Byrjar í dag klukkan] LT",
    "[Starts tomorrow at] LT" : "[Byrjar í á morgun klukkan] LT",
    "[Starts on] LL [at] LT" : "[Byrjar þann] LL [klukkan] LT",
    "[Started yesterday at] LT" : "[Byrjaði í gær klukkan] LT",
    "[Started on] LL [at] LT" : "[Byrjaði þann] LL [klukkan] LT",
    "Set start date" : "Setja upphafsdag",
    "[Due today]" : "[Á að ljúka í dag]",
    "[Due tomorrow]" : "[Á að ljúka á morgun]",
    "[Due on] LL" : "[Á að ljúka þann] LL",
    "[Was due yesterday]" : "[Átti að ljúka í gær]",
    "[Was due on] LL" : "[Átti að ljúka þann] LL",
    "[Was due today at] LT" : "[Átti að ljúka í dag klukkan] LT",
    "[Due today at] LT" : "[Á að ljúka í dag klukkan] LT",
    "[Due tomorrow at] LT" : "[Á að ljúka á morgun klukkan] LT",
    "[Due on] LL [at] LT" : "[Á að ljúka þann] LL [klukkan] LT",
    "[Was due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
    "[Was due on] LL [at] LT" : "[Átti að ljúka þann] LL [klukkan] LT",
    "Set due date" : "Setja skiladag",
    "No priority assigned" : "Enginn forgangur settur",
    "Could not delete the task." : "Gat ekki eytt verkefninu.",
    "Synchronizing to the server." : "Samstilli við netþjóninn.",
    "Task successfully saved to server." : "Tókst að vista verkefnið á þjóninn.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Gat ekki uppfært verkefnið vegna þess að því var breytt á þjóninum. Smelltu til að endurlesa það, breytingum hjá þér verður hent.",
    "Could not update the task." : "Gat ekki uppfært verkefnið.",
    "An error occurred" : "Villa kom upp"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
