OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Επερχόμενες εργασίες",
    "Important" : "Σημαντικό ",
    "Today" : "Σήμερα",
    "Week" : "Εβδομάδα",
    "All" : "Όλες",
    "Current" : "Τρέχουσα",
    "Completed" : "Ολοκληρωμένες",
    "Tasks" : "Εργασίες",
    "The Tasks app for Nextcloud" : "Η εφαρμογή Εργασίες για το Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Μόλις ενεργοποιηθεί, θα εμφανιστεί ένα νέο μενού Εργασίες στο μενού εφαρμογών του Nextcloud. Από εκεί μπορείτε να προσθέσετε και να διαγράψετε εργασίες, να επεξεργαστείτε τον τίτλο, την περιγραφή, τις ημερομηνίες έναρξης και λήξης και να τις επισημάνετε ως σημαντικές. Οι εργασίες μπορούν να μοιράζονται μεταξύ των χρηστών. Οι εργασίες μπορούν να συγχρονιστούν χρησιμοποιώντας το CalDav (κάθε λίστα εργασιών συνδέεται με ένα ημερολόγιο Nextcloud, για να το συγχρονίσετε με την εφαρμογή σας: Thunderbird, Evolution, KDE Kontact, iCal… - απλώς προσθέστε το ημερολόγιο ως απομακρυσμένο ημερολόγιο στην εφαρμογή σας). Μπορείτε να κάνετε λήψη των εργασιών σας ως αρχεία ICS χρησιμοποιώντας το κουμπί λήψης για κάθε ημερολόγιο.",
    "Default list" : "Προεπιλεγμένη λίστα",
    "Visibility of Smart Collections" : "Ορατότητα Έξυπνων Συλλογών",
    "Hidden" : "Κρυφό",
    "Visible" : "Ορατό",
    "Automatic" : "Αυτόματο",
    "Share with users or groups" : "Κοινή χρήση με χρήστες ή ομάδες",
    "No users or groups" : "Δεν υπάρχουν χρήστες ή ομάδες",
    "Can edit" : "Μπορεί να επεξεργαστεί",
    "Unshare with {displayName}" : "Κατάργηση κοινής χρήσης με {displayName}",
    "Unable to delete the share." : "Αδυναμία διαγραφής κοινόχρηστου.",
    "Unable to change permissions." : "Αδυναμία αλλαγής δικαιωμάτων.",
    "Edit" : "Επεξεργασία",
    "Copy private link" : "Αντιγραφή ιδιωτικού συνδέσμου",
    "Copied" : "Αντιγράφηκε",
    "Cannot copy" : "Δεν είναι δυνατή η αντιγραφή",
    "Export" : "Εξαγωγή",
    "Delete" : "Διαγραφή",
    "Unshare" : "Αναίρεση διαμοιρασμού",
    "Cancel" : "Aκύρωση",
    "Save" : "Αποθήκευση",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Θα διαγραφεί το ημερολόγιο \"{calendar}\" και όλα τα σχετικά γεγονότα και εργασίες.",
    "This will unshare the calendar \"{calendar}\"." : "Αυτό θα καταργήσει την κοινή χρήση του ημερολογίου \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Αυτό θα διαγράψει τη λίστα \"{list}\" και όλες τις αντίστοιχες εργασίες.",
    "This will unshare the list \"{list}\"." : "Αυτό θα καταργήσει την κοινή χρήση της λίστας \"{list}\".",
    "Calendar link copied to clipboard." : "Ο σύνδεσμος του ημερολογίου αντιγράφηκε στο πρόχειρο.",
    "List link copied to clipboard." : "Ο σύνδεσμος λίστας αντιγράφηκε στο πρόχειρο.",
    "Calendar link could not be copied to clipboard." : "Αδυναμία αντιγραφής συνδέσμου ημερολογίου στο πρόχειρο.",
    "List link could not be copied to clipboard." : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου λίστας στο πρόχειρο.",
    "The name \"{calendar}\" is already used." : "Το όνομα \"{calendar}\" είναι σε χρήση.",
    "An empty name is not allowed." : "Δεν επιτρέπεται κενό όνομα.",
    "An error occurred, unable to delete the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να διαγραφεί το ημερολόγιο.",
    "An error occurred, unable to delete the list." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η διαγραφή της λίστας.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Διαγραφή ημερολογίου σε {countdown} δεύτερα","Διαγραφή ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Κατάργηση κοινής χρήσης ημερολογίου σε {countdown} δεύτερα","Κατάργηση κοινής χρήσης ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Διαγραφή λίστας σε {countdown} δεύτερα","Διαγραφή λίστας σε {countdown} δευτερόλεπτα"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Κατάργηση κοινής χρήσης λίστας σε {countdown} δεύτερα","Κατάργηση κοινής χρήσης λίστας σε {countdown} δευτερόλεπτα"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Κοινη χρήση με {num} οντότητα","Κοινη χρήση με {num} οντότητες"],
    "Trash bin" : "Κάδος απορριμμάτων",
    "Loading deleted calendars, tasks and events." : "Φόρτωση διαγραμμένων ημερολογίων, εργασιών και συμβάντων.",
    "You do not have any deleted calendars, tasks or events." : "Δεν έχετε διαγραμμένα ημερολόγια, εργασίες ή συμβάντα.",
    "Name" : "Όνομα",
    "Deleted" : "Διαγραμμένα",
    "Restore" : "Επαναφορά",
    "Delete permanently" : "Διαγραφή οριστικά",
    "Empty trash bin" : "Άδειασμα κάδου",
    "Untitled task" : "Εργασία χωρίς όνομα",
    "Untitled event" : "Στοιχείο χωρίς όνομα",
    "Untitled journal" : "Ημερολόγιο χωρίς τίτλο",
    "Untitled item" : "Στοιχείο χωρίς όνομα",
    "Unknown calendar" : "Άγνωστο ημερολόγιο",
    "Could not load deleted calendars and objects" : "Δεν ήταν δυνατή η φόρτωση διαγραμμένων ημερολογίων και αντικειμένων",
    "Could not delete calendar or event" : "Δεν ήταν δυνατή η διαγραφή ημερολογίου ή συμβάντος",
    "Could not restore calendar or event" : "Δεν ήταν δυνατή η επαναφορά ημερολογίου ή συμβάντος",
    "Do you really want to empty the trash bin?" : "Θέλετε πραγματικά να αδειάσετε τον κάδο απορριμμάτων;",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Θέλετε πραγματικά να αδειάσετε τον κάδο απορριμμάτων;","Τα περιεχόμενα στον κάδο απορριμάτων θα διαγραφούν μετά από {numDays} ημέρα"],
    "Select a calendar" : "Επιλέξτε ένα ημερολόγιο",
    "No calendar matches the search." : "Κανένα ημερολόγιο δεν ταιριάζει με την αναζήτηση.",
    "Set date" : "Ορισμός ημερομηνίας",
    "Set time" : "Ορισμός ώρας",
    "Delete date" : "Διαγραφή ημερομηνίας",
    "Click here to add a note." : "Κάντε κλικ εδώ για να προσθέσετε μια σημείωση.",
    "Set value" : "Ορισμός τιμής",
    "Delete value" : "Διαγραφή τιμής",
    "Add this as a new tag" : "Προσθήκη ως νέα ετικέτα",
    "No tag available. Create one!" : "Δεν υπάρχει διαθέσιμη ετικέτα. Δημιουργήστε μια!",
    "Delete all completed tasks." : "Διαγραφή όλων των ολοκληρωμένων εργασιών.",
    "Delete completed tasks." : "Διαγραφή ολοκληρωμένων εργασιών.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Διαγραφή όλων των ολοκληρωμένων εργασιών από το ημερολόγιο \"{calendar}\".",
    "No errors" : "Κανένα σφάλμα",
    "Open your browser console for more details" : "Ανοίξτε την κονσόλα του περιηγητή για περισσότερες λεπτομέρειες",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Θα διαγραφή η ολοκληρωμένη εργασία του {taskCount} και των υπο εργασιών από το ημερολόγιο \"{calendar}\".","Θα διαγραφούν ολοκληρωμένες εργασίες του {taskCount} και των υπο εργασιών από το ημερολόγιο \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Αδυναμία διαγραφής εργασίας {failedCount}.","Αδυναμία διαγραφής εργασιών {failedCount}."],
    "Add an important task to \"{calendar}\"…" : "Προσθήκη σημαντικής εργασίας στο \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Προσθέστε εργασία για σήμερα στο \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Προσθήκη τρέχουσας εργασίας στο \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Προσθήκη έργασίας στο \"{calendar}\"…",
    "Load all completed tasks." : "Φόρτωση όλων των ολοκληρωμένων εργασιών.",
    "Change sort order" : "Αλλαγή σειράς ταξινόμησης",
    "Relevance" : "Συνάφεια",
    "Sort by completed state, due date, priority, start date and summary." : "Ταξινόμηση κατά ολοκληρωμένη κατάσταση, ημερομηνία λήξης, προτεραιότητα, ημερομηνία έναρξης και σύνοψη.",
    "Start date" : "Ημερομηνία έναρξης",
    "Sort by start date and summary." : "Ταξινόμηση ανά ημερομηνία έναρξης και σύνοψη.",
    "Due date" : "Ημερομηνία λήξης",
    "Sort by due date and summary." : "Ταξινόμηση ανά ημερομηνία λήξης και σύνοψη.",
    "Created date" : "Ημερομηνία δημιουργίας",
    "Sort by created date and summary." : "Ταξινόμηση κατά ημερομηνία δημιουργίας και σύνοψη.",
    "Last modified" : "Τελευταία τροποποίηση",
    "Sort by last-modified date and summary." : "Ταξινόμηση κατά ημερομηνία και σύνοψη τελευταίας τροποποίησης.",
    "Completed date" : "Ημερομηνία ολοκλήρωσης",
    "Sort by completed date." : "Ταξινόμηση κατά ημερομηνία ολοκλήρωσης",
    "Priority" : "Προτεραιότητα",
    "Sort by priority and summary." : "Ταξινόμηση κατά προτεραιότητα και σύνοψη.",
    "Alphabetically" : "Αλφαβητικά",
    "Sort by summary and priority." : "Ταξινόμηση κατά σύνοψη και προτεραιότητα.",
    "Manually" : "Χειροκίνητα",
    "Sort by manual order." : "Ταξινόμηση με χειροκίνητη σειρά.",
    "{complete} % completed" : "Ολοκληρώθηκε το {complete} %",
    "Task has hidden subtasks" : "Η εργασίας έχει κρυφές δευτερεύουσες εργασίες",
    "Task is pinned" : "Η εργασία είναι καρφιτσωμένη",
    "Task has a note" : "Η εργασία έχει μια σημείωση",
    "Add subtask" : "Προσθήκη υποεργασίας",
    "Show subtasks" : "Εμφάνιση υποεργασιών",
    "Hide subtasks" : "Απόκρυψη υποεργασιών",
    "Show closed subtasks" : "Εμφάνιση ολοκληρωμένων υποεργασιών",
    "Hide closed subtasks" : "Απόκρυψη ολοκληρωμένων υποεργασιών",
    "Delete task" : "Διαγραφή εργασίας",
    "Toggle starred" : "Με/Χωρίς αστέρι",
    "[Yesterday]" : "[Χθες]",
    "[Today]" : "[Σήμερα]",
    "[Tomorrow]" : "[Αύριο]",
    "[Completed yesterday]" : "[Ολοκληρώθηκε εχθές]",
    "[Completed today]" : "[Ολοκληρώθηκε σήμερα]",
    "[Completed tomorrow]" : "[Ολοκληρώνεται αύριο]",
    "[Yesterday at] LT" : "[Χθες στις] LT",
    "[Today at] LT" : "[Σήμερα στις] LT",
    "[Tomorrow at] LT" : "[Αύριο στις] LT",
    "L [at] LT" : "L [στις] LT",
    "[Completed yesterday at] LT" : "[Ολοκληρώθηκε χθές στις] LT",
    "[Completed today at] LT" : "[Ολοκληρώθηκε σήμερα στις] LT",
    "[Completed tomorrow at] LT" : "[Ολοκληρώνεται αύριο στις] LT",
    "[Completed] L [at] LT" : "[Ολοκληρώθηκε] L [στις] LT",
    "Add a subtask to \"{task}\"…" : "Προσθήκη υποέργου σε \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Διαγραφή εργασίας σε {countdown} δεύτερα","Διαγραφή εργασίας σε {countdown} δευτερόλεπτα"],
    "Task is cancelled" : "Η εργασία ακυρώθηκε",
    "Task is completed" : "Η εργασία ολοκληρώθηκε",
    "Task is read-only" : "Η εργασία είναι μόνο για ανάγνωση",
    "Task is not completed" : "Η εργασία δεν ολοκληρώθηκε",
    "Create a new task" : "Δημιουργία νέας εργασίας",
    "Task summary" : "Περίληψη εργασίας",
    "Create task" : "Δημιουργία εργασίας",
    "Creating the new task…" : "Δημιουργία νέας εργασίας ...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" προστέθηκε στο \"{calendar}\"",
    "Open task" : "Άνοιγμα εργασίας",
    "Close" : "Κλείσιμο",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Ολοκληρωμένη Εργασία","%n Ολοκληρωμένες Εργασίες"],
    "Tomorrow" : "Αύριο",
    "Add List…" : "Προσθήκη λίστας…",
    "New List" : "Νέα λίστα",
    "All day" : "Ολοήμερο",
    "Unpin" : "Ξεκαρφίτσωμα",
    "Pin" : "Καρφίτσωμα",
    "Show in Calendar" : "Εμφάνιση στο ημερολόγιο",
    "Edit title" : "Επεξεργασία τίτλου",
    "Details" : "Λεπτομέρειες",
    "Select a classification" : "Επιλέξτε μια ταξινόμηση",
    "Select a status" : "Επιλέξτε κατάσταση",
    "Select tags" : "Επιλέξτε ετικέτες",
    "Notes" : "Σημειώσεις",
    "Reminders" : "Υπενθυμίσεις",
    "Repeat" : "Επανάληψη",
    "When shared show full event" : "Όταν είναι σε κοινή χρήση να προβάλλεται το πλήρες συμβάν",
    "When shared show only busy" : "Όταν είναι σε κοινή χρήση να προβάλλονται μόνο απασχολημένοι ",
    "When shared hide this event" : "Απόκρυψη, όταν είναι σε κοινή χρήση",
    "[Completed] L" : "[Ολοκληρώθηκε] L",
    "[Completed last] dddd [at] LT" : "[Ολοκληρώθηκε τελευταία] dddd [στις] LT",
    "[Completed] dddd [at] LT" : "[Ολοκληρώθηκε] dddd [στις] LT",
    "[Last modified yesterday at] LT" : "[Τελευταία τροποποίηση χθες στις] LT",
    "[Last modified today at] LT" : "[Τελευταία τροποποίηση σήμερα στις] LT",
    "[Last modified] L" : "[Τελευταία τροποποίηση] L",
    "[Last modified last] dddd [at] LT" : "[Τελευταία τροποποίηση την προηγούμενη] dddd [στις] LT",
    "[Last modified] dddd [at] LT" : "[Τελευταία τροποποίηση] dddd [στις] LT",
    "[Created yesterday at] LT" : "[Δημιουργήθηκε χθες στις] LT",
    "[Created today at] LT" : "[Δημιουργήθηκε σήμερα στις] LT",
    "[Created] L" : "[Δημιουργήθηκε] L",
    "[Created last] dddd [at] LT" : "[Δημιουργήθηκε την τελευταία] dddd [στις] LT",
    "[Created] dddd [at] LT" : "[Δημιουργήθηκε] dddd [στις] LT",
    "Needs action" : "Χρειάζεται ενέργεια",
    "In process" : "Σε εξέλιξη",
    "Canceled" : "Ακυρώθηκε",
    "Clear status" : "Εκκαθάριση κατάστασης",
    "Loading task from server." : "Φόρτωση εργασίας από διακομιστή.",
    "Task not found!" : "Δεν βρέθηκε εργασία!",
    "[Starts today]" : "[Αρχίζει σήμερα]",
    "[Starts tomorrow]" : "[Αρχίζει αύριο]",
    "[Starts on] LL" : "[Ξεκινά σε] LL",
    "[Started yesterday]" : "[Ξεκίνησε εχθές]",
    "[Started on] LL" : "[Ξεκίνησε] LL",
    "[Started today at] LT" : "[Ξεκίνησε σήμερα στις] LT",
    "[Starts today at] LT" : "[Ξεκινά σήμερα στις] LT",
    "[Starts tomorrow at] LT" : "[Ξεκινά αύριο στις] LT",
    "[Starts on] LL [at] LT" : "[Ξεκινά σε] LL [στις] LT",
    "[Started yesterday at] LT" : "[Ξεκίνησε εχθές στις] LT",
    "[Started on] LL [at] LT" : "[Ξεκίνησε] LL [στις] LT",
    "Set start date" : "Ορισμός ημερομηνίας έναρξης",
    "[Due today]" : "[Λήγει σήμερα]",
    "[Due tomorrow]" : "[Λήγει αύριο]",
    "[Due on] LL" : "[Έως στις] LL",
    "[Was due yesterday]" : "[Έληγε εχθές]",
    "[Was due on] LL" : "[Έληγε στις] LL",
    "[Was due today at] LT" : "[Έληγε σήμερα στις] LT",
    "[Due today at] LT" : "[Λήξη σήμερα στις] LT",
    "[Due tomorrow at] LT" : "[Λήγει αύριο στις] LT",
    "[Due on] LL [at] LT" : "[Λήγει σε] LL [στις] LT",
    "[Was due yesterday at] LT" : "[Έληγε χθες στις] LT",
    "[Was due on] LL [at] LT" : "[Έληγε την] LL [στις] LT",
    "Set due date" : "Ορισμός ημερομηνίας λήξης",
    "Priority {priority}: low" : "Προτεραιότητα {priority}: χαμηλή",
    "Priority {priority}: medium" : "Προτεραιότητα {priority}: μεσαία",
    "Priority {priority}: high" : "Προτεραιότητα {priority}: υψηλή",
    "No priority assigned" : "Δεν έχει οριστεί προτεραιότητα",
    "{percent} % completed" : "{complete} % ολοκληρωμένες",
    "No upcoming tasks" : "Δεν υπάρχουν επερχόμενες εργασίες",
    "upcoming tasks" : "επερχόμενες εργασίες",
    "No tasks today" : "Δεν υπάρχουν εργασίες σήμερα",
    "Mark as done" : "Σήμανση ως ολοκληρωμένου",
    "No due date assigned" : "Δεν έχει οριστεί ημερομηνία λήξης",
    "[Due yesterday]" : "[Έληξε χθες]",
    "[Due] L" : "[Λήγει] L",
    "[Due yesterday at] LT" : "[Έληξε χθες στις] LT",
    "[Due] L [at] LT" : "[Λήγει σε] L [στις] LT",
    "Successfully created the task." : "Επιτυχής δημιουργία εργασίας.",
    "Could not delete the task." : "Αδυναμία διαγραφής εργασίας.",
    "Synchronizing to the server." : "Συγχρονισμός με τον διακομιστή.",
    "Task successfully saved to server." : "Η εργασία αποθηκεύτηκε επιτυχώς στον διακομιστή.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Δεν ήταν δυνατή η ενημέρωση της εργασίας επειδή άλλαξε στον διακομιστή. Κλικ για ανανέωση, οι τοπικές αλλαγές θα διαγραφούν.",
    "Could not update the task." : "Αδυναμία ενημέρωσης της εργασίας.",
    "Successfully updated the task." : "Επιτυχής ενημέρωση εργασίας.",
    "Task successfully moved to new calendar." : "Η Εργασία μεταφέρθηκε επιτυχώς στο νέο ημερολόγιο.",
    "An error occurred" : "Παρουσιάστηκε σφάλμα",
    "Create a task" : "Δημιουργήστε μια εργασία",
    "Message from {author} in {conversationName}" : "Μήνυμα από {author} σε {conversationName}"
},
"nplurals=2; plural=(n != 1);");
