OC.L10N.register(
    "tasks",
    {
    "Important" : "Wichteg",
    "Today" : "Haut",
    "Week" : "Woch",
    "All" : "All",
    "Current" : "Aktuell",
    "Completed" : "Erfëllt",
    "Tasks" : "Tâchen",
    "Hidden" : "Verstoppt",
    "Visible" : "Visibel",
    "Automatic" : "Automatesch",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "Edit" : "Änneren",
    "Delete" : "Läschen",
    "Unshare" : "Net méi deelen",
    "Cancel" : "Ofbriechen",
    "Save" : "Späicheren",
    "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n erfëllt Aufgab","%n erfëllten Aufgaben"],
    "Tomorrow" : "Muer",
    "New List" : "Nei Lëscht",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Task not found!" : "Tâche konnt net fonnt ginn!",
    "Set start date" : "Setz en Ufanks Datum fest",
    "Set due date" : "Datum setzen bis wéini et fälleg ass"
},
"nplurals=2; plural=(n != 1);");
