OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Artėjančios užduotys",
    "Important" : "Svarbios",
    "Today" : "Šiandien",
    "Week" : "Savaitė",
    "All" : "Visos",
    "Current" : "Dabartinės",
    "Completed" : "Atliktos",
    "Tasks" : "Užduotys",
    "The Tasks app for Nextcloud" : "Užduočių programėlė, skirta Nextcloud",
    "Default list" : "Numatytasis sąrašas",
    "Visibility of Smart Collections" : "Išmaniųjų rinkinių matomumas",
    "Hidden" : "Paslėpta",
    "Visible" : "Matoma",
    "Automatic" : "Automatiškai",
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
    "Unable to delete the share." : "Nepavyko ištrinti viešinio.",
    "Unable to change permissions." : "Nepavyko pakeisti leidimų.",
    "Edit" : "Taisyti",
    "Copy private link" : "Kopijuoti privačią nuorodą",
    "Copied" : "Nukopijuota",
    "Cannot copy" : "Nepavyksta nukopijuoti",
    "Delete" : "Ištrinti",
    "Unshare" : "Nustoti bendrinti",
    "Cancel" : "Atsisakyti",
    "Save" : "Įrašyti",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tai ištrins kalendorių \"{calendar}\" ir visus atitinkamus įvykius bei užduotis.",
    "This will unshare the calendar \"{calendar}\"." : "Tai nustos bendrinti kalendorių \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Tai ištrins sąrašą „{list}“ ir visas atitinkamas užduotis.",
    "This will unshare the list \"{list}\"." : "Tai nustos bendrinti sąrašą „{list}“.",
    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
    "List link copied to clipboard." : "Sąrašo nuoroda nukopijuota į iškarpinę.",
    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
    "List link could not be copied to clipboard." : "Nepavyko nukopijuoti sąrašo nuorodos į iškarpinę.",
    "The name \"{calendar}\" is already used." : "Pavadinimas \"{calendar}\" jau yra naudojamas.",
    "An empty name is not allowed." : "Pavadinimas yra būtinas",
    "An error occurred, unable to delete the calendar." : "Įvyko klaida, nepavyko ištrinti kalendorių.",
    "An error occurred, unable to delete the list." : "Įvyko klaida, nepavyko ištrinti sąrašo.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendorius ištrinamas po {countdown} sekundės","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundės"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendorius nustojamas bendrinti po {countdown} sekundės","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundės"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Bendrinama su {num} esybe","Bendrinama su {num} esybėmis","Bendrinama su {num} esybių","Bendrinama su {num} esybe"],
    "Trash bin" : "Šiukšlinė",
    "Restore" : "Atkurti",
    "Unknown calendar" : "Nežinomas kalendorius",
    "Could not load deleted calendars and objects" : "Nepavyko įkelti ištrintų kalendorių ir objektų",
    "Could not delete calendar or event" : "Nepavyko ištrinti kalendoriaus ar įvykio",
    "Could not restore calendar or event" : "Nepavyko atkurti kalendoriaus ar įvykio",
    "Set date" : "Nustatyti datą",
    "Set time" : "Nustatyti laiką",
    "Delete date" : "Ištrinti datą",
    "Delete all completed tasks." : "Ištrinti visas atliktas užduotis.",
    "Delete completed tasks." : "Ištrinti atliktas užduotis.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Ištrinti visas atliktas užduotis iš kalendoriaus \"{calendar}\".",
    "No errors" : "Klaidų nėra",
    "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Tai ištrins {taskCount} atliktą užduotį ir jos dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktas užduotis ir jų dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktų užduočių ir jų dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktą užduotį ir jų dalines užduotis iš kalendoriaus „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nepavyko ištrinti {failedCount} užduoties.","Nepavyko ištrinti {failedCount} užduočių.","Nepavyko ištrinti {failedCount} užduočių.","Nepavyko ištrinti {failedCount} užduoties."],
    "Add an important task to \"{calendar}\"…" : "Pridėti svarbią užduotį į \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Pridėti užduotį, kurios galutinis terminas šiandien į kalendorių \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Pridėti dabartinę užduotį į \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Pridėti užduotį į \"{calendar}\"…",
    "Load all completed tasks." : "Įkelti visas atliktas užduotis.",
    "Change sort order" : "Keisti rikiavimo tvarką",
    "Sort by completed state, due date, priority, start date and summary." : "Rikiuoti pagal atlikimo būseną, galutinio termino datą, pirmenybę, pradžios datą bei santrauką.",
    "Start date" : "Pradžios data",
    "Sort by start date and summary." : "Rikiuoti pagal pradžios datą bei santrauką.",
    "Due date" : "Galutinis terminas",
    "Sort by due date and summary." : "Rikiuoti pagal galutinio termino datą bei santrauką.",
    "Created date" : "Sukūrimo data",
    "Sort by created date and summary." : "Rikiuoti pagal sukūrimo datą bei santrauką.",
    "Last modified" : "Paskutinis modifikavimas",
    "Sort by last-modified date and summary." : "Rikiuoti pagal paskutinio modifikavimo datą bei santrauką.",
    "Completed date" : "Atlikimo data",
    "Sort by completed date." : "Rikiuoti pagal atlikimo datą.",
    "Priority" : "Pirmenybė",
    "Sort by priority and summary." : "Rikiuoti pagal pirmenybę bei santrauką.",
    "Alphabetically" : "Pagal abėcėlę",
    "Sort by summary and priority." : "Rikiuoti pagal santrauką bei pirmenybę.",
    "Manually" : "Rankiniu būdu",
    "Sort by manual order." : "Rikiuoti rankine tvarka.",
    "{complete} % completed" : "{complete}% atlikta",
    "Add subtask" : "Pridėti dalinę užduotį",
    "Show subtasks" : "Rodyti dalines užduotis",
    "Hide subtasks" : "Slėpti dalines užduotis",
    "Delete task" : "Ištrinti užduotį",
    "[Yesterday]" : "[Vakar]",
    "[Today]" : "[Šiandien]",
    "[Tomorrow]" : "[Rytoj]",
    "Add a subtask to \"{task}\"…" : "Pridėti dalinę užduotį į „{task}“…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Užduotis ištrinama po {countdown} sekundės","Užduotis ištrinama po {countdown} sekundžių","Užduotis ištrinama po {countdown} sekundžių","Užduotis ištrinama po {countdown} sekundės"],
    "Task is completed" : "Užduotis atlikta",
    "Create a new task" : "Sukurti naują užduotį",
    "Create task" : "Sukurti užduotį",
    "Creating the new task…" : "Kuriama nauja užduotis…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n atlikta užduotis","%n atliktos užduotys","%n atliktų užduočių","%n atlikta užduotis"],
    "Tomorrow" : "Rytoj",
    "Add List…" : "Pridėti sąrašą…",
    "New List" : "Naujas sąrašas",
    "All day" : "Visą dieną",
    "Unpin" : "Atsegti",
    "Pin" : "Prisegti",
    "Show in Calendar" : "Rodyti kalendoriuje",
    "Select a classification" : "Pasirinkite klasifikavimą",
    "Select a status" : "Pasirinkite būseną",
    "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
    "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
    "Needs action" : "Reikalauja veiksmo",
    "In process" : "Eigoje",
    "Canceled" : "Atsisakyta",
    "Loading task from server." : "Įkeliama užduotis iš serverio.",
    "Task not found!" : "Užduotis nerasta!",
    "[Starts today]" : "[Prasideda šiandien]",
    "[Starts tomorrow]" : "[Prasidės rytoj]",
    "[Starts on] LL" : "[Prasidės] LL",
    "[Started yesterday]" : "[Prasidėjo vakar]",
    "[Started on] LL" : "[Prasidėjo] LL",
    "[Started today at] LT" : "[Prasidėjo šiandien] LT",
    "[Starts today at] LT" : "[Prasidės šiandien] LT",
    "[Starts tomorrow at] LT" : "[Prasidės rytoj] LT",
    "[Starts on] LL [at] LT" : "[Prasidės] LL, LT",
    "[Started yesterday at] LT" : "[Prasidėjo vakar] LT",
    "[Started on] LL [at] LT" : "[Prasidėjo] LL, LT",
    "Set start date" : "Nustatyti pradžios datą",
    "[Due today]" : "[Galutinis terminas šiandien]",
    "[Due tomorrow]" : "[Galutinis terminas rytoj]",
    "[Due on] LL" : "[Galutinis terminas] LL",
    "[Was due yesterday]" : "[Galutinis terminas buvo vakar]",
    "[Was due on] LL" : "[Galutinis terminas buvo] LL",
    "[Was due today at] LT" : "[Galutinis terminas buvo šiandien] LT",
    "[Due today at] LT" : "[Galutinis terminas šiandien] LT",
    "[Due tomorrow at] LT" : "[Galutinis terminas rytoj] LT",
    "[Due on] LL [at] LT" : "[Galutinis terminas] LL, LT",
    "[Was due yesterday at] LT" : "[Galutinis terminas buvo vakar] LT",
    "[Was due on] LL [at] LT" : "[Galutinis terminas buvo] LL, LT",
    "Set due date" : "Nustatyti galutinį terminą",
    "Priority {priority}: low" : "Pirmenybė {priority}: žema",
    "Priority {priority}: medium" : "Pirmenybė {priority}: vidutinė",
    "Priority {priority}: high" : "Pirmenybė {priority}: aukšta",
    "No priority assigned" : "Pirmenybė nepriskirta",
    "{percent} % completed" : "{percent} % atlikta",
    "No upcoming tasks" : "Artėjančių užduočių nėra",
    "Successfully created the task." : "Užduotis sėkmingai sukurta.",
    "Could not delete the task." : "Nepavyko ištrinti užduoties.",
    "Synchronizing to the server." : "Sinchronizuojama į serverį.",
    "Task successfully saved to server." : "Užduotis sėkmingai įrašyta į serverį.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nepavyko atnaujinti užduoties, nes ji buvo pakeista serveryje. Spustelėkite, kad įkeltumėte ją iš naujo, vietiniai pakeitimai bus atmesti.",
    "Could not update the task." : "Nepavyko atnaujinti užduoties.",
    "Successfully updated the task." : "Užduotis sėkmingai atnaujinta.",
    "Task successfully moved to new calendar." : "Užduotis sėkmingai perkelta į naują kalendorių.",
    "An error occurred" : "Įvyko klaida",
    "Create a task" : "Sukurti užduotį"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
