OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Данас",
    "Week" : "Недеља",
    "All" : "Све",
    "Current" : "Текуће",
    "Completed" : "Завршено",
    "Tasks" : "Задаци",
    "The Tasks app for Nextcloud" : "Некстклауд апликација за задатке",
    "Default list" : "Подразумевани списак",
    "Visibility of Smart Collections" : "Видљивост паметних збирки",
    "Hidden" : "Сакривен",
    "Visible" : "Видљив",
    "Automatic" : "Аутоматски",
    "Share with users or groups" : "Дели са корисницима или групама",
    "No users or groups" : "Нема корисника или група",
    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
    "Unable to delete the share." : "Не могу да обришем дељење.",
    "Unable to change permissions." : "Не могу да променим привилегије.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватну везу",
    "Copied" : "Копирано",
    "Delete" : "Обриши",
    "Unshare" : "Укини дељење",
    "Cancel" : "Откажи",
    "Save" : "Сачувај",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ово ће обрисати календар „{calendar}“ и све догађаје и задатке из њега.",
    "This will unshare the calendar \"{calendar}\"." : "Овим ћете уклонити дељење календара „{calendar}”",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ово ће обрисати списак „{list}“ и све задатке из њега.",
    "This will unshare the list \"{list}\"." : "Овим ћете уклонити дељење списка „{list}”.",
    "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
    "List link copied to clipboard." : "Веза ка списку копирана у оставу.",
    "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
    "List link could not be copied to clipboard." : "Веза ка списку није могла бити копирана у оставу.",
    "The name \"{calendar}\" is already used." : "Име календара „{calendar}“ се већ користи.",
    "An empty name is not allowed." : "Празан назив није дозвољен.",
    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
    "An error occurred, unable to delete the list." : "Догодила се грешка, не могу да обришем списак.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришем календар за {countdown} секунду","Бришем календар за {countdown} секунде","Бришем календар за {countdown} секунди"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Уклањам дељење календара за {countdown} секунду","Уклањам дељење календара за {countdown} секунде","Уклањам дељење календара за {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Брисање списка за {countdown} секунду","Брисање списка за {countdown} секунде","Брисање списка за {countdown} секунди"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Уклањем дељење списка за {countdown} секунду","Уклањем дељење списка за {countdown} секунде","Уклањем дељење списка за {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Дељено са {num} ентитетом","Дељено са {num} ентитета","Дељено са {num} ентитета"],
    "Delete all completed tasks." : "Обриши све завршене задатке.",
    "Delete completed tasks." : "Обриши завршене задатке.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Обриши све завршене задатке из календара „{calendar}“.",
    "No errors" : "Нема грешака",
    "Open your browser console for more details" : "Отворите конзолу веб читача за више детаља",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ово ће обрисати {taskCount} завршени задатак и све његове подзадатке из календара „{calendar}“.","Ово ће обрисати {taskCount} завршена задатка и све њихове подзадатке из календара „{calendar}“.","Ово ће обрисати {taskCount} завршених задатака и све њихове подзадатке из календара „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Нисам могао да обришем {failedCount} задатак.","Нисам могао да обришем {failedCount} задатка.","Нисам могао да обришем {failedCount} задатака."],
    "Add an important task to \"{calendar}\"…" : "Додај важан задатак на календар „{calendar}“…",
    "Add a task due today to \"{calendar}\"…" : "Додај задатак са роком за данас на календар „{calendar}“…",
    "Add a current task to \"{calendar}\"…" : "Додај тренутни задатак на календар „{calendar}“…",
    "Add a task to \"{calendar}\"…" : "Додај задатак на календар „{calendar}“…",
    "Load all completed tasks." : "Учитај све завршене задатке.",
    "Change sort order" : "Промени сортирање",
    "Relevance" : "Релевантност",
    "Sort by completed state, due date, priority, start date and summary." : "Сортирај по стању завршетка, року, приоритету, датуму почетка и опису.",
    "Start date" : "Датум почетка",
    "Sort by start date and summary." : "Сортирај по датуму почетка и опису.",
    "Due date" : "Рок",
    "Sort by due date and summary." : "Сортирај по року и опису",
    "Created date" : "Датум креирања",
    "Sort by created date and summary." : "Сортирај по датуму креирања и опису.",
    "Last modified" : "Последње измењено",
    "Sort by last-modified date and summary." : "Сортирај по времену последње промене и опису.",
    "Completed date" : "Датум завршетка",
    "Sort by completed date." : "Сортирај по датуму завршетка",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Сортирај по приоритету и опису.",
    "Alphabetically" : "Азбучно",
    "Sort by summary and priority." : "Сортирај по опису и приоритету.",
    "Manually" : "Ручно",
    "Sort by manual order." : "Сортирај ручно.",
    "{complete} % completed" : "{complete} % завршено",
    "Add subtask" : "Додај подзадатак",
    "Show subtasks" : "Прикажи подзадатке",
    "Hide subtasks" : "Сакриј подзадатке",
    "Delete task" : "Обриши задатак",
    "[Yesterday]" : "[Јуче]",
    "[Today]" : "[Данас]",
    "[Tomorrow]" : "[Сутра]",
    "[Completed yesterday]" : "[Завршено јуче]",
    "[Completed today]" : "[Завршено данас]",
    "[Completed tomorrow]" : "[Завршено сутра]",
    "[Yesterday at] LT" : "[Јуче у] LT",
    "[Today at] LT" : "[Данас у] LT",
    "[Tomorrow at] LT" : "[Сутра у] LT",
    "L [at] LT" : "L [у] LT",
    "[Completed yesterday at] LT" : "[Завршено јуче у] LT",
    "[Completed today at] LT" : "[Завршено данас у] LT",
    "[Completed tomorrow at] LT" : "[Завршено сутра у] LT",
    "[Completed] L [at] LT" : "[Завршено] L [у] LT",
    "Add a subtask to \"{task}\"…" : "Додај подзадатак на задатак „{task}“…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Бришем задатак за {countdown} секунду","Бришем задатак за {countdown} секунде","Бришем задатак за {countdown} секунди"],
    "Task is completed" : "Задатак завршен",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завршен задатак","%n завршена задатка","%n завршених задатака"],
    "Tomorrow" : "сутра",
    "Add List…" : "Додај листу…",
    "New List" : "Нова листа",
    "All day" : "Цео дан",
    "Select a classification" : "Одаберите класификацију",
    "Select a status" : "Одаберите статус",
    "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
    "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
    "When shared hide this event" : "Сакриј догађај када је догађај дељен",
    "Needs action" : "Акција потребна",
    "In process" : "У процесу",
    "Canceled" : "Отказано",
    "Loading task from server." : "Учитавам задатке са сервера.",
    "Task not found!" : "Задатак није пронађен!",
    "[Starts today]" : "[Почиње данас]",
    "[Starts tomorrow]" : "[Почиње сутра]",
    "[Starts on] LL" : "[Почиње] LL",
    "[Started yesterday]" : "[Започет јуче]",
    "[Started on] LL" : "[Почео] LL",
    "[Started today at] LT" : "[Почео данас у] LT",
    "[Starts today at] LT" : "[Почиње данас у] LT",
    "[Starts tomorrow at] LT" : "[Почиње сутра у] LT",
    "[Starts on] LL [at] LT" : "[Почиње] LL [у] LT",
    "[Started yesterday at] LT" : "[Почео јуче у] LT",
    "[Started on] LL [at] LT" : "[Почео] LL [у] LT",
    "Set start date" : "Постави датум почетка",
    "[Due today]" : "[Рок данас]",
    "[Due tomorrow]" : "[Рок сутра]",
    "[Due on] LL" : "[Рок до] LL",
    "[Was due yesterday]" : "[рок је био јуче]",
    "[Was due on] LL" : "[Рок био до] LL",
    "[Was due today at] LT" : "[Рок био данас у] LT",
    "[Due today at] LT" : "[Рок до данас у] LT",
    "[Due tomorrow at] LT" : "[Рок сутра у] LT",
    "[Due on] LL [at] LT" : "[Рок до] LL [у] LT",
    "[Was due yesterday at] LT" : "[Рок био јуче у] LT",
    "[Was due on] LL [at] LT" : "[Рок био] LL [у] LT",
    "Set due date" : "Постави датум рока",
    "Priority {priority}: low" : "Приоритет {priority}: мали",
    "Priority {priority}: medium" : "Приоритет {priority}: средњи",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Нема додељеног приоритета",
    "{percent} % completed" : "{percent} % завршено",
    "Successfully created the task." : "Задатак успешно избрисан.",
    "Could not delete the task." : "Не могу да обришем задатак.",
    "Synchronizing to the server." : "Синхронизујем са сервером.",
    "Task successfully saved to server." : "Задатак успешно сачуван на серверу.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не могу да ажурирам задатак пошто је промењен на серверу. Кликните да га освежите, а локалне измене ће бити одбачене.",
    "Could not update the task." : "Не могу да ажурирам задатак.",
    "Successfully updated the task." : "Задатак успешно ажуриран.",
    "Task successfully moved to new calendar." : "Задатак успешно померен у нови календар.",
    "An error occurred" : "Догодила се грешка"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
