OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Ожидающие выполнения",
    "Important" : "Важно",
    "Today" : "Сегодня",
    "Week" : "На неделе",
    "All" : "Все",
    "Current" : "Текущие",
    "Completed" : "Завершённые",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Задачи для Nextcloud",
    "Default list" : "Список по умолчанию:",
    "Visibility of Smart Collections" : "Настройка показа наборов задач:",
    "Hidden" : "Скрывать",
    "Visible" : "Показывать",
    "Automatic" : "Автоматически",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "Can edit" : "Разрешить редактировать",
    "Unshare with {displayName}" : "Отменить общий доступ для {displayName}",
    "Unable to delete the share." : "Невозможно закрыть общий доступ.",
    "Unable to change permissions." : "Невозможно изменить права доступа.",
    "Edit" : "Редактировать",
    "Copy private link" : "Скопировать закрытую ссылку",
    "Copied" : "Скопировано",
    "Cannot copy" : "Не удалось скопировать",
    "Delete" : "Удалить",
    "Unshare" : "Закрыть доступ",
    "Cancel" : "Отмена",
    "Save" : "Сохранить",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Это действие удалит календарь «{calendar}», в том числе все его события и задачи.",
    "This will unshare the calendar \"{calendar}\"." : "Это действие приведёт к закрытию общего доступа к календарю «{calendar}».",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Это приведет к удалению списка \"{list}\" и всех соответствующих задач.",
    "This will unshare the list \"{list}\"." : "Это приведет к отмене общего доступа к списку \"{list}\".",
    "Calendar link copied to clipboard." : "Ссылка на календарь скопирована в буфер обмена.",
    "List link copied to clipboard." : "Ссылка на список скопирована в буфер обмена.",
    "Calendar link could not be copied to clipboard." : "Не удалось скопировать ссылку на календарь в буфер обмена.",
    "List link could not be copied to clipboard." : "Ссылка на список не может быть скопирована в буфер обмена.",
    "The name \"{calendar}\" is already used." : "Название «{calendar}» уже используется.",
    "An empty name is not allowed." : "Пустые имена не допускаются.",
    "An error occurred, unable to delete the calendar." : "Произошла ошибка, не удалось удалить календарь.",
    "An error occurred, unable to delete the list." : "Произошла ошибка, невозможно удалить список.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календарь будет удалён через {countdown} секунды","Календари будут удалены через {countdown} секунды","Календари будут удалены через {countdown} секунды","Календарь будет удалён через {countdown} секунды"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Общий доступ к календарю будет закрыт через {countdown} секунды","Общий доступ к календарям будет закрыт через {countdown} секунды","Общий доступ к календарям будет закрыт через {countdown} секунды","Общий доступ к календарю будет закрыт через {countdown} секунды"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Удаление списка через {countdown} сек.","Удаление списка через {countdown} сек.","Удаление списка через {countdown} сек.","Удаление списка через {countdown} сек."],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Отмена публикации списка через {countdown} сек.","Отмена публикации списка через {countdown} сек.","Отмена публикации списка через {countdown} сек.","Отмена публикации списка через {countdown} сек."],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Совместный доступ с {num} получателем","Совместный доступ с {num} получателями","Совместный доступ с {num} получателями","Совместный доступ с {num} получателями"],
    "Trash bin" : "Корзина",
    "Loading deleted calendars, tasks and events." : "Загрузка удалённых календарей, задач и событий.",
    "You do not have any deleted calendars, tasks or events." : "У вас нет удалённых календарей, задач или событий.",
    "Name" : "Название",
    "Deleted" : "Удалено",
    "Restore" : "Восстановить",
    "Delete permanently" : "Удалить безвозвратно",
    "Empty trash bin" : "Очистить корзину",
    "Untitled task" : "Задача без названия",
    "Untitled event" : "Событие без названия",
    "Untitled journal" : "Журнал без названия",
    "Untitled item" : "Объект без названия",
    "Unknown calendar" : "Неизвестный календарь",
    "Could not load deleted calendars and objects" : "Не удалось загрузить удалённые календари и объекты",
    "Could not delete calendar or event" : "Не удалось удалить календарь или событие",
    "Could not restore calendar or event" : "Не удалось восстановить календарь или событие",
    "Do you really want to empty the trash bin?" : "Подтвердите очистку корзины.",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Объекты в корзине будут удалены через {numDays} день","Объекты в корзине будут удалены через {numDays} дня","Объекты в корзине будут удалены через {numDays} дней","Объекты в корзине будут удалены через {numDays} дня"],
    "Select a calendar" : "Выбрать календарь",
    "No calendar matches the search." : "Ни один календарь не соответствует критерию поиска.",
    "Set date" : "Задать дату",
    "Set time" : "Задать время",
    "Delete date" : "Удалить дату",
    "Click here to add a note." : "Нажмите, чтобы добавить заметку.",
    "Set value" : "Установить значение",
    "Delete value" : "Удалить значение",
    "Add this as a new tag" : "Добавить как новую метку",
    "No tag available. Create one!" : "Пока нет ни одной метки, создайте первую.",
    "Delete all completed tasks." : "Удалить все завершённые задачи",
    "Delete completed tasks." : "Удалить все завершённые задачи",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Из календаря {calendar} удалены все завершённые задачи.",
    "No errors" : "Выполнено без ошибок.",
    "Open your browser console for more details" : "Подробные сведения приведены в консоли браузера",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Это действие приведёт к удалению {taskCount} завершённой задачи и её подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Не удалось удалить {failedCount} задачу.","Не удалось удалить {failedCount} задач.","Не удалось удалить {failedCount} задач.","Не удалось удалить {failedCount} задач."],
    "Add an important task to \"{calendar}\"…" : "Добавить в «{calentar}» важную задачу…",
    "Add a task due today to \"{calendar}\"…" : "Добавить в «{calendar}» задачу на сегодня… ",
    "Add a current task to \"{calendar}\"…" : "Добавить в «{calendar}» текущую задачу…",
    "Add a task to \"{calendar}\"…" : "Создать задачу в календаре «{calendar}»…",
    "Load all completed tasks." : "Показать завершённые задачи",
    "Change sort order" : "Изменение порядка сортировки.",
    "Relevance" : "Актуальность",
    "Sort by completed state, due date, priority, start date and summary." : "Сортировка по состоянию, дате окончания, приоритету, дате начала и описанию.",
    "Start date" : "Дата начала",
    "Sort by start date and summary." : "Сортировка по дате начала и описанию.",
    "Due date" : "Дата исполнения",
    "Sort by due date and summary." : "Сортировка по дате исполнения и описанию.",
    "Created date" : "Дата создания",
    "Sort by created date and summary." : "Сортировать по дате создания и описанию.",
    "Last modified" : "Последнее изменение",
    "Sort by last-modified date and summary." : "Сортирововка по последнему изменению и описанию.",
    "Completed date" : "Дата выполнения",
    "Sort by completed date." : "Сортировка по дате выполнения.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Сортировка по приоритету и описанию.",
    "Alphabetically" : "По алфавиту",
    "Sort by summary and priority." : "Сортировка по описанию и приоритету.",
    "Manually" : "Вручную",
    "Sort by manual order." : "Сортировка вручную.",
    "{complete} % completed" : "Выполнено {complete}%",
    "Task has hidden subtasks" : "Задача содержит скрытые подзадачи",
    "Task is pinned" : "Задача закреплена",
    "Task has a note" : "Задача содержит заметку",
    "Add subtask" : "Добавить вложенную задачу",
    "Show subtasks" : "Показать вложенные задачи",
    "Hide subtasks" : "Скрыть вложенные задачи",
    "Show closed subtasks" : "Показать закрытые подзадачи",
    "Hide closed subtasks" : "Скрыть закрытые подзадачи",
    "Delete task" : "Удалить задачу",
    "Toggle starred" : "Добавить или убрать отметку",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Сегодня]",
    "[Tomorrow]" : "[Завтра]",
    "[Completed yesterday]" : "[Завершено вчера]",
    "[Completed today]" : "[Завершено сегодня]",
    "[Completed tomorrow]" : "[Завершено завтра]",
    "[Yesterday at] LT" : "[Вчера в] LT",
    "[Today at] LT" : "[Сегодня в] LT",
    "[Tomorrow at] LT" : "[Завтра в] LT",
    "L [at] LT" : "L [в] LT",
    "[Completed yesterday at] LT" : "[Завершено вчера в] LT",
    "[Completed today at] LT" : "[Завершено сегодня в] LT",
    "[Completed tomorrow at] LT" : "[Завершено завтра в] LT",
    "[Completed] L [at] LT" : "[Завершено] L [в] LT",
    "Add a subtask to \"{task}\"…" : "Добавить вложенную задачу в «{task}»…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Задача будет удалена через {countdown} секунду","Задача будет удалена через {countdown} секунды","Задача будет удалена через {countdown} секунд","Задача будет удалена через {countdown} секунды"],
    "Task is completed" : "Задача завершена",
    "Create a new task" : "Создать задачу",
    "Task summary" : "Сводные данные",
    "Create task" : "Создать задачу",
    "Creating the new task…" : "Создание задачи…",
    "\"{task}\" was added to \"{calendar}\"" : "Задача «{task}» добавлена в календарь «{calendar}»",
    "Open task" : "Открыть задачу",
    "Close" : "Закрыть",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершённая задача","%n завершённых задачи","%n завершённых задач","%n завершённых задач"],
    "Tomorrow" : "Завтра",
    "Add List…" : "Добавить список…",
    "New List" : "Новый список",
    "All day" : "Весь день",
    "Unpin" : "Открепить",
    "Pin" : "Закрепить",
    "Show in Calendar" : "Показывать в календаре",
    "Edit title" : "Редактировать заголовок",
    "Details" : "Свойства",
    "Select a classification" : "Выбрать классификацию",
    "Select a status" : "Выберите состояние",
    "Select tags" : "Выбор меток",
    "Notes" : "Заметки",
    "Reminders" : "Напоминания",
    "Repeat" : "Повтор",
    "When shared show full event" : "Показывать подробно при размещении в общем доступе",
    "When shared show only busy" : "Показывать только занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "[Completed] L" : "[Завершено] L",
    "[Completed last] dddd [at] LT" : "[Completed last] дддд [at] местному времени",
    "[Completed] dddd [at] LT" : "[Завершено] dddd [в] LT",
    "[Last modified yesterday at] LT" : "[Последнее изменение вчера в] LT",
    "[Last modified today at] LT" : "[Последнее изменение сегодня в] LT",
    "[Last modified] L" : "[Последнее изменение] L",
    "[Last modified last] dddd [at] LT" : "[Last modified last] дддд [at] местному времени",
    "[Last modified] dddd [at] LT" : "[Последнее изменение] dddd [в] LT",
    "[Created yesterday at] LT" : "[Создано вчера в] LT",
    "[Created today at] LT" : "[Создано вчера в] LT",
    "[Created] L" : "[Создано] L",
    "[Created last] dddd [at] LT" : "[Дата создания: прошедший ] dddd [в] LT",
    "[Created] dddd [at] LT" : "[Создано] dddd [в] LT",
    "Needs action" : "Требуется действие",
    "In process" : "Выполянется",
    "Canceled" : "Отменено",
    "Clear status" : "Удалить статус",
    "Loading task from server." : "Получение с сервера списка задач.",
    "Task not found!" : "Задача не найдена",
    "[Starts today]" : "[Начало сегодня]",
    "[Starts tomorrow]" : "[Начало завтра]",
    "[Starts on] LL" : "[Начало] LL",
    "[Started yesterday]" : "[Начато вчера]",
    "[Started on] LL" : "[Начато] LL",
    "[Started today at] LT" : "[Начало сегодня в] LT",
    "[Starts today at] LT" : "[Начато сегодня в] LT",
    "[Starts tomorrow at] LT" : "[Начало завтра в] LT",
    "[Starts on] LL [at] LT" : "[Начало] LL [в] LT ",
    "[Started yesterday at] LT" : "[Начато вчера в] LT",
    "[Started on] LL [at] LT" : "[Начато] LL [в] LT",
    "Set start date" : "Задать дату начала",
    "[Due today]" : "[Завершение сегодня]",
    "[Due tomorrow]" : "[Завершение завтра]",
    "[Due on] LL" : "[Завершение] LL",
    "[Was due yesterday]" : "[Должно было быть завершено вчера]",
    "[Was due on] LL" : "[Должно было быть завершено] LL",
    "[Was due today at] LT" : "[Должно было быть завершено сегодня в] LT",
    "[Due today at] LT" : "[Должно быть завершено сегодня в] LT",
    "[Due tomorrow at] LT" : "[Должно быть завершено завтра в] LT",
    "[Due on] LL [at] LT" : "[До] LL, LT",
    "[Was due yesterday at] LT" : "[Должно было быть завершено в] LT",
    "[Was due on] LL [at] LT" : "[Должно было быть завершено] LL [в] LT",
    "Set due date" : "Задать дату исполнения",
    "Priority {priority}: low" : "Приоритет {priority}: низкий",
    "Priority {priority}: medium" : "Приоритет {priority}: средний",
    "Priority {priority}: high" : "Приоритет {priority}: высокий",
    "No priority assigned" : "Приоритет не задан",
    "{percent} % completed" : "Выполнение: {percent}%",
    "No upcoming tasks" : "Приближающиеся задачи отсуствуют",
    "upcoming tasks" : "Ожидающие выполнения",
    "No tasks today" : "На сегодня нет задач",
    "Mark as done" : "Отметить как выполненную",
    "No due date assigned" : "Без назначенной даты",
    "[Due yesterday]" : "[Должно было быть завершено вчера]",
    "[Due] L" : "[Должно было быть завершено] L",
    "[Due yesterday at] LT" : "[Должно было быть завершено вчера в] LT",
    "[Due] L [at] LT" : "[Должно было быть завершено] L [в] LT",
    "Successfully created the task." : "Задача создана.",
    "Could not delete the task." : "Не удалось удалить задачу.",
    "Synchronizing to the server." : "Синхронизация с сервером…",
    "Task successfully saved to server." : "Задача сохранена на сервере.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не удалось обновить задачу, так как она была изменена на сервере. Нажмите для получения обновлённой задачи с сервера, внесённые изменения не будут сохранены.",
    "Could not update the task." : "Не удалось обновить задачу.",
    "Successfully updated the task." : "Задача обновлена.",
    "Task successfully moved to new calendar." : "Задача перемещена в новый календарь.",
    "An error occurred" : "Произошла ошибка",
    "Create a task" : "Создать задачу",
    "Message from {author} in {conversationName}" : "Сообщение от {author} из беседы «{conversationName}»"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
