OC.L10N.register(
    "tasks",
    {
    "Important" : "Belangrik",
    "Today" : "Vandag",
    "Week" : "Week",
    "All" : "Alle",
    "Current" : "Huidige",
    "Completed" : "Voltooid",
    "Tasks" : "Take",
    "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
    "Hidden" : "Versteek",
    "Visible" : "Sigbaar",
    "Automatic" : "Outomaties",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "Edit" : "Wysig",
    "Copied" : "Gekopieer",
    "Delete" : "Skrap",
    "Unshare" : "Ontdeel",
    "Cancel" : "Kanselleer",
    "Save" : "Stoor",
    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
    "Change sort order" : "Verander sorteer volgorde",
    "Start date" : "Begindatum",
    "Due date" : "Sperdatum",
    "Last modified" : "Laas gewysig",
    "Priority" : "Prioriteit",
    "Alphabetically" : "Alfabeties",
    "Manually" : "Handmatig",
    "Task is completed" : "Taak is voltooid",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Voltooide taak","%n Voltooide take"],
    "Tomorrow" : "Môre",
    "New List" : "Nuwe lys",
    "All day" : "Heeldag",
    "Task not found!" : "Taak nie gevind!",
    "Set start date" : "Stel begindatum",
    "Set due date" : "Stel sperdatum",
    "An error occurred" : "'n Fout het voorgekom"
},
"nplurals=2; plural=(n != 1);");
