OC.L10N.register(
    "tasks",
    {
    "Important" : "مهم",
    "Today" : "امروز",
    "Week" : "هفته",
    "All" : "همه",
    "Current" : "کنونی",
    "Completed" : "نکمیل شده",
    "Tasks" : "وظایف",
    "Hidden" : "مخفی",
    "Automatic" : "خودکار",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
    "Edit" : "ویرایش",
    "Copy private link" : "پیوند خصوصی را کپی کنید",
    "Copied" : "کپی شد",
    "Delete" : "حذف",
    "Unshare" : "لغو اشتراک",
    "Cancel" : "لغو",
    "Save" : "ذخیره",
    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
    "Due date" : "موعد مقرر",
    "Last modified" : "آخرین اصلاح شده",
    "Alphabetically" : "الفبایی",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n کار تکمیل شده","%n کار تکمیل شده"],
    "Tomorrow" : "فردا",
    "New List" : "لیست جدید",
    "All day" : "تمام روز",
    "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
    "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
    "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
    "Task not found!" : "کار یافت نشد!",
    "Set due date" : "تعریف سر رسید",
    "An error occurred" : "خطایی روی داد"
},
"nplurals=2; plural=(n > 1);");
