OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Yaklaşan görevler",
    "Important" : "Önemli",
    "Today" : "Bugün",
    "Week" : "Hafta",
    "All" : "Tümü",
    "Current" : "Güncel",
    "Completed" : "Tamamlanmış",
    "Tasks" : "Görevler",
    "The Tasks app for Nextcloud" : "Nextcloud görevler uygulaması.",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Bu seçenek etkinleştirildiğinde, Nextcloud uygulamaları menüsünde Görevler seçeneği görüntülenir. Bu menüden görevler eklenip silinebilir, başlık, açıklama, başlangıç ve bitiş tarileri düzenlenebilir, önem düzeyi seçilebilir. Görevler kullanıcılar arasında paylaşılabilir. Görevler CalDAV kullanılarak eşitlenebilir (görev listeleri bir Nextcloud takvimi ile bağlantılıdır. Thunderbird, Evolution, KDE Kontact, iCal gibi bir yerel istemci ile eşitlemek için takvimin istemciye uzak takvim olarak eklenmesi yeterlidir). Görevler her takvimde bulunan indirme düğmesi kullanılarak ICS dosyası olarak indirilebilir.",
    "Default list" : "Varsayılan liste",
    "Visibility of Smart Collections" : "Akıllı derleme görünürlüğü",
    "Hidden" : "Gizli",
    "Visible" : "Görünür",
    "Automatic" : "Otomatik",
    "Share with users or groups" : "Kullanıcı ya da gruplarla paylaş",
    "No users or groups" : "Hiçbir kullanıcı ya da grupla",
    "Can edit" : "Düzenleyebilir",
    "Unshare with {displayName}" : "{displayName} ile paylaşımı kaldır",
    "Unable to delete the share." : "Paylaşım silinemedi.",
    "Unable to change permissions." : "İzinler değiştirilemedi.",
    "Edit" : "Düzenle",
    "Copy private link" : "Kişisel bağlantıyı kopyala",
    "Copied" : "Kopyalandı",
    "Cannot copy" : "Kopyalanamadı",
    "Export" : "Dışa aktar",
    "Delete" : "Sil",
    "Unshare" : "Paylaşımı kaldır",
    "Cancel" : "İptal",
    "Save" : "Kaydet",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Bu işlem \"{calendar}\" takvimini ve takvimdeki tüm etkinlik ve görevleri silecek.",
    "This will unshare the calendar \"{calendar}\"." : "Bu işlem {calendar} takvimini paylaşımdan kaldıracak.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Bu işlem \"{list}\" listesi ile ilgili tüm görevleri silecek.",
    "This will unshare the list \"{list}\"." : "Bu işlem \"{list}\" listesini paylaşımdan kaldıracak.",
    "Calendar link copied to clipboard." : "Takvim bağlantısı panoya kopyalandı.",
    "List link copied to clipboard." : "Liste bağlantısı panoya kopyalandı.",
    "Calendar link could not be copied to clipboard." : "Takvim bağlantısı panoya kopyalanamadı.",
    "List link could not be copied to clipboard." : "Liste bağlantısı panoya kopyalanamadı.",
    "The name \"{calendar}\" is already used." : "\"{calendar}\" adı zaten var.",
    "An empty name is not allowed." : "Ad boş bırakılamaz.",
    "An error occurred, unable to delete the calendar." : "Bir sorun çıktı. Takvim silinemedi.",
    "An error occurred, unable to delete the list." : "Bir sorun çıktığından liste silinemedi.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde silinecek","Takvim {countdown} saniye içinde silinecek"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde paylaşımdan kaldırılacak","Takvim {countdown} saniye içinde paylaşımdan kaldırılacak"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Liste {countdown} saniye içinde silinecek","Liste {countdown} saniye içinde silinecek"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Liste {countdown} saniye içinde paylaşımdan kaldırılacak","Liste {countdown} saniye içinde paylaşımdan kaldırılacak"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} varlık ile paylaşılmış","{num} varlık ile paylaşılmış"],
    "Trash bin" : "Çöp kutusu",
    "Loading deleted calendars, tasks and events." : "Silinmiş takvimler, görevler ve etkinlikler yükleniyor.",
    "You do not have any deleted calendars, tasks or events." : "Silinmiş herhangi bir takvim, görev ya da etkinlik yok.",
    "Name" : "Ad",
    "Deleted" : "Silinmiş",
    "Restore" : "Geri yükle",
    "Delete permanently" : "Kalıcı olarak sil",
    "Empty trash bin" : "Çöp kutusunu boşalt",
    "Untitled task" : "Adsız görev",
    "Untitled event" : "Adsız etkinlik",
    "Untitled journal" : "Adsız günlük",
    "Untitled item" : "Adsız öge",
    "Unknown calendar" : "Bilinmeyen takvim",
    "Could not load deleted calendars and objects" : "Silinmiş takvim ve nesneler yüklenemedi",
    "Could not delete calendar or event" : "Takvim ya da etkinlik silinemedi",
    "Could not restore calendar or event" : "Takvim ya da etkinlik geri yüklenemedi",
    "Do you really want to empty the trash bin?" : "Çöp kutusunu boşaltmak istediğinize emin misiniz?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Çöp kutusundaki ögeler {numDays} gün sonra silinir","Çöp kutusundaki ögeler {numDays} gün sonra silinir"],
    "Select a calendar" : "Bir takvim seçin",
    "No calendar matches the search." : "Arama ile eşleşen bir takvim bulunamadı.",
    "Set date" : "Tarihi ayarla",
    "Set time" : "Saati ayarla",
    "Delete date" : "Tarihi sil",
    "Click here to add a note." : "Bir not eklemek için buraya tıklayın.",
    "Set value" : "Değeri ayarla",
    "Delete value" : "Değeri sil",
    "Add this as a new tag" : "Bunu yeni bir etiket olarak ekle",
    "No tag available. Create one!" : "Kullanılabilecek bir etiket yok. İsterseniz ekleyin!",
    "Delete all completed tasks." : "Tüm tamamlanmış görevleri siler.",
    "Delete completed tasks." : "Tamamlanmış görevleri siler.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" takviminden tüm tamamlanmış görevler silindi.",
    "No errors" : "Sorun yok",
    "Open your browser console for more details" : "Ayrıntılı bilgi almak için tarayıcı konsolonu açın",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["\"{calendar}\" takviminden {taskCount} tamamlanmış görev ve alt görevleri silindi.","\"{calendar}\" takviminden {taskCount}  tamamlanmış görev ve alt görevleri silindi."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} görev silinemedi.","{failedCount} görev silinemedi."],
    "Add an important task to \"{calendar}\"…" : "\"{calendar}\" takvimine önemli bir görev ekle …",
    "Add a task due today to \"{calendar}\"…" : "\"{calendar}\" takvimine bugün bitecek bir görev ekle …",
    "Add a current task to \"{calendar}\"…" : "\"{calendar}\" takvimine geçerli bir görevi ekle …",
    "Add a task to \"{calendar}\"…" : "\"{calendar}\" takvimine bir görev ekle …",
    "Load all completed tasks." : "Tüm tamamlanmış görevleri yükler.",
    "Change sort order" : "Sıralamayı değiştir",
    "Relevance" : "İlişki",
    "Sort by completed state, due date, priority, start date and summary." : "Tamamlanma durumu, bitiş tarihi, öncelik, başlangıç tarihi ve özete göre sıralar.",
    "Start date" : "Başlangıç ​​tarihi",
    "Sort by start date and summary." : "Başlangıç tarihi ve özete göre sıralar.",
    "Due date" : "Bitiş tarihi",
    "Sort by due date and summary." : "Bitiş tarihi ve özete göre sıralar.",
    "Created date" : "Eklenme tarihi",
    "Sort by created date and summary." : "Eklenme tarihi ve özete göre sıralar.",
    "Last modified" : "Son değişiklik",
    "Sort by last-modified date and summary." : "Son değişiklik tarihi ve özete göre sıralar.",
    "Completed date" : "Tamamlanma tarihi",
    "Sort by completed date." : "Tamamlanma tarihine göre sıralar.",
    "Priority" : "Öncelik",
    "Sort by priority and summary." : "Öncelik ve özete göre sıralar.",
    "Alphabetically" : "Alfabetik",
    "Sort by summary and priority." : "Özellik ve önceliğe göre sıralar.",
    "Manually" : "El ile",
    "Sort by manual order." : "El belirtilen sıraya göre sıralar.",
    "{complete} % completed" : "% {complete} tamamlandı",
    "Task has hidden subtasks" : "Görevin gizlenmiş alt görevleri var",
    "Task is pinned" : "Görev sabitlenmiş",
    "Task has a note" : "Görevin bir notu var",
    "Add subtask" : "Alt görev ekle",
    "Show subtasks" : "Alt görevleri görüntüle",
    "Hide subtasks" : "Alt görevleri gizle",
    "Show closed subtasks" : "Kapatılmış alt görevleri görüntüle",
    "Hide closed subtasks" : "Kapatılmış alt görevleri gizle",
    "Delete task" : "Görevi sil",
    "Toggle starred" : "Yıldız koy/kaldır",
    "[Yesterday]" : "[Dün]",
    "[Today]" : "[Bugün]",
    "[Tomorrow]" : "[Yarın]",
    "[Completed yesterday]" : "[Dün tamamlanlar]",
    "[Completed today]" : "[Bugün tamamlananlar]",
    "[Completed tomorrow]" : "[Completed tamamlanacaklar]",
    "[Yesterday at] LT" : "[Dün şu saatte] LT",
    "[Today at] LT" : "[Bugün şu saatte] LT",
    "[Tomorrow at] LT" : "[Yarın şu saatte] LT",
    "L [at] LT" : "L LT [saatinde]",
    "[Completed yesterday at] LT" : "[Dün şu saatte tamamlananlar] LT",
    "[Completed today at] LT" : "[Bugün şu saatte tamamlananlar] LT",
    "[Completed tomorrow at] LT" : "[Yarın şu saatte tamamlanacaklar] LT",
    "[Completed] L [at] LT" : "[Tamamlandı] L LT [saatinde] ",
    "Add a subtask to \"{task}\"…" : "\"{task}\" görevine bir alt görev ekle …",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Görev {countdown} saniye içinde silinecek","Görev {countdown} saniye içinde silinecek"],
    "Task is cancelled" : "Görev iptal edildi",
    "Task is completed" : "Görev tamamlandı",
    "Task is read-only" : "Görev salt okunur",
    "Task is not completed" : "Görev tamamlanmadı",
    "Create a new task" : "Görev ekle",
    "Task summary" : "Görev özeti",
    "Create task" : "Görev ekle",
    "Creating the new task…" : "Yeni görev ekleniyor…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" görevi \"{calendar}\" takvimine eklendi",
    "Open task" : "Görevi aç",
    "Close" : "Kapat",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tamamlanmış Görev","%n Tamamlanmış Görev"],
    "Tomorrow" : "Yarın",
    "Add List…" : "Liste ekle …",
    "New List" : "Yeni liste",
    "All day" : "Tüm gün",
    "Unpin" : "Sabitlemeyi kaldır",
    "Pin" : "Sabitle",
    "Show in Calendar" : "Takvimde görüntülensin",
    "Edit title" : "Başlığı düzenle",
    "Details" : "Ayrıntılar",
    "Select a classification" : "Bir sınıflandırma seçin",
    "Select a status" : "Bir durum seçin",
    "Select tags" : "Etiketleri seçin",
    "Notes" : "Notlar",
    "Reminders" : "Anımsatıcılar",
    "Repeat" : "Yineleme",
    "When shared show full event" : "Paylaşılırken tüm işlemler görüntülensin",
    "When shared show only busy" : "Paylaşılırken yalnız meşgul olarak görüntülensin",
    "When shared hide this event" : "Paylaşılırken bu işlem gizlensin",
    "[Completed] L" : "[Tamamlandı] L",
    "[Completed last] dddd [at] LT" : "[Tamamlandı son olarak] dddd LT [zamanında]",
    "[Completed] dddd [at] LT" : "[Tamamlandı] dddd LT [zamanında]",
    "[Last modified yesterday at] LT" : "[Son değişiklik dün şu saatte] LT",
    "[Last modified today at] LT" : "[Son değişiklik bugün şu saatte] LT",
    "[Last modified] L" : "[Son değişiklik] L",
    "[Last modified last] dddd [at] LT" : "[Son değişiklik son olarak] dddd LT [zamanında]",
    "[Last modified] dddd [at] LT" : "[Son değişiklik] dddd LT [zamanında] ",
    "[Created yesterday at] LT" : "[Eklenme dün şu saatte] LT",
    "[Created today at] LT" : "[Eklenme bugün şu saatte] LT",
    "[Created] L" : "[Eklenme] L",
    "[Created last] dddd [at] LT" : "[Eklenme son] dddd LT [zamanında]",
    "[Created] dddd [at] LT" : "[Eklenme] dddd LT [zamanında]",
    "Needs action" : "İşlem yapılması gerekiyor",
    "In process" : "Sürüyor",
    "Canceled" : "İptal edildi",
    "Clear status" : "Durumu kaldır",
    "Loading task from server." : "Görev sunucudan yükleniyor.",
    "Task not found!" : "Görev bulunamadı!",
    "[Starts today]" : "[Bugün başlayanlar]",
    "[Starts tomorrow]" : "[Yarın başlayacaklar]",
    "[Starts on] LL" : "LL [tarihinde başlayacaklar]",
    "[Started yesterday]" : "[Dün başlayanlar]",
    "[Started on] LL" : "LL [tarihinde başlayanlar]",
    "[Started today at] LT" : "[Bugün şu saatte başlayanlar] LT",
    "[Starts today at] LT" : "[Bugün şu saatte başlayacaklar] LT",
    "[Starts tomorrow at] LT" : "[Yarın şu saatte başlayacaklar] LT",
    "[Starts on] LL [at] LT" : "LL [gününde] LT [saatinde başlayanlar]",
    "[Started yesterday at] LT" : "[Dün şu saatte başlayanlar] LT",
    "[Started on] LL [at] LT" : "LL [gününde] LT [saatinde başlayanlar]",
    "Set start date" : "Başlangıç tarihini ayarla",
    "[Due today]" : "[Bugün bitecekler]",
    "[Due tomorrow]" : "[Yarın bitecekler]",
    "[Due on] LL" : "LL [gününde bitecekler]",
    "[Was due yesterday]" : "[Dün bitmesi gerekenler]",
    "[Was due on] LL" : "LL [günü bitmesi gerekenler]",
    "[Was due today at] LT" : "[Bugün şu saatte bitmesi gerekenler] LT",
    "[Due today at] LT" : "[Bugün şu saatte bitecekler] LT",
    "[Due tomorrow at] LT" : "[Yarın şu saatte bitmesi gerekenler] LT",
    "[Due on] LL [at] LT" : "LL [günü] LT [saatinde bitmesi gerekenler]",
    "[Was due yesterday at] LT" : "[Dün şu saatte bitmesi gerekenler] LT",
    "[Was due on] LL [at] LT" : "LL [günü] LT [saatinde bitmesi gerekenler]",
    "Set due date" : "Bitiş tarihini ayarla",
    "Priority {priority}: low" : "Öncelik {priority}: Düşük",
    "Priority {priority}: medium" : "Öncelik {priority}: Orta",
    "Priority {priority}: high" : "Öncelik {priority}: Yüksek",
    "No priority assigned" : "Henüz bir öncelik atanmamış",
    "{percent} % completed" : "% {percent} tamamlandı",
    "No upcoming tasks" : "Yaklaşan bir görev yok",
    "upcoming tasks" : "yaklaşan görevler",
    "No tasks today" : "Bugün için bir görev yok",
    "Mark as done" : "Tamamlanmış olarak işaretle",
    "No due date assigned" : "Bitiş tarihi atanmamış",
    "[Due yesterday]" : "[Dün biten]",
    "[Due] L" : "L [gününde biten] ",
    "[Due yesterday at] LT" : "[Dün şu saatte biten] LT",
    "[Due] L [at] LT" : "L [günü] LT [saatinde biten]",
    "Successfully created the task." : "Görev oluşturuldu.",
    "Could not delete the task." : "Görev silinemedi.",
    "Synchronizing to the server." : "Sunucu ile eşitleniyor.",
    "Task successfully saved to server." : "Görev sunucu üzerine kaydedildi.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Görev sunucu üzerinde değiştirilmiş olduğundan güncellenemedi. Lütfen yenilemek için tıklayın. Yaptığınız yerel değişiklikler yok sayılacak.",
    "Could not update the task." : "Görev güncellenemedi.",
    "Successfully updated the task." : "Görev güncellendi.",
    "Task successfully moved to new calendar." : "Görev yeni takvime taşındı.",
    "An error occurred" : "Bir sorun çıktı",
    "Create a task" : "Bir görev ekle",
    "Message from {author} in {conversationName}" : "{conversationName} görüşmesinde {author} iletisi"
},
"nplurals=2; plural=(n > 1);");
