OC.L10N.register(
    "tasks",
    {
    "Important" : "مهم",
    "Today" : "اليوم",
    "Week" : "أسبوع",
    "All" : "الكل",
    "Current" : "الحالي",
    "Completed" : "مكتمل",
    "Tasks" : "المهام",
    "Hidden" : "مخفي",
    "Automatic" : "تلقائي",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "Edit" : "تعديل",
    "Delete" : "حذف ",
    "Unshare" : "إلغاء المشاركة",
    "Cancel" : "إلغاء",
    "Save" : "حفظ",
    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
    "No errors" : "لا توجد أخطاء",
    "Due date" : "تاريخ الانجاز",
    "Last modified" : "آخر تعديل",
    "Tomorrow" : "غدا",
    "New List" : "قائمة جديدة",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "An error occurred" : "طرأ هناك خطأ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
