OC.L10N.register(
    "tasks",
    {
    "Important" : "Important",
    "Today" : "Today",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Tasks" : "Tasks",
    "The Tasks app for Nextcloud" : "The Tasks app for Nextcloud",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Share with users or groups" : "Share with users or groups",
    "Edit" : "Edit",
    "Delete" : "Delete",
    "Unshare" : "Unshare",
    "Cancel" : "Cancel",
    "Save" : "Save",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "Change sort order" : "Change sort order",
    "Start date" : "Start date",
    "Due date" : "Due date",
    "Last modified" : "Last modified",
    "Priority" : "Priority",
    "Alphabetically" : "Alphabetically",
    "Manually" : "Manually",
    "Task is completed" : "Task is completed",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Tomorrow" : "Tomorrow",
    "New List" : "New List",
    "All day" : "All day",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Task not found!" : "Task not found!",
    "Set start date" : "Set start date",
    "Set due date" : "Set due date"
},
"nplurals=2; plural=(n != 1);");
